@@ -9,7 +9,7 @@ builddir="$2"
 # code
 #
 
-rm -Rf headers 2>/dev/null
+rm -Rf aqbanking5 2>/dev/null
 
 # The prefix to the source code (=srcdir)
 sprefix=`( cd ${srcdir} ; pwd )`
@@ -23,7 +23,7 @@ bprefix=`pwd`
 # functions
 #
 
-function symlinkFolder() {
+symlinkFolder () {
   local dfiles
   local src
   local dst
@@ -72,27 +72,40 @@ function symlinkFolder() {
 
 # symlink all headers from src/lib/aqbanking
 AQ_HEADER_FILES="${sprefix}/version.h ${sprefix}/system.h"
-mkdir -p headers/aqbanking
-symlinkFolder "src/libs/aqbanking" "headers/aqbanking"
-ln -s "${bprefix}/version.h" headers/aqbanking/version.h
-ln -s "${bprefix}/system.h" headers/aqbanking/system.h
-
-# symlink all headers from src/frontends
-dirlist='q4banking qbanking'  # list might be empty
-for frontend in ${dirlist} ; do
-  mkdir -p headers/${frontend}
-  symlinkFolder "src/frontends/${frontend}" "headers/${frontend}"
-done
+mkdir -p aqbanking5/aqbanking
+symlinkFolder "src/libs/aqbanking" "aqbanking5/aqbanking"
+ln -s "${bprefix}/version.h" aqbanking5/aqbanking/version.h
+ln -s "${bprefix}/system.h" aqbanking5/aqbanking/system.h
+ln -s "${bprefix}/src/libs/aqbanking/backendsupport/ab_jobqueue.h" aqbanking5/aqbanking
+ln -s "${bprefix}/src/libs/aqbanking/backendsupport/ab_accountqueue.h" aqbanking5/aqbanking
+ln -s "${bprefix}/src/libs/aqbanking/backendsupport/ab_userqueue.h" aqbanking5/aqbanking
 
 # symlink all headers from src/plugins/backends/
-dirlist='aqhbci aqofxconnect'  # list might be empty
+dirlist='aqhbci aqofxconnect aqpaypal'  # list might be empty
 for backend in ${dirlist} ; do
-  mkdir -p headers/${backend}
+  mkdir -p aqbanking5/${backend}
   if [ -d "src/plugins/backends/${backend}/plugin" ] ; then
-    symlinkFolder "src/plugins/backends/${backend}/plugin" "headers/${backend}"
+    symlinkFolder "src/plugins/backends/${backend}/plugin" "aqbanking5/${backend}"
+    # symlink all subfolders
+    for f in src/plugins/backends/${backend}/plugin/*; do
+      if [ -d "src/plugins/backends/${backend}/plugin/$f" ] ; then
+        case $f in
+          .libs | .deps)
+            ;;
+          *)
+            symlinkFolder "src/plugins/backends/${backend}/plugin/$f" "aqbanking5/${backend}"
+            ;;
+        esac
+      fi
+    done
   fi
+  
 done
 
+if [ -d aqbanking5/aqofxconnect ] ; then
+  ln -s "${bprefix}/src/plugins/backends/aqofxconnect/plugin/libofxhome/oh_institute_data.h" aqbanking5/aqofxconnect
+  ln -s "${bprefix}/src/plugins/backends/aqofxconnect/plugin/libofxhome/oh_institute_spec.h" aqbanking5/aqofxconnect
+fi
 
 
 rm -f sl-headers 2>/dev/null
