@@ -33,7 +33,7 @@
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/directory.h>
 #include <gwenhywfar/libloader.h>
-#include <gwenhywfar/bio_file.h>
+//#include <gwenhywfar/bio_file.h>
 #include <gwenhywfar/text.h>
 #include <gwenhywfar/xml.h>
 #include <gwenhywfar/pathmanager.h>
@@ -41,6 +41,7 @@
 #include <gwenhywfar/dbio.h>
 #include <gwenhywfar/ctplugin.h>
 #include <gwenhywfar/configmgr.h>
+#include <gwenhywfar/syncio_file.h>
 
 #include <stdlib.h>
 #include <assert.h>
@@ -167,7 +168,7 @@ void AB_Banking_free(AB_BANKING *ab){
 
     GWEN_INHERIT_FINI(AB_BANKING, ab);
 
-    AB_Banking_ClearCryptTokenList(ab, 0);
+    AB_Banking_ClearCryptTokenList(ab);
     GWEN_Crypt_Token_List2_free(ab->cryptTokenList);
     AB_Account_List_free(ab->accounts);
     AB_User_List_free(ab->users);
@@ -185,15 +186,14 @@ void AB_Banking_free(AB_BANKING *ab){
 
 
 
-int AB_Banking_GetUniqueId(AB_BANKING *ab, uint32_t guiid){
+int AB_Banking_GetUniqueId(AB_BANKING *ab){
   int rv;
   int uid=0;
   GWEN_DB_NODE *dbConfig=NULL;
 
   rv=GWEN_ConfigMgr_LockGroup(ab->configMgr,
 			      AB_CFG_GROUP_MAIN,
-			      "uniqueId",
-			      guiid);
+			      "uniqueId");
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Unable to lock main config (%d)", rv);
     return rv;
@@ -202,8 +202,7 @@ int AB_Banking_GetUniqueId(AB_BANKING *ab, uint32_t guiid){
   rv=GWEN_ConfigMgr_GetGroup(ab->configMgr,
 			     AB_CFG_GROUP_MAIN,
 			     "uniqueId",
-			     &dbConfig,
-			     guiid);
+			     &dbConfig);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Unable to read main config (%d)", rv);
     return rv;
@@ -216,14 +215,12 @@ int AB_Banking_GetUniqueId(AB_BANKING *ab, uint32_t guiid){
   rv=GWEN_ConfigMgr_SetGroup(ab->configMgr,
 			     AB_CFG_GROUP_MAIN,
 			     "uniqueId",
-			     dbConfig,
-			     guiid);
+			     dbConfig);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Unable to write main config (%d)", rv);
     GWEN_ConfigMgr_UnlockGroup(ab->configMgr,
 			       AB_CFG_GROUP_MAIN,
-			       "uniqueId",
-			       guiid);
+			       "uniqueId");
     GWEN_DB_Group_free(dbConfig);
     return rv;
   }
@@ -232,8 +229,7 @@ int AB_Banking_GetUniqueId(AB_BANKING *ab, uint32_t guiid){
   /* unlock */
   rv=GWEN_ConfigMgr_UnlockGroup(ab->configMgr,
 				AB_CFG_GROUP_MAIN,
-				"uniqueId",
-				guiid);
+				"uniqueId");
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Unable to unlock main config (%d)", rv);
     return rv;
@@ -244,14 +240,13 @@ int AB_Banking_GetUniqueId(AB_BANKING *ab, uint32_t guiid){
 
 
 
-int AB_Banking_SetUniqueId(AB_BANKING *ab, uint32_t uid, uint32_t guiid){
+int AB_Banking_SetUniqueId(AB_BANKING *ab, uint32_t uid){
   int rv;
   GWEN_DB_NODE *dbConfig=NULL;
 
   rv=GWEN_ConfigMgr_LockGroup(ab->configMgr,
 			      AB_CFG_GROUP_MAIN,
-			      "uniqueId",
-			      guiid);
+			      "uniqueId");
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Unable to lock main config (%d)", rv);
     return rv;
@@ -260,8 +255,7 @@ int AB_Banking_SetUniqueId(AB_BANKING *ab, uint32_t uid, uint32_t guiid){
   rv=GWEN_ConfigMgr_GetGroup(ab->configMgr,
 			     AB_CFG_GROUP_MAIN,
 			     "uniqueId",
-			     &dbConfig,
-			     guiid);
+			     &dbConfig);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Unable to read main config (%d)", rv);
     return rv;
@@ -272,14 +266,12 @@ int AB_Banking_SetUniqueId(AB_BANKING *ab, uint32_t uid, uint32_t guiid){
   rv=GWEN_ConfigMgr_SetGroup(ab->configMgr,
 			     AB_CFG_GROUP_MAIN,
 			     "uniqueId",
-			     dbConfig,
-			     guiid);
+			     dbConfig);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Unable to write main config (%d)", rv);
     GWEN_ConfigMgr_UnlockGroup(ab->configMgr,
 			       AB_CFG_GROUP_MAIN,
-			       "uniqueId",
-			       guiid);
+			       "uniqueId");
     GWEN_DB_Group_free(dbConfig);
     return rv;
   }
@@ -288,8 +280,7 @@ int AB_Banking_SetUniqueId(AB_BANKING *ab, uint32_t uid, uint32_t guiid){
   /* unlock */
   rv=GWEN_ConfigMgr_UnlockGroup(ab->configMgr,
 				AB_CFG_GROUP_MAIN,
-				"uniqueId",
-				guiid);
+				"uniqueId");
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "Unable to unlock main config (%d)", rv);
     return rv;
@@ -321,212 +312,6 @@ const char *AB_Banking_GetEscapedAppName(const AB_BANKING *ab){
 
 
 
-
-
-
-GWEN_PLUGIN_DESCRIPTION_LIST2 *AB_Banking_GetImExporterDescrs(AB_BANKING *ab){
-  GWEN_PLUGIN_DESCRIPTION_LIST2 *l;
-
-  l=GWEN_LoadPluginDescrs(AQBANKING_PLUGINS DIRSEP AB_IMEXPORTER_FOLDER);
-  return l;
-}
-
-
-
-int AB_Banking__ReadImExporterProfiles(AB_BANKING *ab,
-                                       const char *path,
-                                       GWEN_DB_NODE *db) {
-  GWEN_DIRECTORY *d;
-  GWEN_BUFFER *nbuf;
-  char nbuffer[64];
-  unsigned int pathLen;
-
-  if (!path)
-    path="";
-
-  /* create path */
-  nbuf=GWEN_Buffer_new(0, 256, 0, 1);
-  GWEN_Buffer_AppendString(nbuf, path);
-  pathLen=GWEN_Buffer_GetUsedBytes(nbuf);
-
-  d=GWEN_Directory_new();
-  if (GWEN_Directory_Open(d, GWEN_Buffer_GetStart(nbuf))) {
-    DBG_INFO(AQBANKING_LOGDOMAIN,
-             "Path \"%s\" is not available",
-	     GWEN_Buffer_GetStart(nbuf));
-    GWEN_Buffer_free(nbuf);
-    GWEN_Directory_free(d);
-    return GWEN_ERROR_NOT_FOUND;
-  }
-
-  while(!GWEN_Directory_Read(d,
-                             nbuffer,
-                             sizeof(nbuffer))) {
-    if (strcmp(nbuffer, ".") &&
-        strcmp(nbuffer, "..")) {
-      int nlen;
-
-      nlen=strlen(nbuffer);
-      if (nlen>4) {
-        if (strcasecmp(nbuffer+nlen-5, ".conf")==0) {
-          struct stat st;
-
-	  GWEN_Buffer_Crop(nbuf, 0, pathLen);
-	  GWEN_Buffer_SetPos(nbuf, pathLen);
-	  GWEN_Buffer_AppendString(nbuf, DIRSEP);
-	  GWEN_Buffer_AppendString(nbuf, nbuffer);
-
-	  if (stat(GWEN_Buffer_GetStart(nbuf), &st)) {
-	    DBG_ERROR(AQBANKING_LOGDOMAIN, "stat(%s): %s",
-		      GWEN_Buffer_GetStart(nbuf),
-		      strerror(errno));
-	  }
-	  else {
-            if (!S_ISDIR(st.st_mode)) {
-              GWEN_DB_NODE *dbT;
-
-              dbT=GWEN_DB_Group_new("profile");
-              if (GWEN_DB_ReadFile(dbT,
-                                   GWEN_Buffer_GetStart(nbuf),
-                                   GWEN_DB_FLAGS_DEFAULT |
-				   GWEN_PATH_FLAGS_CREATE_GROUP, 0, 2000)) {
-                DBG_ERROR(AQBANKING_LOGDOMAIN,
-                          "Could not read file \"%s\"",
-                          GWEN_Buffer_GetStart(nbuf));
-              }
-              else {
-                const char *s;
-
-                s=GWEN_DB_GetCharValue(dbT, "name", 0, 0);
-                if (!s) {
-                  DBG_ERROR(AQBANKING_LOGDOMAIN,
-                            "Bad file \"%s\" (no name)",
-                            GWEN_Buffer_GetStart(nbuf));
-                }
-                else {
-                  GWEN_DB_NODE *dbTarget;
-                  DBG_INFO(AQBANKING_LOGDOMAIN,
-                           "File \"%s\" contains profile \"%s\"",
-                           GWEN_Buffer_GetStart(nbuf), s);
-
-                  dbTarget=GWEN_DB_GetGroup(db,
-                                            GWEN_DB_FLAGS_OVERWRITE_GROUPS,
-                                            s);
-                  assert(dbTarget);
-                  GWEN_DB_AddGroupChildren(dbTarget, dbT);
-                } /* if name */
-              } /* if file successfully read */
-              GWEN_DB_Group_free(dbT);
-            } /* if !dir */
-          } /* if stat was ok */
-        } /* if conf */
-      } /* if name has more than 4 chars */
-    } /* if not "." and not ".." */
-  } /* while */
-  GWEN_Directory_Close(d);
-  GWEN_Directory_free(d);
-  GWEN_Buffer_free(nbuf);
-
-  return 0;
-}
-
-
-
-GWEN_DB_NODE *AB_Banking_GetImExporterProfiles(AB_BANKING *ab,
-                                               const char *name){
-  GWEN_BUFFER *buf;
-  GWEN_DB_NODE *db;
-  int rv;
-  GWEN_STRINGLIST *sl;
-  GWEN_STRINGLISTENTRY *sentry;
-
-  buf=GWEN_Buffer_new(0, 256, 0, 1);
-  db=GWEN_DB_Group_new("profiles");
-
-  sl=AB_Banking_GetGlobalDataDirs(ab);
-  assert(sl);
-
-  sentry=GWEN_StringList_FirstEntry(sl);
-  assert(sentry);
-
-  while(sentry) {
-    const char *pkgdatadir;
-
-    pkgdatadir = GWEN_StringListEntry_Data(sentry);
-    assert(pkgdatadir);
-
-    /* read global profiles */
-    GWEN_Buffer_AppendString(buf, pkgdatadir);
-    GWEN_Buffer_AppendString(buf,
-			     DIRSEP
-			     "aqbanking"
-			     DIRSEP
-			     AB_IMEXPORTER_FOLDER
-			     DIRSEP);
-    if (GWEN_Text_EscapeToBufferTolerant(name, buf)) {
-      DBG_ERROR(AQBANKING_LOGDOMAIN,
-                "Bad name for importer/exporter");
-      GWEN_StringList_free(sl);
-      GWEN_DB_Group_free(db);
-      GWEN_Buffer_free(buf);
-      return 0;
-    }
-    GWEN_Buffer_AppendString(buf, DIRSEP "profiles");
-    rv=AB_Banking__ReadImExporterProfiles(ab,
-                                          GWEN_Buffer_GetStart(buf),
-                                          db);
-    if (rv && rv!=GWEN_ERROR_NOT_FOUND) {
-      DBG_ERROR(AQBANKING_LOGDOMAIN,
-                "Error reading global profiles");
-      GWEN_StringList_free(sl);
-      GWEN_DB_Group_free(db);
-      GWEN_Buffer_free(buf);
-      return 0;
-    }
-    GWEN_Buffer_Reset(buf);
-    sentry=GWEN_StringListEntry_Next(sentry);
-  }
-  GWEN_StringList_free(sl);
-
-  /* read local user profiles */
-  if (AB_Banking_GetUserDataDir(ab, buf)) {
-    DBG_ERROR(AQBANKING_LOGDOMAIN,
-              "Could not get user data dir");
-    GWEN_DB_Group_free(db);
-    GWEN_Buffer_free(buf);
-    return 0;
-  }
-  GWEN_Buffer_AppendString(buf, DIRSEP AB_IMEXPORTER_FOLDER DIRSEP);
-  if (GWEN_Text_EscapeToBufferTolerant(name, buf)) {
-    DBG_ERROR(AQBANKING_LOGDOMAIN,
-              "Bad name for importer/exporter");
-    GWEN_DB_Group_free(db);
-    GWEN_Buffer_free(buf);
-    return 0;
-  }
-  GWEN_Buffer_AppendString(buf, DIRSEP "profiles");
-
-  rv=AB_Banking__ReadImExporterProfiles(ab,
-                                        GWEN_Buffer_GetStart(buf),
-                                        db);
-  if (rv && rv!=GWEN_ERROR_NOT_FOUND) {
-    DBG_ERROR(AQBANKING_LOGDOMAIN,
-              "Error reading users profiles");
-    GWEN_DB_Group_free(db);
-    GWEN_Buffer_free(buf);
-    return 0;
-  }
-  GWEN_Buffer_free(buf);
-
-  return db;
-}
-
-
-
-
-
-
-
 AB_BANKINFO_PLUGIN *AB_Banking__LoadBankInfoPlugin(AB_BANKING *ab,
 						   const char *modname){
   GWEN_PLUGIN *pl;
@@ -675,67 +460,6 @@ void AB_Banking_SetUserData(AB_BANKING *ab, void *user_data) {
 
 
 
-AB_IMEXPORTER *AB_Banking_FindImExporter(AB_BANKING *ab, const char *name) {
-  AB_IMEXPORTER *ie;
-
-  assert(ab);
-  assert(name);
-  ie=AB_ImExporter_List_First(ab_imexporters);
-  while(ie) {
-    if (strcasecmp(AB_ImExporter_GetName(ie), name)==0)
-      break;
-    ie=AB_ImExporter_List_Next(ie);
-  } /* while */
-
-  return ie;
-}
-
-
-
-AB_IMEXPORTER *AB_Banking_GetImExporter(AB_BANKING *ab, const char *name){
-  AB_IMEXPORTER *ie;
-
-  assert(ab);
-  assert(name);
-
-  ie=AB_Banking_FindImExporter(ab, name);
-  if (ie)
-    return ie;
-  ie=AB_Banking__LoadImExporterPlugin(ab, name);
-  if (ie) {
-    AB_ImExporter_List_Add(ie, ab_imexporters);
-  }
-
-  return ie;
-}
-
-
-
-AB_IMEXPORTER *AB_Banking__LoadImExporterPlugin(AB_BANKING *ab,
-                                                const char *modname){
-  GWEN_PLUGIN *pl;
-
-  pl=GWEN_PluginManager_GetPlugin(ab_pluginManagerImExporter, modname);
-  if (pl) {
-    AB_IMEXPORTER *ie;
-
-    ie=AB_Plugin_ImExporter_Factory(pl, ab);
-    if (!ie) {
-      DBG_ERROR(AQBANKING_LOGDOMAIN,
-		"Error in plugin [%s]: No im/exporter created",
-		modname);
-      return NULL;
-    }
-    return ie;
-  }
-  else {
-    DBG_INFO(AQBANKING_LOGDOMAIN, "Plugin [%s] not found", modname);
-    return NULL;
-  }
-}
-
-
-
 
 
 
@@ -747,11 +471,11 @@ AB_IMEXPORTER *AB_Banking__LoadImExporterPlugin(AB_BANKING *ab,
 
 
 
-AB_ACCOUNT *AB_Banking__GetAccount(AB_BANKING *ab, const char *accountId, uint32_t guiid){
+AB_ACCOUNT *AB_Banking__GetAccount(AB_BANKING *ab, const char *accountId){
   int rv;
   GWEN_DB_NODE *dbData=NULL;
 
-  rv=AB_Banking_LoadAppConfig(ab, &dbData, guiid);
+  rv=AB_Banking_LoadAppConfig(ab, &dbData);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN,
 	      "Unable to load app config");
@@ -791,30 +515,27 @@ AB_ACCOUNT *AB_Banking__GetAccount(AB_BANKING *ab, const char *accountId, uint32
 
 
 AB_ACCOUNT *AB_Banking_GetAccountByAlias(AB_BANKING *ab,
-					 const char *accountId,
-					 uint32_t guiid){
-  return AB_Banking__GetAccount(ab, accountId, guiid);
+					 const char *accountId){
+  return AB_Banking__GetAccount(ab, accountId);
 }
 
 
 
-void AB_Banking_SetAccountAlias(AB_BANKING *ab,
-				AB_ACCOUNT *a, const char *alias,
-				uint32_t guiid){
+void AB_Banking_SetAccountAlias(AB_BANKING *ab, AB_ACCOUNT *a, const char *alias){
   int rv;
   GWEN_DB_NODE *dbConfig=NULL;
   GWEN_DB_NODE *db;
 
-  rv=AB_Banking_LockAppConfig(ab, guiid);
+  rv=AB_Banking_LockAppConfig(ab);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "here (%d)", rv);
     return;
   }
 
-  rv=AB_Banking_LoadAppConfig(ab, &dbConfig, guiid);
+  rv=AB_Banking_LoadAppConfig(ab, &dbConfig);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "here (%d)", rv);
-    AB_Banking_UnlockAppConfig(ab, guiid);
+    AB_Banking_UnlockAppConfig(ab);
     return;
   }
 
@@ -823,14 +544,14 @@ void AB_Banking_SetAccountAlias(AB_BANKING *ab,
 		      alias,
 		      AB_Account_GetUniqueId(a));
 
-  rv=AB_Banking_SaveAppConfig(ab, dbConfig, guiid);
+  rv=AB_Banking_SaveAppConfig(ab, dbConfig);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "here (%d)", rv);
-    AB_Banking_UnlockAppConfig(ab, guiid);
+    AB_Banking_UnlockAppConfig(ab);
     return;
   }
 
-  rv=AB_Banking_UnlockAppConfig(ab, guiid);
+  rv=AB_Banking_UnlockAppConfig(ab);
   if (rv<0) {
     DBG_ERROR(AQBANKING_LOGDOMAIN, "here (%d)", rv);
     return;
@@ -1032,152 +753,32 @@ void AB_Banking_GetVersion(int *major,
 
 
 
+GWEN_DIALOG *AB_Banking_GetNewUserDialog(AB_BANKING *ab,
+					 const char *backend,
+					 int mode) {
+  AB_PROVIDER *pro;
+  GWEN_DIALOG *dlg;
 
-int AB_Banking_ExportWithProfile(AB_BANKING *ab,
-				 const char *exporterName,
-				 AB_IMEXPORTER_CONTEXT *ctx,
-				 const char *profileName,
-				 const char *profileFile,
-				 GWEN_IO_LAYER *io,
-				 uint32_t guiid) {
-  AB_IMEXPORTER *exporter;
-  GWEN_DB_NODE *dbProfiles;
-  GWEN_DB_NODE *dbProfile;
-  int rv;
-
-  exporter=AB_Banking_GetImExporter(ab, exporterName);
-  if (!exporter) {
-    DBG_ERROR(AQBANKING_LOGDOMAIN,
-	      "Export module \"%s\" not found",
-	      exporterName);
-    return GWEN_ERROR_NOT_FOUND;
+  assert(ab);
+  pro=AB_Banking_GetProvider(ab, backend);
+  if (!pro) {
+    DBG_ERROR(AQBANKING_LOGDOMAIN, "Backend \"%s\" not found", backend);
+    return NULL;
   }
 
-  /* get profiles */
-  if (profileFile) {
-    dbProfiles=GWEN_DB_Group_new("profiles");
-    if (GWEN_DB_ReadFile(dbProfiles, profileFile,
-                         GWEN_DB_FLAGS_DEFAULT |
-			 GWEN_PATH_FLAGS_CREATE_GROUP,
-			 0,
-			 2000)) {
-      DBG_ERROR(0, "Error reading profiles from \"%s\"",
-                profileFile);
-      return GWEN_ERROR_GENERIC;
-    }
-  }
-  else {
-    dbProfiles=AB_Banking_GetImExporterProfiles(ab, exporterName);
+  dlg=AB_Provider_GetNewUserDialog(pro, mode);
+  if (dlg==NULL) {
+    DBG_INFO(AQBANKING_LOGDOMAIN,
+	     "Provider did not return a NewUser dialog (backend=%s, mode=%d)",
+	     backend, mode);
+    return NULL;
   }
 
-  /* select profile */
-  dbProfile=GWEN_DB_GetFirstGroup(dbProfiles);
-  while(dbProfile) {
-    const char *name;
-
-    name=GWEN_DB_GetCharValue(dbProfile, "name", 0, 0);
-    assert(name);
-    if (strcasecmp(name, profileName)==0)
-      break;
-    dbProfile=GWEN_DB_GetNextGroup(dbProfile);
-  }
-  if (!dbProfile) {
-    DBG_ERROR(AQBANKING_LOGDOMAIN,
-	      "Profile \"%s\" for exporter \"%s\" not found",
-	      profileName, exporterName);
-    GWEN_DB_Group_free(dbProfiles);
-    return GWEN_ERROR_NOT_FOUND;
-  }
-
-  rv=AB_ImExporter_Export(exporter,
-			  ctx,
-			  io,
-			  dbProfile,
-			  guiid);
-  if (rv<0) {
-    DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
-    GWEN_DB_Group_free(dbProfiles);
-    return rv;
-  }
-
-  GWEN_DB_Group_free(dbProfiles);
-  return 0;
-}
-
-
-
-int AB_Banking_ImportWithProfile(AB_BANKING *ab,
-				 const char *importerName,
-				 AB_IMEXPORTER_CONTEXT *ctx,
-				 const char *profileName,
-				 const char *profileFile,
-				 GWEN_IO_LAYER *io,
-				 uint32_t guiid) {
-  AB_IMEXPORTER *importer;
-  GWEN_DB_NODE *dbProfiles;
-  GWEN_DB_NODE *dbProfile;
-  int rv;
-
-  importer=AB_Banking_GetImExporter(ab, importerName);
-  if (!importer) {
-    DBG_ERROR(AQBANKING_LOGDOMAIN,
-	      "Import module \"%s\" not found",
-	      importerName);
-    return GWEN_ERROR_NOT_FOUND;
-  }
-
-  /* get profiles */
-  if (profileFile) {
-    dbProfiles=GWEN_DB_Group_new("profiles");
-    if (GWEN_DB_ReadFile(dbProfiles, profileFile,
-                         GWEN_DB_FLAGS_DEFAULT |
-			 GWEN_PATH_FLAGS_CREATE_GROUP,
-			 0,
-			 2000)) {
-      DBG_ERROR(0, "Error reading profiles from \"%s\"",
-                profileFile);
-      return GWEN_ERROR_GENERIC;
-    }
-  }
-  else {
-    dbProfiles=AB_Banking_GetImExporterProfiles(ab, importerName);
-  }
-
-  /* select profile */
-  dbProfile=GWEN_DB_GetFirstGroup(dbProfiles);
-  while(dbProfile) {
-    const char *name;
-
-    name=GWEN_DB_GetCharValue(dbProfile, "name", 0, 0);
-    assert(name);
-    if (strcasecmp(name, profileName)==0)
-      break;
-    dbProfile=GWEN_DB_GetNextGroup(dbProfile);
-  }
-  if (!dbProfile) {
-    DBG_ERROR(AQBANKING_LOGDOMAIN,
-	      "Profile \"%s\" for importer \"%s\" not found",
-	      profileName, importerName);
-    GWEN_DB_Group_free(dbProfiles);
-    return GWEN_ERROR_NOT_FOUND;
-  }
-
-  rv=AB_ImExporter_Import(importer,
-			  ctx,
-			  io,
-			  dbProfile,
-			  guiid);
-  if (rv<0) {
-    DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
-    GWEN_DB_Group_free(dbProfiles);
-    return rv;
-  }
-
-  GWEN_DB_Group_free(dbProfiles);
-  return 0;
+  return dlg;
 }
 
 
 
 
 
+
