@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Mon Mar 01 2004
- copyright   : (C) 2004 by Martin Preuss
+ copyright   : (C) 2004-2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -19,10 +16,8 @@
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/inherit.h>
-#include <gwenhywfar/iolayer.h>
-#include <gwenhywfar/io_file.h>
-#include <gwenhywfar/io_memory.h>
-#include <gwenhywfar/iomanager.h>
+#include <gwenhywfar/syncio_file.h>
+#include <gwenhywfar/syncio_memory.h>
 
 #include <stdlib.h>
 #include <assert.h>
@@ -75,18 +70,45 @@ void AB_ImExporter_free(AB_IMEXPORTER *ie){
 
 
 
+uint32_t AB_ImExporter_GetFlags(const AB_IMEXPORTER *ie) {
+  assert(ie);
+  return ie->flags;
+}
+
+
+
+void AB_ImExporter_SetFlags(AB_IMEXPORTER *ie, uint32_t flags) {
+  assert(ie);
+  ie->flags=flags;
+}
+
+
+
+void AB_ImExporter_AddFlags(AB_IMEXPORTER *ie, uint32_t flags) {
+  assert(ie);
+  ie->flags|=flags;
+}
+
+
+
+void AB_ImExporter_SubFlags(AB_IMEXPORTER *ie, uint32_t flags) {
+  assert(ie);
+  ie->flags&=~flags;
+}
+
+
+
 int AB_ImExporter_Import(AB_IMEXPORTER *ie,
                          AB_IMEXPORTER_CONTEXT *ctx,
-			 GWEN_IO_LAYER *io,
-			 GWEN_DB_NODE *params,
-			 uint32_t guiid){
+			 GWEN_SYNCIO *sio,
+			 GWEN_DB_NODE *params){
   assert(ie);
   assert(ctx);
-  assert(io);
+  assert(sio);
   assert(params);
 
   if (ie->importFn)
-    return ie->importFn(ie, ctx, io, params, guiid);
+    return ie->importFn(ie, ctx, sio, params);
   else
     return GWEN_ERROR_NOT_SUPPORTED;
 }
@@ -95,16 +117,15 @@ int AB_ImExporter_Import(AB_IMEXPORTER *ie,
 
 int AB_ImExporter_Export(AB_IMEXPORTER *ie,
                          AB_IMEXPORTER_CONTEXT *ctx,
-			 GWEN_IO_LAYER *io,
-			 GWEN_DB_NODE *params,
-			 uint32_t guiid){
+			 GWEN_SYNCIO *sio,
+			 GWEN_DB_NODE *params){
   assert(ie);
   assert(ctx);
-  assert(io);
+  assert(sio);
   assert(params);
 
   if (ie->exportFn)
-    return ie->exportFn(ie, ctx, io, params, guiid);
+    return ie->exportFn(ie, ctx, sio, params);
   else
     return GWEN_ERROR_NOT_SUPPORTED;
 }
@@ -112,13 +133,27 @@ int AB_ImExporter_Export(AB_IMEXPORTER *ie,
 
 
 int AB_ImExporter_CheckFile(AB_IMEXPORTER *ie,
-			    const char *fname,
-			    uint32_t guiid){
+			    const char *fname){
   assert(ie);
   assert(fname);
 
   if (ie->checkFileFn)
-    return ie->checkFileFn(ie, fname, guiid);
+    return ie->checkFileFn(ie, fname);
+  else
+    return GWEN_ERROR_NOT_SUPPORTED;
+}
+
+
+
+int AB_ImExporter_GetEditProfileDialog(AB_IMEXPORTER *ie,
+				       GWEN_DB_NODE *dbProfile,
+				       const char *testFileName,
+				       GWEN_DIALOG **pDlg) {
+  assert(ie);
+  assert(dbProfile);
+
+  if (ie->getEditProfileDialogFn)
+    return ie->getEditProfileDialogFn(ie, dbProfile, testFileName, pDlg);
   else
     return GWEN_ERROR_NOT_SUPPORTED;
 }
@@ -128,38 +163,80 @@ int AB_ImExporter_CheckFile(AB_IMEXPORTER *ie,
 int AB_ImExporter_ImportFile(AB_IMEXPORTER *ie,
                              AB_IMEXPORTER_CONTEXT *ctx,
                              const char *fname,
-			     GWEN_DB_NODE *dbProfile,
-			     uint32_t guiid){
-  int fd;
+			     GWEN_DB_NODE *dbProfile){
+  GWEN_SYNCIO *sio;
   int rv;
-  GWEN_IO_LAYER *io;
 
   assert(ie);
   assert(ctx);
   assert(fname);
   assert(dbProfile);
 
-  fd=open(fname, O_RDONLY);
-  if (fd==-1) {
-    /* error */
-    DBG_ERROR(AQBANKING_LOGDOMAIN, "open(%s): %s", fname, strerror(errno));
-    return GWEN_ERROR_NOT_FOUND;
+  if (fname) {
+    sio=GWEN_SyncIo_File_new(fname, GWEN_SyncIo_File_CreationMode_OpenExisting);
+    GWEN_SyncIo_AddFlags(sio, GWEN_SYNCIO_FILE_FLAGS_READ);
+    rv=GWEN_SyncIo_Connect(sio);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      GWEN_SyncIo_free(sio);
+      return rv;
+    }
+  }
+  else {
+    sio=GWEN_SyncIo_File_fromStdin();
+    GWEN_SyncIo_AddFlags(sio, GWEN_SYNCIO_FLAGS_DONTCLOSE);
   }
 
-  /* create io layer for this file (readonly) */
-  io=GWEN_Io_LayerFile_new(fd, -1);
-  assert(io);
+  rv=AB_ImExporter_Import(ie, ctx, sio, dbProfile);
+  GWEN_SyncIo_Disconnect(sio);
+  GWEN_SyncIo_free(sio);
 
-  rv=GWEN_Io_Manager_RegisterLayer(io);
-  if (rv) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Internal error: Could not register io layer (%d)", rv);
-    GWEN_Io_Layer_free(io);
+  return rv;
+}
+
+
+
+int AB_ImExporter_ExportToFile(AB_IMEXPORTER *ie,
+			       AB_IMEXPORTER_CONTEXT *ctx,
+			       const char *fname,
+			       GWEN_DB_NODE *dbProfile) {
+  GWEN_SYNCIO *sio;
+  int rv;
+
+  assert(ie);
+  assert(ctx);
+  assert(fname);
+  assert(dbProfile);
+
+  if (fname) {
+    sio=GWEN_SyncIo_File_new(fname, GWEN_SyncIo_File_CreationMode_CreateAlways);
+    GWEN_SyncIo_AddFlags(sio,
+			 GWEN_SYNCIO_FILE_FLAGS_READ |
+			 GWEN_SYNCIO_FILE_FLAGS_WRITE |
+			 GWEN_SYNCIO_FILE_FLAGS_UREAD |
+			 GWEN_SYNCIO_FILE_FLAGS_UWRITE |
+			 GWEN_SYNCIO_FILE_FLAGS_GREAD |
+			 GWEN_SYNCIO_FILE_FLAGS_GWRITE);
+    rv=GWEN_SyncIo_Connect(sio);
+    if (rv<0) {
+      DBG_INFO(AQBANKING_LOGDOMAIN, "here (%d)", rv);
+      GWEN_SyncIo_free(sio);
+      return rv;
+    }
+  }
+  else {
+    sio=GWEN_SyncIo_File_fromStdout();
+    GWEN_SyncIo_AddFlags(sio, GWEN_SYNCIO_FLAGS_DONTCLOSE);
+  }
+
+  rv=AB_ImExporter_Export(ie, ctx, sio, dbProfile);
+  rv=GWEN_SyncIo_Disconnect(sio);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+    GWEN_SyncIo_free(sio);
     return rv;
   }
-
-  rv=AB_ImExporter_Import(ie, ctx, io, dbProfile, guiid);
-  GWEN_Io_Layer_DisconnectRecursively(io, NULL, GWEN_IO_REQUEST_FLAGS_FORCE, guiid, 2000);
-  GWEN_Io_Layer_free(io);
+  GWEN_SyncIo_free(sio);
 
   return rv;
 }
@@ -169,10 +246,9 @@ int AB_ImExporter_ImportFile(AB_IMEXPORTER *ie,
 int AB_ImExporter_ImportBuffer(AB_IMEXPORTER *ie,
 			       AB_IMEXPORTER_CONTEXT *ctx,
 			       GWEN_BUFFER *buf,
-			       GWEN_DB_NODE *dbProfile,
-			       uint32_t guiid) {
+			       GWEN_DB_NODE *dbProfile) {
   int rv;
-  GWEN_IO_LAYER *io;
+  GWEN_SYNCIO *sio;
 
   assert(ie);
   assert(ctx);
@@ -180,19 +256,10 @@ int AB_ImExporter_ImportBuffer(AB_IMEXPORTER *ie,
   assert(dbProfile);
 
   /* create io layer for this file (readonly) */
-  io=GWEN_Io_LayerMemory_new(buf);
-  assert(io);
+  sio=GWEN_SyncIo_Memory_new(buf, 0);
 
-  rv=GWEN_Io_Manager_RegisterLayer(io);
-  if (rv<0) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Internal error: Could not register io layer (%d)", rv);
-    GWEN_Io_Layer_free(io);
-    return rv;
-  }
-
-  rv=AB_ImExporter_Import(ie, ctx, io, dbProfile, guiid);
-  GWEN_Io_Layer_DisconnectRecursively(io, NULL, GWEN_IO_REQUEST_FLAGS_FORCE, guiid, 2000);
-  GWEN_Io_Layer_free(io);
+  rv=AB_ImExporter_Import(ie, ctx, sio, dbProfile);
+  GWEN_SyncIo_free(sio);
 
   return rv;
 }
@@ -202,10 +269,9 @@ int AB_ImExporter_ImportBuffer(AB_IMEXPORTER *ie,
 int AB_ImExporter_ExportToBuffer(AB_IMEXPORTER *ie,
 				 AB_IMEXPORTER_CONTEXT *ctx,
 				 GWEN_BUFFER *buf,
-				 GWEN_DB_NODE *dbProfile,
-				 uint32_t guiid) {
+				 GWEN_DB_NODE *dbProfile) {
   int rv;
-  GWEN_IO_LAYER *io;
+  GWEN_SYNCIO *sio;
 
   assert(ie);
   assert(ctx);
@@ -213,19 +279,9 @@ int AB_ImExporter_ExportToBuffer(AB_IMEXPORTER *ie,
   assert(dbProfile);
 
   /* create io layer for this file (readonly) */
-  io=GWEN_Io_LayerMemory_new(buf);
-  assert(io);
-
-  rv=GWEN_Io_Manager_RegisterLayer(io);
-  if (rv<0) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Internal error: Could not register io layer (%d)", rv);
-    GWEN_Io_Layer_free(io);
-    return rv;
-  }
-
-  rv=AB_ImExporter_Export(ie, ctx, io, dbProfile, guiid);
-  GWEN_Io_Layer_DisconnectRecursively(io, NULL, GWEN_IO_REQUEST_FLAGS_FORCE, guiid, 2000);
-  GWEN_Io_Layer_free(io);
+  sio=GWEN_SyncIo_Memory_new(buf, 0);
+  rv=AB_ImExporter_Export(ie, ctx, sio, dbProfile);
+  GWEN_SyncIo_free(sio);
 
   return rv;
 }
@@ -256,6 +312,14 @@ void AB_ImExporter_SetCheckFileFn(AB_IMEXPORTER *ie,
 
 
 
+void AB_ImExporter_SetGetEditProfileDialogFn(AB_IMEXPORTER *ie,
+					     AB_IMEXPORTER_GET_EDITPROFILE_DIALOG_FN f) {
+  assert(ie);
+  ie->getEditProfileDialogFn=f;
+}
+
+
+
 AB_BANKING *AB_ImExporter_GetBanking(const AB_IMEXPORTER *ie){
   assert(ie);
   return ie->banking;
@@ -971,6 +1035,14 @@ int AB_ImExporterAccountInfo_GetTransactionCount(const AB_IMEXPORTER_ACCOUNTINFO
 
 
 
+void AB_ImExporterAccountInfo_ClearTransactions(AB_IMEXPORTER_ACCOUNTINFO *iea) {
+  assert(iea);
+  iea->nextTransaction=NULL;
+  AB_Transaction_List_Clear(iea->transactions);
+}
+
+
+
 void AB_ImExporterAccountInfo_AddStandingOrder(AB_IMEXPORTER_ACCOUNTINFO *iea,
                                                AB_TRANSACTION *t){
   assert(iea);
@@ -1434,6 +1506,16 @@ void AB_ImExporterContext_free(AB_IMEXPORTER_CONTEXT *iec){
 
 
 
+void AB_ImExporterContext_Clear(AB_IMEXPORTER_CONTEXT *iec){
+  assert(iec);
+  GWEN_Buffer_Reset(iec->logs);
+  AB_Message_List_Clear(iec->messageList);
+  AB_Security_List_Clear(iec->securityList);
+  AB_ImExporterAccountInfo_List_Clear(iec->accountInfoList);
+}
+
+
+
 int AB_ImExporterContext_toDb(const AB_IMEXPORTER_CONTEXT *iec,
 			       GWEN_DB_NODE *db){
   AB_IMEXPORTER_ACCOUNTINFO *iea;
