@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Mon Mar 01 2004
- copyright   : (C) 2004 by Martin Preuss
+ copyright   : (C) 2004-2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -16,9 +13,11 @@
 #define AQBANKING_IMEXPORTER_H
 
 #include <gwenhywfar/inherit.h>
-#include <gwenhywfar/iolayer.h>
+#include <gwenhywfar/syncio.h>
 #include <gwenhywfar/db.h>
 #include <gwenhywfar/types.h>
+#include <gwenhywfar/dialog.h>
+
 #include <aqbanking/error.h>
 #include <aqbanking/accstatus.h>
 
@@ -42,6 +41,21 @@
  */
 /*@{*/
 
+
+
+/** @name Flags returned by @ref AB_ImExporter_GetFlags
+ *
+ */
+/*@{*/
+
+/** This module supports the function @ref AB_ImExporter_GetEditProfileDialog */
+#define AB_IMEXPORTER_FLAGS_GETPROFILEEDITOR_SUPPORTED 0x00000001
+
+
+/*@}*/
+
+
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -86,9 +100,8 @@ extern "C" {
 AQBANKING_API 
 int AB_ImExporter_Import(AB_IMEXPORTER *ie,
                          AB_IMEXPORTER_CONTEXT *ctx,
-			 GWEN_IO_LAYER *io,
-			 GWEN_DB_NODE *dbProfile,
-			 uint32_t guiid);
+			 GWEN_SYNCIO *sio,
+			 GWEN_DB_NODE *dbProfile);
 
 /**
  * Writes all data to the given stream.
@@ -102,9 +115,32 @@ int AB_ImExporter_Import(AB_IMEXPORTER *ie,
 AQBANKING_API 
 int AB_ImExporter_Export(AB_IMEXPORTER *ie,
                          AB_IMEXPORTER_CONTEXT *ctx,
-			 GWEN_IO_LAYER *io,
-			 GWEN_DB_NODE *dbProfile,
-			 uint32_t guiid);
+			 GWEN_SYNCIO *sio,
+			 GWEN_DB_NODE *dbProfile);
+
+/**
+ * This function should return a dialog (see @ref GWEN_DIALOG) which
+ * allows editing of the given profile.
+ * You can use @ref AB_ImExporter_GetFlags to determine beforehand whether
+ * this function is supported (look for
+ * @ref AB_IMEXPORTER_FLAGS_GETPROFILEEDITOR_SUPPORTED).
+ * (introduced in AqBanking 4.3.0)
+ *
+ * @param ie pointer to the importer/exporter
+ *
+ * @param dbProfile configuration data for the exporter. You can get this
+ *   using @ref AB_Banking_GetImExporterProfiles.
+ *
+ * @param pDlg pointer to a dialog pointer (receives the created dialog if any)
+ *
+ * @return 0 on success, error code otherwise
+ */
+AQBANKING_API
+int AB_ImExporter_GetEditProfileDialog(AB_IMEXPORTER *ie,
+				       GWEN_DB_NODE *dbProfile,
+				       const char *testFileName,
+				       GWEN_DIALOG **pDlg);
+
 
 /**
  * This is just a convenience function for @ref AB_ImExporter_Import.
@@ -113,31 +149,32 @@ AQBANKING_API
 int AB_ImExporter_ImportFile(AB_IMEXPORTER *ie,
                              AB_IMEXPORTER_CONTEXT *ctx,
                              const char *fname,
-			     GWEN_DB_NODE *dbProfile,
-			     uint32_t guiid);
+			     GWEN_DB_NODE *dbProfile);
 
 AQBANKING_API
 int AB_ImExporter_ImportBuffer(AB_IMEXPORTER *ie,
 			       AB_IMEXPORTER_CONTEXT *ctx,
                                GWEN_BUFFER *buf,
-			       GWEN_DB_NODE *dbProfile,
-			       uint32_t guiid);
+			       GWEN_DB_NODE *dbProfile);
 
 AQBANKING_API
 int AB_ImExporter_ExportToBuffer(AB_IMEXPORTER *ie,
 				 AB_IMEXPORTER_CONTEXT *ctx,
 				 GWEN_BUFFER *buf,
-				 GWEN_DB_NODE *dbProfile,
-				 uint32_t guiid);
+				 GWEN_DB_NODE *dbProfile);
 
+AQBANKING_API
+int AB_ImExporter_ExportToFile(AB_IMEXPORTER *ie,
+			       AB_IMEXPORTER_CONTEXT *ctx,
+			       const char *fname,
+			       GWEN_DB_NODE *dbProfile);
 
 /**
  * This function checks whether the given importer supports the given file.
  */
 AQBANKING_API
 int AB_ImExporter_CheckFile(AB_IMEXPORTER *ie,
-			    const char *fname,
-			    uint32_t guiid);
+			    const char *fname);
 
 /*@}*/
 
@@ -155,6 +192,14 @@ AQBANKING_API
 const char *AB_ImExporter_GetName(const AB_IMEXPORTER *ie);
 
 
+/**
+ * Returns the flags if this im/exporter which specify the supported
+ * features.
+ */
+AQBANKING_API
+uint32_t AB_ImExporter_GetFlags(const AB_IMEXPORTER *ie);
+
+
 /*@}*/ /* defgroup */
 
 
@@ -174,6 +219,13 @@ AB_IMEXPORTER_CONTEXT *AB_ImExporterContext_new();
 AQBANKING_API
 void AB_ImExporterContext_free(AB_IMEXPORTER_CONTEXT *iec);
 
+/**
+ * This function clears the context (e.g. removes all transactions etc).
+ * (introduced in AqBanking 4.3.0)
+ */
+AQBANKING_API
+void AB_ImExporterContext_Clear(AB_IMEXPORTER_CONTEXT *iec);
+
 /** Stores a complete import/export context to a GWEN_DB.
  *
  */
@@ -620,6 +672,12 @@ AB_ImExporterAccountInfo_TransactionsForEach(AB_IMEXPORTER_ACCOUNTINFO *iea,
 AQBANKING_API
 int AB_ImExporterAccountInfo_GetTransactionCount(const AB_IMEXPORTER_ACCOUNTINFO *iea);
 
+/**
+ * Clear all transactions stored in the given account info.
+ */
+AQBANKING_API 
+void AB_ImExporterAccountInfo_ClearTransactions(AB_IMEXPORTER_ACCOUNTINFO *iea);
+
 /*@}*/
 
 
