@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Mon Mar 01 2004
- copyright   : (C) 2004 by Martin Preuss
+ copyright   : (C) 2004-2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -17,7 +14,6 @@
 
 #include "transaction_p.h"
 #include <aqbanking/transactionfns.h>
-#include <gwenhywfar/bio_buffer.h>
 #include <gwenhywfar/debug.h>
 
 
@@ -44,7 +40,7 @@ int AB_Transaction_Compare(const AB_TRANSACTION *t1,
       /* remove variables from comparison */
       GWEN_DB_DeleteVar(dbT, "status");
 
-      err=GWEN_DB_WriteToBuffer(dbT, buf1, GWEN_DB_FLAGS_COMPACT, 0, 2000);
+      err=GWEN_DB_WriteToBuffer(dbT, buf1, GWEN_DB_FLAGS_COMPACT);
       if (err) {
 	DBG_ERROR(AQBANKING_LOGDOMAIN,
 		  "INTERNAL: Error writing DB to buffer");
@@ -64,7 +60,7 @@ int AB_Transaction_Compare(const AB_TRANSACTION *t1,
       /* remove variables from comparison */
       GWEN_DB_DeleteVar(dbT, "status");
 
-      err=GWEN_DB_WriteToBuffer(dbT, buf0, GWEN_DB_FLAGS_COMPACT, 0, 2000);
+      err=GWEN_DB_WriteToBuffer(dbT, buf0, GWEN_DB_FLAGS_COMPACT);
       if (err) {
 	DBG_ERROR(AQBANKING_LOGDOMAIN,
 		  "INTERNAL: Error writing DB to buffer");
