@@ -181,8 +181,7 @@ int AH_Job_MultiTransferBase_GetMaxTransfers(AH_JOB *j){
 
 
 /* --------------------------------------------------------------- FUNCTION */
-int AH_Job_MultiTransfer_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
-				 uint32_t guiid){
+int AH_Job_MultiTransfer_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_MULTITRANSFER *aj;
 
   assert(j);
@@ -366,8 +365,8 @@ int AH_Job_MultiTransfer__ValidateTransfer(AB_JOB *bj,
 	     "No local suffix, filling in (if possible)");
     a=AH_AccountJob_GetAccount(mj);
     assert(a);
-    s=AH_Account_GetSuffix(a);
-    if (s)
+    s=AB_Account_GetSubAccountId(a);
+    if (s && *s)
       AB_Transaction_SetLocalSuffix(t, s);
   }
 
@@ -402,8 +401,7 @@ int AH_Job_MultiTransfer__ValidateTransfer(AB_JOB *bj,
 /* --------------------------------------------------------------- FUNCTION */
 int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 				  AH_JOB_EXCHANGE_MODE m,
-				  AB_IMEXPORTER_CONTEXT *ctx,
-				  uint32_t guiid){
+				  AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_MULTITRANSFER *aj;
 
   DBG_INFO(AQHBCI_LOGDOMAIN, "Exchanging (%d)", m);
@@ -430,7 +428,7 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
     dbParams=AH_Job_GetParams(j);
     DBG_DEBUG(AQHBCI_LOGDOMAIN, "Have this parameters to exchange:");
     if (GWEN_Logger_GetLevel(AQHBCI_LOGDOMAIN)>=GWEN_LoggerLevel_Debug)
-      GWEN_DB_Dump(dbParams, stderr, 2);
+      GWEN_DB_Dump(dbParams, 2);
     /* read limits */
     lim=AB_TransactionLimits_new();
     AB_TransactionLimits_SetMaxLenPurpose(lim, 27);
@@ -665,7 +663,7 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 
 
 
-int AH_Job_MultiTransfer_Prepare(AH_JOB *j, uint32_t guiid){
+int AH_Job_MultiTransfer_Prepare(AH_JOB *j){
   AH_JOB_MULTITRANSFER *aj;
   GWEN_BUFFER *tbuf;
   char *p;
