@@ -27,13 +27,11 @@ struct AH_JOB_MULTITRANSFER {
 };
 static void GWENHYWFAR_CB AH_Job_MultiTransfer_FreeData(void *bp, void *p);
 static int AH_Job_MultiTransfer_Process(AH_JOB *j,
-					AB_IMEXPORTER_CONTEXT *ctx,
-					uint32_t guiid);
+					AB_IMEXPORTER_CONTEXT *ctx);
 static int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 					 AH_JOB_EXCHANGE_MODE m,
-					 AB_IMEXPORTER_CONTEXT *ctx,
-					 uint32_t guiid);
-static int AH_Job_MultiTransfer_Prepare(AH_JOB *j, uint32_t guiid);
+					 AB_IMEXPORTER_CONTEXT *ctx);
+static int AH_Job_MultiTransfer_Prepare(AH_JOB *j);
 
 
 static int AH_Job_MultiTransfer__ValidateTransfer(AB_JOB *bj,
