@@ -275,8 +275,7 @@ const char *AH_Job_SingleTransfer_GetOldFiid(AH_JOB *j) {
 
 
 /* --------------------------------------------------------------- FUNCTION */
-int AH_Job_SingleTransfer_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
-				  uint32_t guiid){
+int AH_Job_SingleTransfer_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_SINGLETRANSFER *aj;
   GWEN_DB_NODE *dbResponses;
   GWEN_DB_NODE *dbCurr;
@@ -556,6 +555,10 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
 	if (maxn && n>maxn) {
 	  DBG_ERROR(AQHBCI_LOGDOMAIN,
 		    "Too many purpose lines (%d>%d)", n, maxn);
+	  GWEN_Gui_ProgressLog2(0,
+				GWEN_LoggerLevel_Error,
+				I18N("Too many purpose lines (%d>%d)"),
+				n, maxn);
 	  GWEN_StringList_free(nsl);
 	  return GWEN_ERROR_INVALID;
 	}
@@ -566,6 +569,10 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
 	if (maxs && l>maxs) {
 	  DBG_ERROR(AQHBCI_LOGDOMAIN,
 		    "Too many chars in purpose line %d (%d>%d)", n, l, maxs);
+	  GWEN_Gui_ProgressLog2(0,
+				GWEN_LoggerLevel_Error,
+				I18N("Too many chars in purpose line %d (%d>%d)"),
+				n, l, maxs);
 	  GWEN_StringList_free(nsl);
 	  return GWEN_ERROR_INVALID;
 	}
@@ -698,8 +705,8 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
 	     "No local suffix, filling in (if possible)");
     a=AH_AccountJob_GetAccount(mj);
     assert(a);
-    s=AH_Account_GetSuffix(a);
-    if (s)
+    s=AB_Account_GetSubAccountId(a);
+    if (s && *s)
       AB_Transaction_SetLocalSuffix(t, s);
   }
 
@@ -730,6 +737,10 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
       if (!AB_TransactionLimits_HasValuesTextKey(lim, numbuf)) {
 	DBG_ERROR(AQHBCI_LOGDOMAIN, "Text key \"%s\" not supported by bank",
 		  numbuf);
+	GWEN_Gui_ProgressLog2(0,
+			      GWEN_LoggerLevel_Error,
+			      I18N("Text key \"%d\" not supported by the bank"),
+			      n);
 	return GWEN_ERROR_INVALID;
       }
     }
@@ -766,6 +777,10 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "Month day \"%s\" not supported by bank",
                       numbuf);
+	    GWEN_Gui_ProgressLog2(0,
+				  GWEN_LoggerLevel_Error,
+				  I18N("Month day \"%d\" not supported by bank"),
+				  n);
             return GWEN_ERROR_INVALID;
           }
         }
@@ -788,6 +803,10 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "Execution month day \"%s\" not supported by bank",
                       numbuf);
+	    GWEN_Gui_ProgressLog2(0,
+				  GWEN_LoggerLevel_Error,
+				  I18N("Execution month day \"%d\" not supported by bank"),
+				  n);
             return GWEN_ERROR_INVALID;
           }
         } /* if there are limits */
@@ -813,6 +832,10 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "Week day \"%s\" not supported by bank",
                       numbuf);
+	    GWEN_Gui_ProgressLog2(0,
+				  GWEN_LoggerLevel_Error,
+				  I18N("Week day \"%d\" not supported by bank"),
+				  n);
             return GWEN_ERROR_INVALID;
           }
         } /* if there are limits */
@@ -835,6 +858,10 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
             DBG_ERROR(AQHBCI_LOGDOMAIN,
                       "Execution month day \"%s\" not supported by bank",
                       numbuf);
+	    GWEN_Gui_ProgressLog2(0,
+				  GWEN_LoggerLevel_Error,
+				  I18N("Execution month day \"%d\" not supported by bank"),
+				  n);
             return GWEN_ERROR_INVALID;
           }
         } /* if there are limits */
@@ -862,6 +889,11 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
         if (n && dt<n) {
           DBG_ERROR(AQHBCI_LOGDOMAIN,
                     "Minimum setup time violated");
+	  GWEN_Gui_ProgressLog2(0,
+				GWEN_LoggerLevel_Error,
+				I18N("Minimum setup time violated. "
+				     "Dated transactions need to be at least %d days away"),
+				n);
           return GWEN_ERROR_INVALID;
         }
 
@@ -870,6 +902,11 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
         if (n && dt>n) {
           DBG_ERROR(AQHBCI_LOGDOMAIN,
                     "Maximum setup time violated");
+	  GWEN_Gui_ProgressLog2(0,
+				GWEN_LoggerLevel_Error,
+				I18N("Maximum setup time violated. "
+				     "Dated transactions need to be at most %d days away"),
+				n);
           return GWEN_ERROR_INVALID;
         }
       }
@@ -893,6 +930,11 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
         if (n && dt<n) {
           DBG_ERROR(AQHBCI_LOGDOMAIN,
                     "Minimum setup time violated");
+	  GWEN_Gui_ProgressLog2(0,
+				GWEN_LoggerLevel_Error,
+				I18N("Minimum setup time violated. "
+				     "Dated transactions need to be at least %d days away"),
+				n);
           return GWEN_ERROR_INVALID;
         }
 
@@ -901,6 +943,11 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
         if (n && dt>n) {
           DBG_ERROR(AQHBCI_LOGDOMAIN,
                     "Maximum setup time violated");
+	  GWEN_Gui_ProgressLog2(0,
+				GWEN_LoggerLevel_Error,
+				I18N("Maximum setup time violated. "
+				     "Dated transactions need to be at most %d days away"),
+				n);
           return GWEN_ERROR_INVALID;
         }
       }
@@ -923,8 +970,7 @@ int AH_Job_SingleTransfer__ValidateTransfer(AB_JOB *bj,
 /* --------------------------------------------------------------- FUNCTION */
 int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 				   AH_JOB_EXCHANGE_MODE m,
-				   AB_IMEXPORTER_CONTEXT *ctx,
-				   uint32_t guiid){
+				   AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_SINGLETRANSFER *aj;
 
   DBG_INFO(AQHBCI_LOGDOMAIN, "Exchanging (%d)", m);
@@ -950,7 +996,7 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
     dbParams=AH_Job_GetParams(j);
     DBG_DEBUG(AQHBCI_LOGDOMAIN, "Have this parameters to exchange:");
     if (GWEN_Logger_GetLevel(AQHBCI_LOGDOMAIN)>=GWEN_LoggerLevel_Debug)
-      GWEN_DB_Dump(dbParams, stderr, 2);
+      GWEN_DB_Dump(dbParams, 2);
 
     /* read limits */
     lim=AB_TransactionLimits_new();
@@ -1047,16 +1093,16 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
       s=GWEN_DB_GetCharValue(dbParams, "AllowedWeekDays", 0, 0);
       if (s && *s) {
 	while(*s) {
-	  char buf[3];
+	  char buf[2];
           const char *x;
 
-          buf[2]=0;
-          strncpy(buf, s, 2);
+	  buf[0]=*s;
+	  buf[1]=0;
           x=buf;
           if (*x=='0')
             x++;
           AB_TransactionLimits_AddValuesExecutionDayWeek(lim, x, 0);
-	  s+=2;
+	  s++;
 	} /* while */
         GWEN_StringList_Sort(AB_TransactionLimits_GetValuesExecutionDayWeek(lim),
                              1, GWEN_StringList_SortModeInt);
@@ -1177,6 +1223,7 @@ int AH_Job_SingleTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
       return -1;
     }
 
+    AB_TransactionLimits_free(lim);
     return 0;
   }
 
