@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -56,7 +53,7 @@ AH_JOB *AH_Job_GetKeys_new(AB_USER *u){
   int version;
 
   assert(u);
-  j=AH_Job_new("JobGetKeys", u, 0);
+  j=AH_Job_new("JobGetKeys", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN,
               "JobGetKeys not supported, should not happen");
@@ -118,8 +115,7 @@ void GWENHYWFAR_CB GWENHYWFAR_CB AH_Job_GetKeys_FreeData(void *bp, void *p){
 
 
 /* --------------------------------------------------------------- FUNCTION */
-int AH_Job_GetKeys_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
-			   uint32_t guiid){
+int AH_Job_GetKeys_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   AH_HBCI *h;
   AH_JOB_GETKEYS *jd;
   AB_USER *u;
@@ -145,7 +141,7 @@ int AH_Job_GetKeys_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
     return rv;
   }
 
-  cctx=GWEN_Crypt_Token_GetContext(ct, AH_User_GetTokenContextId(u), guiid);
+  cctx=GWEN_Crypt_Token_GetContext(ct, AH_User_GetTokenContextId(u), 0);
   if (cctx==NULL) {
     DBG_ERROR(AQHBCI_LOGDOMAIN,
 	      "CT context %d not found",
@@ -182,7 +178,7 @@ int AH_Job_GetKeys_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
 
       DBG_DEBUG(AQHBCI_LOGDOMAIN, "Got this key response:");
       if (GWEN_Logger_GetLevel(AQHBCI_LOGDOMAIN)>=GWEN_LoggerLevel_Debug)
-        GWEN_DB_Dump(dbKeyResponse, stderr, 2);
+        GWEN_DB_Dump(dbKeyResponse, 2);
 
       p=GWEN_DB_GetBinValue(dbKeyResponse, "key/modulus", 0, 0, 0 , &bs);
       if (!p || !bs) {
@@ -353,9 +349,9 @@ AH_JOB *AH_Job_SendKeys_new(AB_USER *u,
   assert(u);
 
   if (authKeyInfo)
-    j=AH_Job_new("JobSendKeysWithAuthKey", u, 0);
+    j=AH_Job_new("JobSendKeysWithAuthKey", u, 0, 0);
   else
-    j=AH_Job_new("JobSendKeys", u, 0);
+    j=AH_Job_new("JobSendKeys", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "JobSendKeys not supported, should not happen");
     return NULL;
@@ -434,6 +430,7 @@ int AH_Job_SendKeys_PrepareKey(AH_JOB *j,
   const char *userId;
   const AB_COUNTRY *pcountry;
   int country;
+  int hbciVersion;
 
   assert(j);
   assert(dbKey);
@@ -454,6 +451,10 @@ int AH_Job_SendKeys_PrepareKey(AH_JOB *j,
   else
     country=280;
 
+  hbciVersion=AH_User_GetHbciVersion(u);
+  if (hbciVersion==0)
+    hbciVersion=220;
+
   GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
                       "keyName/country", country);
   GWEN_DB_SetCharValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
@@ -502,8 +503,18 @@ int AH_Job_SendKeys_PrepareKey(AH_JOB *j,
       GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			  "key/opmode", 2);
       break;
-    case 0:
     case 1:
+      if (hbciVersion<300)
+	/* for HBCI up until 2.20 the opmode has to be set to 16 even for crypt keys */
+	GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
+			    "key/opmode", 16);
+      else
+	/* since FinTS 3.00 the crypt key uses the value "2" (meaning CBC) */
+	GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
+			    "key/opmode", 2);
+      break;
+
+    case 0:
     default:
       GWEN_DB_SetIntValue(dbKey, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			  "key/opmode", 2);
@@ -584,7 +595,7 @@ AH_JOB *AH_Job_UpdateBank_new(AB_USER *u) {
   AH_JOB_UPDATEBANK *jd;
 
   assert(u);
-  j=AH_Job_new("JobUpdateBankInfo", u, 0);
+  j=AH_Job_new("JobUpdateBankInfo", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "JobUpdateBankInfo not supported, should not happen");
     return 0;
@@ -620,8 +631,7 @@ void GWENHYWFAR_CB AH_Job_UpdateBank_FreeData(void *bp, void *p){
 
 
 
-int AH_Job_UpdateBank_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
-			      uint32_t guiid){
+int AH_Job_UpdateBank_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_UPDATEBANK *jd;
   GWEN_DB_NODE *dbResponses;
   GWEN_DB_NODE *dbCurr;
@@ -653,36 +663,55 @@ int AH_Job_UpdateBank_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
   dbCurr=GWEN_DB_GetFirstGroup(dbResponses);
   while(dbCurr) {
     dbAccountData=GWEN_DB_GetGroup(dbCurr, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                                   "data/AccountData");
+				   "data/AccountData2");
+    if (dbAccountData==NULL)
+      dbAccountData=GWEN_DB_GetGroup(dbCurr, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
+				     "data/AccountData");
     if (dbAccountData) {
       const char *accountId;
       const char *userName;
       const char *accountName;
       const char *bankCode;
+      const char *accountSuffix;
       AB_ACCOUNT *acc;
   
-      DBG_INFO(AQHBCI_LOGDOMAIN, "Found an account");
-      accs++;
+      DBG_INFO(AQHBCI_LOGDOMAIN, "Found an account candidate");
 
       /* account data found */
       accountId=GWEN_DB_GetCharValue(dbAccountData, "accountId", 0, 0);
-      assert(accountId);
+      accountSuffix=GWEN_DB_GetCharValue(dbAccountData, "accountsubid", 0, 0);
       accountName=GWEN_DB_GetCharValue(dbAccountData, "account/name", 0, 0);
       userName=GWEN_DB_GetCharValue(dbAccountData, "name1", 0, 0);
       bankCode=GWEN_DB_GetCharValue(dbAccountData, "bankCode", 0, 0);
-      assert(bankCode);
 
-      acc=AB_Banking_CreateAccount(ab, AH_PROVIDER_NAME);
-      assert(acc);
-      AB_Account_SetBankCode(acc, bankCode);
-      AB_Account_SetAccountNumber(acc, accountId);
+      if (accountId && *accountId &&
+	  bankCode && *bankCode) {
+	acc=AB_Banking_CreateAccount(ab, AH_PROVIDER_NAME);
+	assert(acc);
+        if (strcasecmp(GWEN_DB_GroupName(dbAccountData), "AccountData2")==0)
+          /* KTV in version 2 available */
+          AH_Account_AddFlags(acc, AH_BANK_FLAGS_KTV2);
+        else
+          AH_Account_SubFlags(acc, AH_BANK_FLAGS_KTV2);
+	AB_Account_SetBankCode(acc, bankCode);
+	AB_Account_SetAccountNumber(acc, accountId);
 
-      if (accountName)
-        AB_Account_SetAccountName(acc, accountName);
-      if (userName)
-        AB_Account_SetOwnerName(acc, userName);
+	if (accountName)
+	  AB_Account_SetAccountName(acc, accountName);
+        if (accountSuffix)
+          AB_Account_SetSubAccountId(acc, accountSuffix);
+        if (userName)
+	  AB_Account_SetOwnerName(acc, userName);
 
-      AB_Account_List2_PushBack(jd->accountList, acc);
+        accs++;
+	AB_Account_List2_PushBack(jd->accountList, acc);
+      }
+      else {
+	DBG_ERROR(AQHBCI_LOGDOMAIN, "Missing information in account: BLZ=[%s], Kto=[%s], AccName=[%s]",
+		  bankCode?bankCode:"",
+		  accountId?accountId:"",
+		  accountName?accountName:"");
+      }
     }
     dbCurr=GWEN_DB_GetNextGroup(dbCurr);
   }
@@ -739,7 +768,7 @@ AH_JOB *AH_Job_GetSysId_new(AB_USER *u){
   AH_JOB_GETSYSID *jd;
 
   assert(u);
-  j=AH_Job_new("JobSync", u, 0);
+  j=AH_Job_new("JobSync", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "JobSync not supported, should not happen");
     return 0;
@@ -799,7 +828,7 @@ int AH_Job_GetSysId_ExtractSysId(AH_JOB *j){
 
   DBG_DEBUG(AQHBCI_LOGDOMAIN, "Extracting system-id from this response:");
   if (GWEN_Logger_GetLevel(AQHBCI_LOGDOMAIN)>=GWEN_LoggerLevel_Debug)
-    GWEN_DB_Dump(dbResponses, stderr, 2);
+    GWEN_DB_Dump(dbResponses, 2);
 
   /* search for "SyncResponse" */
   dbCurr=GWEN_DB_GetFirstGroup(dbResponses);
@@ -833,8 +862,7 @@ int AH_Job_GetSysId_ExtractSysId(AH_JOB *j){
 
 
 
-int AH_Job_GetSysId_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
-			    uint32_t guiid){
+int AH_Job_GetSysId_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_GETSYSID *jd;
 
   assert(j);
@@ -899,9 +927,9 @@ AH_JOB *AH_Job_TestVersion_new(AB_USER *u, int anon){
 
   assert(u);
   if (anon)
-    j=AH_Job_new("JobDialogInitAnon", u, 0);
+    j=AH_Job_new("JobDialogInitAnon", u, 0, 0);
   else
-    j=AH_Job_new("JobDialogInit", u, 0);
+    j=AH_Job_new("JobDialogInit", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN,
               "JobTestVersion not supported, should not happen");
@@ -938,8 +966,7 @@ void GWENHYWFAR_CB AH_Job_TestVersion_FreeData(void *bp, void *p){
 
 
 
-int AH_Job_TestVersion_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
-			       uint32_t guiid){
+int AH_Job_TestVersion_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_TESTVERSION *jd;
   GWEN_DB_NODE *dbResponses;
   GWEN_DB_NODE *dbCurr;
@@ -955,7 +982,7 @@ int AH_Job_TestVersion_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
 
   DBG_DEBUG(AQHBCI_LOGDOMAIN, "Parsing this response");
   if (GWEN_Logger_GetLevel(AQHBCI_LOGDOMAIN)>=GWEN_LoggerLevel_Debug)
-    GWEN_DB_Dump(dbResponses, stderr, 2);
+    GWEN_DB_Dump(dbResponses, 2);
 
   /* search for "MsgResult" */
   dbCurr=GWEN_DB_GetFirstGroup(dbResponses);
@@ -1052,7 +1079,7 @@ AH_JOB *AH_Job_GetStatus_new(AB_USER *u,
   AH_JOB_GETSTATUS *aj;
   GWEN_DB_NODE *dbArgs;
 
-  j=AH_Job_new("JobGetStatus", u, 0);
+  j=AH_Job_new("JobGetStatus", u, 0, 0);
   if (!j)
     return 0;
 
@@ -1119,8 +1146,7 @@ void GWENHYWFAR_CB AH_Job_GetStatus_FreeData(void *bp, void *p){
 
 
 
-int AH_Job_GetStatus_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
-			     uint32_t guiid){
+int AH_Job_GetStatus_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_GETSTATUS *aj;
 
   DBG_INFO(AQHBCI_LOGDOMAIN, "Processing JobGetStatus");
@@ -1137,8 +1163,7 @@ int AH_Job_GetStatus_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
 
 int AH_Job_GetStatus_Exchange(AH_JOB *j, AB_JOB *bj,
 			      AH_JOB_EXCHANGE_MODE m,
-			      AB_IMEXPORTER_CONTEXT *ctx,
-			      uint32_t guiid){
+			      AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_GETSTATUS *aj;
 
   DBG_WARN(AQHBCI_LOGDOMAIN, "Exchanging (%d), should not happen...", m);
@@ -1161,13 +1186,13 @@ int AH_Job_GetStatus_Exchange(AH_JOB *j, AB_JOB *bj,
 GWEN_INHERIT(AH_JOB, AH_JOB_TAN);
 
 
-AH_JOB *AH_Job_Tan_new(AB_USER *u, int process) {
+AH_JOB *AH_Job_Tan_new(AB_USER *u, int process, int jobVersion) {
   AH_JOB *j;
   AH_JOB_TAN *aj;
   GWEN_DB_NODE *dbArgs;
   GWEN_DB_NODE *dbParams;
 
-  j=AH_Job_new("JobTan", u, 0);
+  j=AH_Job_new("JobTan", u, 0, jobVersion);
   if (!j)
     return 0;
 
@@ -1198,6 +1223,7 @@ void GWENHYWFAR_CB AH_Job_Tan_FreeData(void *bp, void *p){
   AH_JOB_TAN *aj;
 
   aj=(AH_JOB_TAN*)p;
+  free(aj->tanMediumId);
   free(aj->reference);
   free(aj->challenge);
   GWEN_FREE_OBJECT(aj);
@@ -1205,8 +1231,7 @@ void GWENHYWFAR_CB AH_Job_Tan_FreeData(void *bp, void *p){
 
 
 
-int AH_Job_Tan_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
-		       uint32_t guiid){
+int AH_Job_Tan_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_TAN *aj;
   GWEN_DB_NODE *dbResponses;
   GWEN_DB_NODE *dbCurr;
@@ -1245,7 +1270,7 @@ int AH_Job_Tan_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
 
       DBG_NOTICE(AQHBCI_LOGDOMAIN, "Got a TAN response");
       if (GWEN_Logger_GetLevel(0)>=GWEN_LoggerLevel_Debug)
-        GWEN_DB_Dump(dbTanResponse, stderr, 2);
+        GWEN_DB_Dump(dbTanResponse, 2);
 
       s=GWEN_DB_GetCharValue(dbTanResponse, "challenge", 0, 0);
       if (s) {
@@ -1295,8 +1320,7 @@ void AH_Job_Tan_SetTanMethod(AH_JOB *j, int i) {
 
 int AH_Job_Tan_Exchange(AH_JOB *j, AB_JOB *bj,
 			AH_JOB_EXCHANGE_MODE m,
-			AB_IMEXPORTER_CONTEXT *ctx,
-			uint32_t guiid){
+			AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_TAN *aj;
 
   DBG_WARN(AQHBCI_LOGDOMAIN, "Exchanging (%d)", m);
@@ -1416,6 +1440,26 @@ const char *AH_Job_Tan_GetReference(const AH_JOB *j) {
 
 
 
+void AH_Job_Tan_SetTanMediumId(AH_JOB *j, const char *s) {
+  AH_JOB_TAN *aj;
+  GWEN_DB_NODE *dbArgs;
+
+  assert(j);
+  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_TAN, j);
+  assert(aj);
+
+  dbArgs=AH_Job_GetArguments(j);
+  assert(dbArgs);
+
+  if (s)
+    GWEN_DB_SetCharValue(dbArgs, GWEN_DB_FLAGS_OVERWRITE_VARS,
+			 "tanMediumId", s);
+  else
+    GWEN_DB_DeleteVar(dbArgs, "tanMediumId");
+}
+
+
+
 int AH_Job_Tan_FinishSetup(AH_JOB *j) {
   AH_JOB_TAN *aj;
   GWEN_DB_NODE *args;
@@ -1528,7 +1572,7 @@ AH_JOB *AH_Job_GetItanModes_new(AB_USER *u){
   AH_JOB_GETITANMODES *jd;
 
   assert(u);
-  j=AH_Job_new("JobGetItanModes", u, 0);
+  j=AH_Job_new("JobGetItanModes", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN,
               "JobGetItanModes not supported, should not happen");
@@ -1565,8 +1609,7 @@ void GWENHYWFAR_CB AH_Job_GetItanModes_FreeData(void *bp, void *p){
 
 
 
-int AH_Job_GetItanModes_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
-				uint32_t guiid){
+int AH_Job_GetItanModes_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_GETITANMODES *jd;
   GWEN_DB_NODE *dbResponses;
   GWEN_DB_NODE *dbCurr;
@@ -1581,7 +1624,7 @@ int AH_Job_GetItanModes_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx,
 
   DBG_DEBUG(AQHBCI_LOGDOMAIN, "Parsing this response");
   if (GWEN_Logger_GetLevel(AQHBCI_LOGDOMAIN)>=GWEN_LoggerLevel_Debug)
-    GWEN_DB_Dump(dbResponses, stderr, 2);
+    GWEN_DB_Dump(dbResponses, 2);
 
   /* search for "SegResult" */
   dbCurr=GWEN_DB_GetFirstGroup(dbResponses);
@@ -1661,7 +1704,7 @@ AH_JOB *AH_Job_ChangePin_new(AB_USER *u, const char *newPin){
   GWEN_DB_NODE *dbArgs;
 
   assert(u);
-  j=AH_Job_new("JobChangePin", u, 0);
+  j=AH_Job_new("JobChangePin", u, 0, 0);
   if (!j) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "JobChangePin not supported, should not happen");
     return 0;
