@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -418,7 +415,7 @@ GWEN_TIME *AH_Outbox__CBox_GetLatestPendingDate(AH_OUTBOX__CBOX *cbox) {
 
 
 
-int AH_Outbox__CBox_Prepare(AH_OUTBOX__CBOX *cbox, uint32_t guiid){
+int AH_Outbox__CBox_Prepare(AH_OUTBOX__CBOX *cbox){
   AH_JOB *j;
   unsigned int errors;
   AH_JOBQUEUE *jq;
@@ -437,7 +434,7 @@ int AH_Outbox__CBox_Prepare(AH_OUTBOX__CBOX *cbox, uint32_t guiid){
     next=AH_Job_List_Next(j);
     st=AH_Job_GetStatus(j);
     if (st==AH_JobStatusToDo) {
-      int rv=AH_Job_Prepare(j, guiid);
+      int rv=AH_Job_Prepare(j);
       if (rv<0 && rv!=GWEN_ERROR_NOT_SUPPORTED) {
 	DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
 	AH_Job_SetStatus(j, AH_JobStatusError);
@@ -687,34 +684,33 @@ int AH_Outbox__CBox_Prepare(AH_OUTBOX__CBOX *cbox, uint32_t guiid){
 
 
 
-int AH_Outbox__CBox_SendQueue(AH_OUTBOX__CBOX *cbox, int timeout,
+int AH_Outbox__CBox_SendQueue(AH_OUTBOX__CBOX *cbox,
 			      AH_DIALOG *dlg,
-			      AH_JOBQUEUE *jq,
-			      uint32_t guiid){
+			      AH_JOBQUEUE *jq){
   AH_MSG *msg;
   int rv;
 
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Encoding queue");
-  GWEN_Gui_ProgressLog(guiid,
+  GWEN_Gui_ProgressLog(0,
 		       GWEN_LoggerLevel_Info,
 		       I18N("Encoding queue"));
   msg=AH_JobQueue_ToMessage(jq, dlg);
   if (!msg) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Could not encode queue");
-    GWEN_Gui_ProgressLog(guiid,
+    GWEN_Gui_ProgressLog(0,
 			 GWEN_LoggerLevel_Error,
 			 I18N("Unable to encode"));
     return GWEN_ERROR_GENERIC;
   }
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Sending queue");
-  GWEN_Gui_ProgressLog(guiid,
+  GWEN_Gui_ProgressLog(0,
 		       GWEN_LoggerLevel_Info,
 		       I18N("Sending queue"));
 
   rv=AH_Dialog_SendMessage(dlg, msg);
   if (rv) {
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Could not send message");
-    GWEN_Gui_ProgressLog(guiid,
+    GWEN_Gui_ProgressLog(0,
 			 GWEN_LoggerLevel_Error,
 			 I18N("Unable to send (network error)"));
     return rv;
@@ -726,17 +722,15 @@ int AH_Outbox__CBox_SendQueue(AH_OUTBOX__CBOX *cbox, int timeout,
 
 
 int AH_Outbox__CBox_RecvQueue(AH_OUTBOX__CBOX *cbox,
-			      int timeout,
 			      AH_DIALOG *dlg,
-			      AH_JOBQUEUE *jq,
-			      uint32_t guiid){
+			      AH_JOBQUEUE *jq){
   AH_MSG *msg;
   GWEN_DB_NODE *rsp;
   int rv;
 
   assert(cbox);
 
-  GWEN_Gui_ProgressLog(guiid,
+  GWEN_Gui_ProgressLog(0,
 		       GWEN_LoggerLevel_Info,
 		       I18N("Waiting for response"));
 
@@ -744,14 +738,14 @@ int AH_Outbox__CBox_RecvQueue(AH_OUTBOX__CBOX *cbox,
   if (rv<0) {
     DBG_INFO(AQHBCI_LOGDOMAIN,
 	     "No message within specified timeout, giving up");
-    GWEN_Gui_ProgressLog(guiid,
+    GWEN_Gui_ProgressLog(0,
 			 GWEN_LoggerLevel_Error,
 			 I18N("No response (timeout)"));
-    return AB_ERROR_NETWORK;
+    return rv;
   }
 
   DBG_INFO(AQHBCI_LOGDOMAIN, "Got a message");
-  GWEN_Gui_ProgressLog(guiid,
+  GWEN_Gui_ProgressLog(0,
 		       GWEN_LoggerLevel_Info,
 		       I18N("Response received"));
 
@@ -759,9 +753,9 @@ int AH_Outbox__CBox_RecvQueue(AH_OUTBOX__CBOX *cbox,
   rsp=GWEN_DB_Group_new("response");
   if (AH_Msg_DecodeMsg(msg, rsp, GWEN_MSGENGINE_READ_FLAGS_DEFAULT)) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not decode this message:");
-    AH_Msg_Dump(msg, stderr, 2);
+    AH_Msg_Dump(msg, 2);
     GWEN_DB_Group_free(rsp);
-    GWEN_Gui_ProgressLog(guiid,
+    GWEN_Gui_ProgressLog(0,
 			 GWEN_LoggerLevel_Error,
 			 I18N("Bad response (unable to decode)"));
     return GWEN_ERROR_GENERIC;
@@ -773,11 +767,11 @@ int AH_Outbox__CBox_RecvQueue(AH_OUTBOX__CBOX *cbox,
   /* check for message reference */
   if (AH_Msg_GetMsgRef(msg)==0) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Unrequested message, deleting it");
-    AH_Msg_Dump(msg, stderr, 2);
-    GWEN_DB_Dump(rsp, stderr, 2);
+    AH_Msg_Dump(msg, 2);
+    GWEN_DB_Dump(rsp, 2);
     GWEN_DB_Group_free(rsp);
     AH_Msg_free(msg);
-    GWEN_Gui_ProgressLog(guiid,
+    GWEN_Gui_ProgressLog(0,
 			 GWEN_LoggerLevel_Error,
 			 I18N("Bad response (bad message reference)"));
     return GWEN_ERROR_GENERIC;
@@ -787,13 +781,13 @@ int AH_Outbox__CBox_RecvQueue(AH_OUTBOX__CBOX *cbox,
   if (rv) {
     if (rv==GWEN_ERROR_ABORTED) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Dialog aborted by server");
-      GWEN_Gui_ProgressLog(guiid,
+      GWEN_Gui_ProgressLog(0,
 			   GWEN_LoggerLevel_Error,
 			   I18N("Dialog aborted by server"));
     }
     else {
       DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not dispatch response");
-      GWEN_Gui_ProgressLog(guiid,
+      GWEN_Gui_ProgressLog(0,
 			   GWEN_LoggerLevel_Error,
 			   I18N("Bad response (unable to dispatch)"));
     }
@@ -811,17 +805,15 @@ int AH_Outbox__CBox_RecvQueue(AH_OUTBOX__CBOX *cbox,
 
 
 int AH_Outbox__CBox_SendAndRecvQueue(AH_OUTBOX__CBOX *cbox,
-				     int timeout,
 				     AH_DIALOG *dlg,
-				     AH_JOBQUEUE *jq,
-				     uint32_t guiid){
+				     AH_JOBQUEUE *jq){
   int rv;
 
   if ((AH_JobQueue_GetFlags(jq) & AH_JOBQUEUE_FLAGS_NEEDTAN) &&
       AH_Dialog_GetItanProcessType(dlg)!=0) {
     DBG_DEBUG(AQHBCI_LOGDOMAIN, "iTAN mode");
 
-    rv=AH_Outbox__CBox_Itan(cbox, dlg, jq, timeout, guiid);
+    rv=AH_Outbox__CBox_Itan(cbox, dlg, jq);
     if (rv) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
       return rv;
@@ -829,7 +821,7 @@ int AH_Outbox__CBox_SendAndRecvQueue(AH_OUTBOX__CBOX *cbox,
   }
   else {
     DBG_DEBUG(AQHBCI_LOGDOMAIN, "Normal mode");
-    rv=AH_Outbox__CBox_SendQueue(cbox, timeout, dlg, jq, guiid);
+    rv=AH_Outbox__CBox_SendQueue(cbox, dlg, jq);
     if (rv) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Error sending queue");
       return rv;
@@ -838,7 +830,7 @@ int AH_Outbox__CBox_SendAndRecvQueue(AH_OUTBOX__CBOX *cbox,
     AH_JobQueue_SetJobStatusOnMatch(jq, AH_JobStatusEncoded,
                                     AH_JobStatusSent);
 
-    rv=AH_Outbox__CBox_RecvQueue(cbox, timeout, dlg, jq, guiid);
+    rv=AH_Outbox__CBox_RecvQueue(cbox, dlg, jq);
     if (rv) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Error receiving queue response");
       return rv;
@@ -851,10 +843,9 @@ int AH_Outbox__CBox_SendAndRecvQueue(AH_OUTBOX__CBOX *cbox,
 
 
 
-int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
+int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox,
 			       AH_DIALOG *dlg,
-			       uint32_t jqFlags,
-			       uint32_t guiid) {
+			       uint32_t jqFlags) {
   AH_JOBQUEUE *jqDlgOpen;
   AH_JOB *jDlgOpen;
   int rv;
@@ -867,7 +858,7 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
     /* sign and crypt, not anonymous */
     DBG_NOTICE(AQHBCI_LOGDOMAIN,
                "Creating non-anonymous dialog open request");
-    jDlgOpen=AH_Job_new("JobDialogInit", cbox->user, 0);
+    jDlgOpen=AH_Job_new("JobDialogInit", cbox->user, 0, 0);
     if (!jDlgOpen) {
       DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not create job JobDialogInit");
       return GWEN_ERROR_GENERIC;
@@ -894,7 +885,7 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
   else {
     /* neither sign nor crypt, use anonymous dialog */
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Creating anonymous dialog open request");
-    jDlgOpen=AH_Job_new("JobDialogInitAnon", cbox->user, 0);
+    jDlgOpen=AH_Job_new("JobDialogInitAnon", cbox->user, 0, 0);
     if (!jDlgOpen) {
       DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not create job JobDialogInitAnon");
       return GWEN_ERROR_GENERIC;
@@ -902,7 +893,7 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
     AH_Dialog_AddFlags(dlg, AH_DIALOG_FLAGS_ANONYMOUS);
   }
 
-  GWEN_Gui_ProgressLog(guiid,
+  GWEN_Gui_ProgressLog(0,
 		       GWEN_LoggerLevel_Notice,
 		       I18N("Opening dialog"));
   jqDlgOpen=AH_JobQueue_new(cbox->user);
@@ -916,7 +907,7 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
     return GWEN_ERROR_GENERIC;
   }
 
-  rv=AH_Outbox__CBox_SendAndRecvQueue(cbox, timeout, dlg, jqDlgOpen, guiid);
+  rv=AH_Outbox__CBox_SendAndRecvQueue(cbox, dlg, jqDlgOpen);
   if (rv) {
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Could not exchange message");
     AH_JobQueue_free(jqDlgOpen);
@@ -927,12 +918,12 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
     if (AH_Job_HasItanResult(jDlgOpen)) {
       DBG_NOTICE(AQHBCI_LOGDOMAIN,
 		 "Adjusting to iTAN modes of the server");
-      GWEN_Gui_ProgressLog(guiid,
+      GWEN_Gui_ProgressLog(0,
 			   GWEN_LoggerLevel_Notice,
 			   I18N("Adjusting to iTAN modes of the server"));
       /* do not call AH_Job_CommitSystemData() here, the iTAN modes have already
        * been caught by AH_JobQueue_DispatchMessage()
-        AH_Job_CommitSystemData(jDlgOpen, guiid); */
+        AH_Job_CommitSystemData(jDlgOpen); */
       AH_JobQueue_free(jqDlgOpen);
       return 1;
     }
@@ -943,7 +934,7 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
     }
   }
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Dialog open request done");
-  rv=AH_Job_CommitSystemData(jDlgOpen, 0, guiid);
+  rv=AH_Job_CommitSystemData(jDlgOpen, 0);
   AH_JobQueue_free(jqDlgOpen);
   return rv;
 }
@@ -951,23 +942,21 @@ int AH_Outbox__CBox_OpenDialog(AH_OUTBOX__CBOX *cbox, int timeout,
 
 
 int AH_Outbox__CBox_CloseDialog(AH_OUTBOX__CBOX *cbox,
-				int timeout,
 				AH_DIALOG *dlg,
-				uint32_t jqFlags,
-				uint32_t guiid) {
+				uint32_t jqFlags) {
   AH_JOBQUEUE *jqDlgClose;
   AH_JOB *jDlgClose;
   GWEN_DB_NODE *db;
   uint32_t dlgFlags;
   int rv;
 
-  GWEN_Gui_ProgressLog(guiid,
+  GWEN_Gui_ProgressLog(0,
 		       GWEN_LoggerLevel_Notice,
 		       I18N("Closing dialog"));
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Sending dialog close request (flags=%08x)",
 	     jqFlags);
   dlgFlags=AH_Dialog_GetFlags(dlg);
-  jDlgClose=AH_Job_new("JobDialogEnd", cbox->user, 0);
+  jDlgClose=AH_Job_new("JobDialogEnd", cbox->user, 0, 0);
   if (!jDlgClose) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not create job JobDialogEnd");
     return GWEN_ERROR_GENERIC;
@@ -999,14 +988,14 @@ int AH_Outbox__CBox_CloseDialog(AH_OUTBOX__CBOX *cbox,
     return GWEN_ERROR_GENERIC;
   }
 
-  rv=AH_Outbox__CBox_SendAndRecvQueue(cbox, timeout, dlg, jqDlgClose, guiid);
+  rv=AH_Outbox__CBox_SendAndRecvQueue(cbox, dlg, jqDlgClose);
   if (rv) {
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Could not exchange message");
     AH_JobQueue_free(jqDlgClose);
     return rv;
   }
   DBG_NOTICE(AQHBCI_LOGDOMAIN, "Dialog closed");
-  rv=AH_Job_CommitSystemData(jDlgClose, 0, guiid);
+  rv=AH_Job_CommitSystemData(jDlgClose, 0);
   AH_JobQueue_free(jqDlgClose);
   if (rv) {
     DBG_NOTICE(AQHBCI_LOGDOMAIN, "Could not commit system data");
@@ -1045,9 +1034,7 @@ void AH_Outbox__CBox_HandleQueueError(AH_OUTBOX__CBOX *cbox,
 
 int AH_Outbox__CBox_PerformQueue(AH_OUTBOX__CBOX *cbox,
 				 AH_DIALOG *dlg,
-				 AH_JOBQUEUE *jq,
-				 int timeout,
-				 uint32_t guiid) {
+				 AH_JOBQUEUE *jq) {
   int jobsTodo;
   int rv;
 
@@ -1142,7 +1129,7 @@ int AH_Outbox__CBox_PerformQueue(AH_OUTBOX__CBOX *cbox,
       break;
 
     /* jq now contains all jobs to be executed */
-    rv=AH_Outbox__CBox_SendAndRecvQueue(cbox, timeout, dlg, jq, guiid);
+    rv=AH_Outbox__CBox_SendAndRecvQueue(cbox, dlg, jq);
     if (rv) {
       AH_Outbox__CBox_HandleQueueError(cbox, jq,
                                        "Error performing queue");
@@ -1157,9 +1144,7 @@ int AH_Outbox__CBox_PerformQueue(AH_OUTBOX__CBOX *cbox,
 
 
 int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
-					   int timeout,
-					   AH_JOBQUEUE_LIST *jql,
-					   uint32_t guiid){
+					   AH_JOBQUEUE_LIST *jql){
   AH_DIALOG *dlg;
   AH_JOBQUEUE *jq;
   int rv=0;
@@ -1173,8 +1158,8 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
   }
 
   for(i=0; i<2; i++) {
-    dlg=AH_Dialog_new(cbox->user, guiid);
-    rv=AH_Dialog_Connect(dlg, AH_HBCI_GetConnectTimeout(cbox->hbci));
+    dlg=AH_Dialog_new(cbox->user);
+    rv=AH_Dialog_Connect(dlg);
     if (rv) {
       DBG_INFO(AQHBCI_LOGDOMAIN,
 	       "Could not begin a dialog for customer \"%s\" (%d)",
@@ -1191,12 +1176,12 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
     jqflags=AH_JobQueue_GetFlags(jq);
   
     /* open dialog */
-    rv=AH_Outbox__CBox_OpenDialog(cbox, timeout, dlg, jqflags, guiid);
+    rv=AH_Outbox__CBox_OpenDialog(cbox, dlg, jqflags);
     if (rv==0)
       break;
     else if (rv<0) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Could not open dialog");
-      AH_Dialog_Disconnect(dlg, 2);
+      AH_Dialog_Disconnect(dlg);
       /* finish all queues */
       AH_Outbox__CBox_HandleQueueListError(cbox, jql,
 					   "Could not open dialog");
@@ -1204,16 +1189,15 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
       return rv;
     }
     else if (rv==1) {
-      AH_Dialog_Disconnect(dlg, 2);
-      GWEN_Gui_ProgressLog(
-			     0,
-			     GWEN_LoggerLevel_Info,
-			     I18N("Retrying to open dialog"));
+      AH_Dialog_Disconnect(dlg);
+      GWEN_Gui_ProgressLog(0,
+			   GWEN_LoggerLevel_Info,
+			   I18N("Retrying to open dialog"));
     }
   }
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Could not open dialog");
-    AH_Dialog_Disconnect(dlg, 2);
+    AH_Dialog_Disconnect(dlg);
     /* finish all queues */
     AH_Outbox__CBox_HandleQueueListError(cbox, jql,
 					 "Could not open dialog");
@@ -1225,7 +1209,7 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
   rv=0;
   while((jq=AH_JobQueue_List_First(jql))) {
     AH_JobQueue_List_Del(jq);
-    rv=AH_Outbox__CBox_PerformQueue(cbox, dlg, jq, timeout, guiid);
+    rv=AH_Outbox__CBox_PerformQueue(cbox, dlg, jq);
     if (rv)
       break;
   } /* while */
@@ -1234,13 +1218,13 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
     /* finish all remaining queues */
     AH_Outbox__CBox_HandleQueueListError(cbox, jql,
                                          "Could not send ");
-    AH_Dialog_Disconnect(dlg, 2);
+    AH_Dialog_Disconnect(dlg);
     AH_Dialog_free(dlg);
     return rv;
   }
 
   /* close dialog */
-  rv=AH_Outbox__CBox_CloseDialog(cbox, timeout, dlg, jqflags, guiid);
+  rv=AH_Outbox__CBox_CloseDialog(cbox, dlg, jqflags);
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN,
              "Could not close dialog, ignoring");
@@ -1249,7 +1233,7 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
   }
 
   DBG_INFO(AQHBCI_LOGDOMAIN, "Closing connection");
-  AH_Dialog_Disconnect(dlg, 2);
+  AH_Dialog_Disconnect(dlg);
   AH_Dialog_free(dlg);
 
   AH_JobQueue_List_free(jql);
@@ -1259,15 +1243,13 @@ int AH_Outbox__CBox_PerformNonDialogQueues(AH_OUTBOX__CBOX *cbox,
 
 
 int AH_Outbox__CBox_PerformDialogQueue(AH_OUTBOX__CBOX *cbox,
-				       int timeout,
-				       AH_JOBQUEUE *jq,
-				       uint32_t guiid){
+				       AH_JOBQUEUE *jq){
   AH_DIALOG *dlg;
   int rv;
 
   /* open connection */
-  dlg=AH_Dialog_new(cbox->user, guiid);
-  rv=AH_Dialog_Connect(dlg, AH_HBCI_GetConnectTimeout(cbox->hbci));
+  dlg=AH_Dialog_new(cbox->user);
+  rv=AH_Dialog_Connect(dlg);
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN,
              "Could not begin a dialog for customer \"%s\" (%d)",
@@ -1284,23 +1266,23 @@ int AH_Outbox__CBox_PerformDialogQueue(AH_OUTBOX__CBOX *cbox,
   if (!(AH_JobQueue_GetFlags(jq) & AH_JOBQUEUE_FLAGS_NOITAN)) {
     rv=AH_Outbox__CBox_SelectItanMode(cbox, dlg);
     if (rv) {
-      AH_Dialog_Disconnect(dlg, 2);
+      AH_Dialog_Disconnect(dlg);
       AH_Dialog_free(dlg);
       return rv;
     }
   }
 
   /* handle queue */
-  rv=AH_Outbox__CBox_PerformQueue(cbox, dlg, jq, timeout, guiid);
+  rv=AH_Outbox__CBox_PerformQueue(cbox, dlg, jq);
   if (rv) {
-    AH_Dialog_Disconnect(dlg, 2);
+    AH_Dialog_Disconnect(dlg);
     AH_Dialog_free(dlg);
     return rv;
   }
 
   /* close connection */
   DBG_INFO(AQHBCI_LOGDOMAIN, "Closing connection");
-  AH_Dialog_Disconnect(dlg, 2);
+  AH_Dialog_Disconnect(dlg);
   AH_Dialog_free(dlg);
 
   return 0;
@@ -1344,9 +1326,7 @@ void AH_Outbox__CBox_HandleQueueListError(AH_OUTBOX__CBOX *cbox,
 
 
 
-int AH_Outbox__CBox_SendAndRecvDialogQueues(AH_OUTBOX__CBOX *cbox,
-					    int timeout,
-					    uint32_t guiid) {
+int AH_Outbox__CBox_SendAndRecvDialogQueues(AH_OUTBOX__CBOX *cbox) {
   AH_JOBQUEUE_LIST *jqlWanted;
   AH_JOBQUEUE_LIST *jqlRest;
   int rv;
@@ -1365,7 +1345,7 @@ int AH_Outbox__CBox_SendAndRecvDialogQueues(AH_OUTBOX__CBOX *cbox,
 
     /* there are matching queues, handle them */
     while((jq=AH_JobQueue_List_First(jqlWanted))) {
-      rv=AH_Outbox__CBox_PerformDialogQueue(cbox, timeout, jq, guiid);
+      rv=AH_Outbox__CBox_PerformDialogQueue(cbox, jq);
       if (rv) {
 	DBG_INFO(AQHBCI_LOGDOMAIN,
 		 "Error performing queue (%d)", rv);
@@ -1387,10 +1367,8 @@ int AH_Outbox__CBox_SendAndRecvDialogQueues(AH_OUTBOX__CBOX *cbox,
 
 
 int AH_Outbox__CBox_SendAndRecvSelected(AH_OUTBOX__CBOX *cbox,
-					int timeout,
 					uint32_t jqflags,
-					uint32_t jqmask,
-					uint32_t guiid){
+					uint32_t jqmask){
   AH_JOBQUEUE_LIST *jqlWanted;
   AH_JOBQUEUE_LIST *jqlRest;
   int rv;
@@ -1404,7 +1382,7 @@ int AH_Outbox__CBox_SendAndRecvSelected(AH_OUTBOX__CBOX *cbox,
   cbox->todoQueues=jqlRest;
   if (AH_JobQueue_List_GetCount(jqlWanted)) {
     /* there are matching queues, handle them */
-    rv=AH_Outbox__CBox_PerformNonDialogQueues(cbox, timeout, jqlWanted, guiid);
+    rv=AH_Outbox__CBox_PerformNonDialogQueues(cbox, jqlWanted);
     if (rv) {
       DBG_ERROR(AQHBCI_LOGDOMAIN,
 		"Error performing queue (%d)", rv);
@@ -1422,60 +1400,56 @@ int AH_Outbox__CBox_SendAndRecvSelected(AH_OUTBOX__CBOX *cbox,
 
 
 
-int AH_Outbox__CBox_SendAndRecvBox(AH_OUTBOX__CBOX *cbox, int timeout, uint32_t guiid){
+int AH_Outbox__CBox_SendAndRecvBox(AH_OUTBOX__CBOX *cbox){
   int rv;
 
   /* dialog queues */
-  rv=AH_Outbox__CBox_SendAndRecvDialogQueues(cbox, timeout, guiid);
+  rv=AH_Outbox__CBox_SendAndRecvDialogQueues(cbox);
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Error performing dialog queues (%d)", rv);
     return rv;
   }
 
   /* non-dialog queues: unsigned, uncrypted */
-  rv=AH_Outbox__CBox_SendAndRecvSelected(cbox, timeout,
+  rv=AH_Outbox__CBox_SendAndRecvSelected(cbox,
 					 0,
 					 AH_JOBQUEUE_FLAGS_ISDIALOG |
 					 AH_JOBQUEUE_FLAGS_SIGN |
-					 AH_JOBQUEUE_FLAGS_CRYPT,
-					 guiid);
+					 AH_JOBQUEUE_FLAGS_CRYPT);
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Error performing queues (-S, -C: %d)", rv);
     return rv;
   }
 
   /* non-dialog queues: unsigned, crypted */
-  rv=AH_Outbox__CBox_SendAndRecvSelected(cbox, timeout,
+  rv=AH_Outbox__CBox_SendAndRecvSelected(cbox,
 					 AH_JOBQUEUE_FLAGS_CRYPT,
 					 AH_JOBQUEUE_FLAGS_ISDIALOG |
 					 AH_JOBQUEUE_FLAGS_SIGN |
-					 AH_JOBQUEUE_FLAGS_CRYPT,
-					 guiid);
+					 AH_JOBQUEUE_FLAGS_CRYPT);
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Error performing queues (-S, +C: %d)", rv);
     return rv;
   }
 
   /* non-dialog queues: signed, uncrypted */
-  rv=AH_Outbox__CBox_SendAndRecvSelected(cbox, timeout,
+  rv=AH_Outbox__CBox_SendAndRecvSelected(cbox,
 					 AH_JOBQUEUE_FLAGS_SIGN,
 					 AH_JOBQUEUE_FLAGS_ISDIALOG |
 					 AH_JOBQUEUE_FLAGS_SIGN |
-					 AH_JOBQUEUE_FLAGS_CRYPT,
-					 guiid);
+					 AH_JOBQUEUE_FLAGS_CRYPT);
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Error performing queues (+S, -C: %d)", rv);
     return rv;
   }
 
   /* non-dialog queues: signed, crypted */
-  rv=AH_Outbox__CBox_SendAndRecvSelected(cbox, timeout,
+  rv=AH_Outbox__CBox_SendAndRecvSelected(cbox,
 					 AH_JOBQUEUE_FLAGS_SIGN |
 					 AH_JOBQUEUE_FLAGS_CRYPT,
 					 AH_JOBQUEUE_FLAGS_ISDIALOG |
 					 AH_JOBQUEUE_FLAGS_SIGN |
-					 AH_JOBQUEUE_FLAGS_CRYPT,
-					 guiid);
+					 AH_JOBQUEUE_FLAGS_CRYPT);
   if (rv) {
     DBG_INFO(AQHBCI_LOGDOMAIN, "Error performing queues (+S, +C: %d)", rv);
     return rv;
@@ -1503,7 +1477,7 @@ int AH_Outbox__CBox_SendAndRecvBox(AH_OUTBOX__CBOX *cbox, int timeout, uint32_t
 
 
 
-AH_OUTBOX *AH_Outbox_new(AH_HBCI *hbci, uint32_t guiid) {
+AH_OUTBOX *AH_Outbox_new(AH_HBCI *hbci) {
   AH_OUTBOX *ob;
 
   assert(hbci);
@@ -1542,7 +1516,7 @@ void AH_Outbox_Attach(AH_OUTBOX *ob){
 
 
 
-int AH_Outbox_Prepare(AH_OUTBOX *ob, uint32_t guiid){
+int AH_Outbox_Prepare(AH_OUTBOX *ob){
   AH_OUTBOX__CBOX *cbox;
   unsigned int errors;
 
@@ -1556,7 +1530,7 @@ int AH_Outbox_Prepare(AH_OUTBOX *ob, uint32_t guiid){
     u=AH_Outbox__CBox_GetUser(cbox);
     DBG_INFO(AQHBCI_LOGDOMAIN, "Preparing queues for customer \"%s\"",
              AB_User_GetCustomerId(u));
-    if (AH_Outbox__CBox_Prepare(cbox, guiid)) {
+    if (AH_Outbox__CBox_Prepare(cbox)) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "Error preparing cbox");
       errors++;
     }
@@ -1577,7 +1551,7 @@ int AH_Outbox_Prepare(AH_OUTBOX *ob, uint32_t guiid){
 
 
 
-int AH_Outbox_LockUsers(AH_OUTBOX *ob, AB_USER_LIST2 *lockedUsers, uint32_t guiid){
+int AH_Outbox_LockUsers(AH_OUTBOX *ob, AB_USER_LIST2 *lockedUsers){
   AH_OUTBOX__CBOX *cbox;
   AB_BANKING *ab;
 
@@ -1596,10 +1570,10 @@ int AH_Outbox_LockUsers(AH_OUTBOX *ob, AB_USER_LIST2 *lockedUsers, uint32_t guii
 	     I18N("Locking user %s"),
 	     AB_User_GetUserId(cbox->user));
     tbuf[sizeof(tbuf)-1]=0;
-    GWEN_Gui_ProgressLog(guiid,
+    GWEN_Gui_ProgressLog(0,
 			 GWEN_LoggerLevel_Info,
 			 tbuf);
-    rv=AB_Banking_BeginExclUseUser(ab, cbox->user, guiid);
+    rv=AB_Banking_BeginExclUseUser(ab, cbox->user);
     if (rv<0) {
       DBG_INFO(AQHBCI_LOGDOMAIN,
 	       "Could not lock customer [%s] (%d)",
@@ -1608,10 +1582,10 @@ int AH_Outbox_LockUsers(AH_OUTBOX *ob, AB_USER_LIST2 *lockedUsers, uint32_t guii
 	       I18N("Could not lock user %s (%d)"),
 	       AB_User_GetUserId(cbox->user), rv);
       tbuf[sizeof(tbuf)-1]=0;
-      GWEN_Gui_ProgressLog(guiid,
+      GWEN_Gui_ProgressLog(0,
 			   GWEN_LoggerLevel_Error,
 			   tbuf);
-      AH_Outbox_UnlockUsers(ob, lockedUsers, 1, guiid); /* abandon */
+      AH_Outbox_UnlockUsers(ob, lockedUsers, 1); /* abandon */
       return rv;
     }
     cbox->isLocked=1;
@@ -1626,7 +1600,7 @@ int AH_Outbox_LockUsers(AH_OUTBOX *ob, AB_USER_LIST2 *lockedUsers, uint32_t guii
 
 
 int AH_Outbox_UnlockUsers(AH_OUTBOX *ob, AB_USER_LIST2 *lockedUsers,
-			  int abandon, uint32_t guiid){
+			  int abandon){
   int errors=0;
   AB_BANKING *ab;
   AB_USER_LIST2_ITERATOR *it;
@@ -1644,7 +1618,7 @@ int AH_Outbox_UnlockUsers(AH_OUTBOX *ob, AB_USER_LIST2 *lockedUsers,
 
       DBG_INFO(AQHBCI_LOGDOMAIN, "Unlocking customer \"%s\"",
 	       AB_User_GetCustomerId(u));
-      rv=AB_Banking_EndExclUseUser(ab, u, abandon, guiid);
+      rv=AB_Banking_EndExclUseUser(ab, u, abandon);
       if (rv<0) {
 	DBG_WARN(AQHBCI_LOGDOMAIN,
 		 "Could not unlock customer [%s] (%d)",
@@ -1752,13 +1726,13 @@ void AH_Outbox_AddPendingJob(AH_OUTBOX *ob, AB_JOB *bj){
 
 
 
-int AH_Outbox_StartSending(AH_OUTBOX *ob, uint32_t guiid) {
-  return AH_Outbox_Prepare(ob, guiid);
+int AH_Outbox_StartSending(AH_OUTBOX *ob) {
+  return AH_Outbox_Prepare(ob);
 }
 
 
 
-void AH_Outbox__FinishCBox(AH_OUTBOX *ob, AH_OUTBOX__CBOX *cbox, uint32_t guiid){
+void AH_Outbox__FinishCBox(AH_OUTBOX *ob, AH_OUTBOX__CBOX *cbox){
   AH_JOB_LIST *jl;
   AH_JOB *j;
 
@@ -1775,7 +1749,7 @@ void AH_Outbox__FinishCBox(AH_OUTBOX *ob, AH_OUTBOX__CBOX *cbox, uint32_t guiid)
     AH_Job_List_Del(j);
     st=AH_Job_GetStatus(j);
     if (st==AH_JobStatusAnswered) {
-      rv=AH_Job_Process(j, ob->context, guiid);
+      rv=AH_Job_Process(j, ob->context);
       if (rv) {
         char buf[256];
 
@@ -1789,7 +1763,7 @@ void AH_Outbox__FinishCBox(AH_OUTBOX *ob, AH_OUTBOX__CBOX *cbox, uint32_t guiid)
                  AH_Job_GetName(j));
 	AH_Job_SetStatus(j, AH_JobStatusError);
 
-        GWEN_Gui_ProgressLog(guiid,
+        GWEN_Gui_ProgressLog(0,
 			     GWEN_LoggerLevel_Error,
 			     buf);
       }
@@ -1808,22 +1782,17 @@ void AH_Outbox__FinishCBox(AH_OUTBOX *ob, AH_OUTBOX__CBOX *cbox, uint32_t guiid)
   if (cbox->isLocked) {
     if (cbox->isLocked) {
       int rv;
-      char tbuf[256];
 
-      snprintf(tbuf, sizeof(tbuf)-1,
-	       I18N("Unlocking user %s"),
-	       AB_User_GetUserId(cbox->user));
-      tbuf[sizeof(tbuf)-1]=0;
-      GWEN_Gui_ProgressLog(guiid,
-			   GWEN_LoggerLevel_Info,
-                           tbuf);
+      GWEN_Gui_ProgressLog2(0,
+			    GWEN_LoggerLevel_Info,
+			    I18N("Unlocking user %s"),
+			    AB_User_GetUserId(cbox->user));
       DBG_INFO(AQHBCI_LOGDOMAIN,
 	       "Unlocking customer \"%s\"",
 	       AB_User_GetCustomerId(cbox->user));
       rv=AB_Banking_EndExclUseUser(AH_HBCI_GetBankingApi(cbox->hbci),
 				   cbox->user,
-				   0,
-				   guiid);
+				   0);
       cbox->isLocked=0;
       if (rv<0) {
 	DBG_WARN(AQHBCI_LOGDOMAIN,
@@ -1837,12 +1806,12 @@ void AH_Outbox__FinishCBox(AH_OUTBOX *ob, AH_OUTBOX__CBOX *cbox, uint32_t guiid)
 
 
 
-static void AH_Outbox__FinishOutbox(AH_OUTBOX *ob, uint32_t guiid) {
+static void AH_Outbox__FinishOutbox(AH_OUTBOX *ob) {
   AH_OUTBOX__CBOX *cbox;
 
   assert(ob);
   while((cbox=AH_Outbox__CBox_List_First(ob->userBoxes))) {
-    AH_Outbox__FinishCBox(ob, cbox, guiid);
+    AH_Outbox__FinishCBox(ob, cbox);
     AH_Outbox__CBox_List_Del(cbox);
     AH_Outbox__CBox_free(cbox);
   } /* while */
@@ -1850,7 +1819,7 @@ static void AH_Outbox__FinishOutbox(AH_OUTBOX *ob, uint32_t guiid) {
 
 
 
-int AH_Outbox_SendAndRecv(AH_OUTBOX *ob, int timeout, uint32_t guiid){
+int AH_Outbox_SendAndRecv(AH_OUTBOX *ob){
   AH_OUTBOX__CBOX *cbox;
   int rv;
   int errors;
@@ -1864,34 +1833,34 @@ int AH_Outbox_SendAndRecv(AH_OUTBOX *ob, int timeout, uint32_t guiid){
              "Sending next message for customer \"%s\"",
              AB_User_GetCustomerId(u));
 
-    rv=AH_Outbox__CBox_SendAndRecvBox(cbox, timeout, guiid);
-    AH_Outbox__FinishCBox(ob, cbox, guiid);
+    rv=AH_Outbox__CBox_SendAndRecvBox(cbox);
+    AH_Outbox__FinishCBox(ob, cbox);
     AH_Outbox__CBox_List_Del(cbox);
     AH_Outbox__CBox_free(cbox);
     if (rv)
       errors++;
     if (rv==GWEN_ERROR_USER_ABORTED) {
-      AH_Outbox__FinishOutbox(ob, guiid);
+      AH_Outbox__FinishOutbox(ob);
       return rv;
     }
   } /* while */
 
-  AH_Outbox__FinishOutbox(ob, guiid);
+  AH_Outbox__FinishOutbox(ob);
   return 0;
 }
 
 
 
-AH_JOB_LIST *AH_Outbox_GetFinishedJobs(AH_OUTBOX *ob, uint32_t guiid){
+AH_JOB_LIST *AH_Outbox_GetFinishedJobs(AH_OUTBOX *ob){
   assert(ob);
   assert(ob->usage);
-  AH_Outbox__FinishOutbox(ob, guiid);
+  AH_Outbox__FinishOutbox(ob);
   return ob->finishedJobs;
 }
 
 
 
-void AH_Outbox_Commit(AH_OUTBOX *ob, int doLock, uint32_t guiid){
+void AH_Outbox_Commit(AH_OUTBOX *ob, int doLock){
   AH_JOB *j;
 
   assert(ob);
@@ -1900,7 +1869,7 @@ void AH_Outbox_Commit(AH_OUTBOX *ob, int doLock, uint32_t guiid){
     if (AH_Job_GetStatus(j)==AH_JobStatusAnswered) {
       /* only commit answered jobs */
       DBG_NOTICE(AQHBCI_LOGDOMAIN, "Committing job \"%s\"", AH_Job_GetName(j));
-      AH_Job_Commit(j, doLock, guiid);
+      AH_Job_Commit(j, doLock);
     }
     j=AH_Job_List_Next(j);
   } /* while */
@@ -1908,7 +1877,7 @@ void AH_Outbox_Commit(AH_OUTBOX *ob, int doLock, uint32_t guiid){
 
 
 
-void AH_Outbox_CommitSystemData(AH_OUTBOX *ob, int doLock, uint32_t guiid){
+void AH_Outbox_CommitSystemData(AH_OUTBOX *ob, int doLock){
   AH_JOB *j;
 
   assert(ob);
@@ -1917,7 +1886,7 @@ void AH_Outbox_CommitSystemData(AH_OUTBOX *ob, int doLock, uint32_t guiid){
     if (AH_Job_GetStatus(j)==AH_JobStatusAnswered) {
       /* only commit answered jobs */
       DBG_NOTICE(AQHBCI_LOGDOMAIN, "Committing job \"%s\"", AH_Job_GetName(j));
-      AH_Job_DefaultCommitHandler(j, doLock, guiid);
+      AH_Job_DefaultCommitHandler(j, doLock);
     }
     j=AH_Job_List_Next(j);
   } /* while */
@@ -1925,7 +1894,7 @@ void AH_Outbox_CommitSystemData(AH_OUTBOX *ob, int doLock, uint32_t guiid){
 
 
 
-void AH_Outbox_Process(AH_OUTBOX *ob, uint32_t guiid){
+void AH_Outbox_Process(AH_OUTBOX *ob){
   AH_JOB *j;
 
   assert(ob);
@@ -1937,7 +1906,7 @@ void AH_Outbox_Process(AH_OUTBOX *ob, uint32_t guiid){
       /* only process answered jobs */
       DBG_DEBUG(AQHBCI_LOGDOMAIN,
 		"Processing job \"%s\"", AH_Job_GetName(j));
-      rv=AH_Job_Process(j, ob->context, guiid);
+      rv=AH_Job_Process(j, ob->context);
       if (rv) {
 	char buf[256];
 
@@ -2068,7 +2037,7 @@ unsigned int AH_Outbox_CountFinishedJobs(AH_OUTBOX *ob){
 
 
 
-int AH_Outbox__Execute(AH_OUTBOX *ob, uint32_t guiid){
+int AH_Outbox__Execute(AH_OUTBOX *ob){
   unsigned int loop;
   unsigned int jobCount;
   int rv;
@@ -2084,23 +2053,23 @@ int AH_Outbox__Execute(AH_OUTBOX *ob, uint32_t guiid){
 		       GWEN_LoggerLevel_Notice,
 		       I18N("AqHBCI started"));
 
-  rv=AH_Outbox_StartSending(ob, guiid);
+  rv=AH_Outbox_StartSending(ob);
   if (rv) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not start sending outbox.");
     return rv;
   }
 
   loop=0;
-  rv=AH_Outbox_SendAndRecv(ob, AH_HBCI_GetTransferTimeout(ob->hbci), guiid);
+  rv=AH_Outbox_SendAndRecv(ob);
   if (rv) {
     DBG_ERROR(AQHBCI_LOGDOMAIN, "Error while sending outbox.");
     return rv;
   }
 
-  rv=AB_Banking_ExecutionProgress(AH_HBCI_GetBankingApi(ob->hbci), 0);
-  if (rv) {
-    DBG_ERROR(AQHBCI_LOGDOMAIN, "User aborted");
-    AH_Outbox__FinishOutbox(ob, guiid);
+  rv=AB_Banking_ExecutionProgress(AH_HBCI_GetBankingApi(ob->hbci));
+  if (rv==GWEN_ERROR_USER_ABORTED) {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "User aborted (%d)", rv);
+    AH_Outbox__FinishOutbox(ob);
     return rv;
   }
 
@@ -2114,8 +2083,7 @@ int AH_Outbox__Execute(AH_OUTBOX *ob, uint32_t guiid){
 
 int AH_Outbox_Execute(AH_OUTBOX *ob,
                       AB_IMEXPORTER_CONTEXT *ctx,
-		      int withProgress, int nounmount, int doLock,
-		      uint32_t guiid) {
+		      int withProgress, int nounmount, int doLock) {
   int rv;
   uint32_t pid=0;
   AB_USER_LIST2 *lockedUsers = NULL;
@@ -2131,10 +2099,8 @@ int AH_Outbox_Execute(AH_OUTBOX *ob,
 			       I18N("Now the jobs are send via their "
 				    "backends to the credit institutes."),
 			       AH_Outbox_CountTodoJobs(ob),
-			       guiid);
+			       0);
   }
-  else
-    pid=guiid;
 
   ob->context=ctx;
 
@@ -2143,7 +2109,7 @@ int AH_Outbox_Execute(AH_OUTBOX *ob,
 			 GWEN_LoggerLevel_Info,
 			 I18N("Locking users"));
     lockedUsers=AB_User_List2_new();
-    rv=AH_Outbox_LockUsers(ob, lockedUsers, pid);
+    rv=AH_Outbox_LockUsers(ob, lockedUsers);
     if (rv<0) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
       GWEN_Gui_ProgressLog(pid,
@@ -2158,14 +2124,14 @@ int AH_Outbox_Execute(AH_OUTBOX *ob,
     GWEN_Gui_ProgressLog(pid,
 			 GWEN_LoggerLevel_Info,
 			 I18N("Executing HBCI jobs"));
-    rv=AH_Outbox__Execute(ob, pid);
+    rv=AH_Outbox__Execute(ob);
     if (rv<0) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
     }
     if (doLock) {
       int rv2;
 
-      rv2=AH_Outbox_UnlockUsers(ob, lockedUsers, 0, pid);
+      rv2=AH_Outbox_UnlockUsers(ob, lockedUsers, 0);
       if (rv2<0) {
 	DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
 	GWEN_Gui_ProgressLog(pid,
@@ -2179,7 +2145,7 @@ int AH_Outbox_Execute(AH_OUTBOX *ob,
 
   /* unmount currently mounted medium */
   if (!nounmount)
-    AB_Banking_ClearCryptTokenList(AH_HBCI_GetBankingApi(ob->hbci), pid);
+    AB_Banking_ClearCryptTokenList(AH_HBCI_GetBankingApi(ob->hbci));
   if (withProgress) {
     GWEN_Gui_ProgressEnd(pid);
   }
