@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -40,8 +37,9 @@ GWEN_INHERIT_FUNCTIONS(AH_JOB);
 
 
 AH_JOB *AH_Job_new(const char *name,
-                   AB_USER *u,
-                   const char *accountId) {
+		   AB_USER *u,
+		   const char *accountId,
+		   int jobVersion) {
   AH_JOB *j;
   GWEN_XMLNODE *node;
   GWEN_XMLNODE *jobNode=0;
@@ -78,7 +76,6 @@ AH_JOB *AH_Job_new(const char *name,
 
   e=AH_User_GetMsgEngine(u);
   assert(e);
-  GWEN_MsgEngine_Attach(e);
 
   bpd=AH_User_GetBpd(u);
 
@@ -158,32 +155,62 @@ AH_JOB *AH_Job_new(const char *name,
     }
 
     /* check for a job for which we have a BPD */
-    node=0;
-    dbHighestVersion=0;
+    node=NULL;
+    dbHighestVersion=NULL;
     highestVersion=-1;
-    while(jobBPD) {
-      int version;
 
-      /* get version from BPD */
-      version=atoi(GWEN_DB_GroupName(jobBPD));
-      if (version>highestVersion) {
-        /* now get the correct version of the JOB */
-        DBG_INFO(AQHBCI_LOGDOMAIN, "Checking Job %s (%d)",
-                 name, version);
-        node=GWEN_MsgEngine_FindNodeByProperty(e,
-                                               "JOB",
-                                               "id",
-                                               version,
-                                               name);
-        if (node) {
-          dbHighestVersion=jobBPD;
-          highestVersion=version;
-          jobNode=node;
-        }
-      }
-      jobBPD=GWEN_DB_GetNextGroup(jobBPD);
-    } /* while */
-    jobBPD=dbHighestVersion;
+    if (jobVersion) {
+      /* a job version has been selected from outside, look for
+       * the BPD of that particular version */
+      while(jobBPD) {
+	int version;
+
+	/* get version from BPD */
+	version=atoi(GWEN_DB_GroupName(jobBPD));
+	if (version==jobVersion) {
+	  /* now get the correct version of the JOB */
+	  DBG_INFO(AQHBCI_LOGDOMAIN, "Checking Job %s (%d)",
+		   name, version);
+	  node=GWEN_MsgEngine_FindNodeByProperty(e,
+						 "JOB",
+						 "id",
+						 version,
+						 name);
+	  if (node) {
+	    dbHighestVersion=jobBPD;
+	    highestVersion=version;
+	    jobNode=node;
+	  }
+	}
+	jobBPD=GWEN_DB_GetNextGroup(jobBPD);
+      } /* while */
+      jobBPD=dbHighestVersion;
+    }
+    else {
+      while(jobBPD) {
+	int version;
+
+	/* get version from BPD */
+	version=atoi(GWEN_DB_GroupName(jobBPD));
+	if (version>highestVersion) {
+	  /* now get the correct version of the JOB */
+	  DBG_INFO(AQHBCI_LOGDOMAIN, "Checking Job %s (%d)",
+		   name, version);
+	  node=GWEN_MsgEngine_FindNodeByProperty(e,
+						 "JOB",
+						 "id",
+						 version,
+						 name);
+	  if (node) {
+	    dbHighestVersion=jobBPD;
+	    highestVersion=version;
+	    jobNode=node;
+	  }
+	}
+	jobBPD=GWEN_DB_GetNextGroup(jobBPD);
+      } /* while */
+      jobBPD=dbHighestVersion;
+    }
 
     if (!jobBPD) {
       if (needsBPD) {
@@ -353,7 +380,6 @@ AH_JOB *AH_Job_new(const char *name,
 
 
 
-
 void AH_Job_free(AH_JOB *j) {
   if (j) {
     assert(j->usage);
@@ -385,6 +411,143 @@ void AH_Job_free(AH_JOB *j) {
 
 
 
+int AH_Job_SampleBpdVersions(const char *name,
+			     AB_USER *u,
+			     GWEN_DB_NODE *dbResult) {
+  GWEN_XMLNODE *node;
+  GWEN_XMLNODE *jobNode=0;
+  const char *segCode;
+  const char *paramName;
+  GWEN_DB_NODE *bpdgrp;
+  const AH_BPD *bpd;
+  GWEN_MSGENGINE *e;
+
+  assert(name);
+  assert(u);
+
+  /* get job descriptions */
+  e=AH_User_GetMsgEngine(u);
+  assert(e);
+
+  bpd=AH_User_GetBpd(u);
+
+  if (AH_User_GetHbciVersion(u)==0)
+    GWEN_MsgEngine_SetProtocolVersion(e, 210);
+  else
+    GWEN_MsgEngine_SetProtocolVersion(e, AH_User_GetHbciVersion(u));
+
+  GWEN_MsgEngine_SetMode(e, AH_CryptMode_toString(AH_User_GetCryptMode(u)));
+
+  /* first select any version, we simply need to know the BPD job name */
+  node=GWEN_MsgEngine_FindNodeByProperty(e,
+                                         "JOB",
+                                         "id",
+                                         0,
+                                         name);
+  if (!node) {
+    DBG_INFO(AQHBCI_LOGDOMAIN,
+	     "Job \"%s\" not supported by local XML files", name);
+    return GWEN_ERROR_NOT_FOUND;
+  }
+  jobNode=node;
+
+  /* get some properties */
+  paramName=GWEN_XMLNode_GetProperty(node, "params", "");
+  segCode=GWEN_XMLNode_GetProperty(node, "code", "");
+
+  if (bpd) {
+    bpdgrp=AH_Bpd_GetBpdJobs(bpd, AH_User_GetHbciVersion(u));
+    assert(bpdgrp);
+  }
+  else
+    bpdgrp=NULL;
+
+  if (paramName && *paramName) {
+    GWEN_DB_NODE *jobBPD;
+
+    DBG_INFO(AQHBCI_LOGDOMAIN, "Job \"%s\" needs BPD job \"%s\"",
+	     name, paramName);
+
+    if (!bpd) {
+      DBG_ERROR(AQHBCI_LOGDOMAIN,"No BPD");
+      return GWEN_ERROR_BAD_DATA;
+    }
+
+    /* get BPD job */
+    jobBPD=GWEN_DB_GetGroup(bpdgrp,
+                            GWEN_PATH_FLAGS_NAMEMUSTEXIST,
+                            paramName);
+    if (jobBPD) {
+      /* children are one group per version */
+      jobBPD=GWEN_DB_GetFirstGroup(jobBPD);
+    }
+
+    /* check for jobs for which we have a BPD */
+    while(jobBPD) {
+      int version;
+
+      /* get version from BPD */
+      version=atoi(GWEN_DB_GroupName(jobBPD));
+      /* now get the correct version of the JOB */
+      DBG_INFO(AQHBCI_LOGDOMAIN, "Checking Job %s (%d)", name, version);
+      node=GWEN_MsgEngine_FindNodeByProperty(e,
+					     "JOB",
+					     "id",
+					     version,
+					     name);
+      if (node) {
+	GWEN_DB_NODE *cpy;
+
+	cpy=GWEN_DB_Group_dup(jobBPD);
+	GWEN_DB_AddGroup(dbResult, cpy);
+      }
+      jobBPD=GWEN_DB_GetNextGroup(jobBPD);
+    } /* while */
+  } /* if paramName */
+  else {
+    DBG_ERROR(AQHBCI_LOGDOMAIN, "Job has no BPDs");
+    return 0;
+  }
+
+  return 0;
+}
+
+
+
+int AH_Job_GetMaxVersionUpUntil(const char *name, AB_USER *u, int maxVersion) {
+  GWEN_DB_NODE *db;
+  int rv;
+
+  db=GWEN_DB_Group_new("bpd");
+  rv=AH_Job_SampleBpdVersions(name, u, db);
+  if (rv<0) {
+    DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
+    GWEN_DB_Group_free(db);
+    return rv;
+  }
+  else {
+    GWEN_DB_NODE *dbT;
+    int m=-1;
+
+    /* determine maximum version */
+    dbT=GWEN_DB_GetFirstGroup(db);
+    while(dbT) {
+      int v;
+
+      v=atoi(GWEN_DB_GroupName(dbT));
+      if (v>0 && v>m && v<=maxVersion)
+        m=v;
+      dbT=GWEN_DB_GetNextGroup(dbT);
+    }
+    GWEN_DB_Group_free(db);
+    DBG_INFO(AQHBCI_LOGDOMAIN, "Max version of [%s] up until %d: %d",
+	     name, maxVersion, m);
+    return m;
+  }
+}
+
+
+
 AB_MESSAGE_LIST *AH_Job_GetMessages(const AH_JOB *j) {
   assert(j);
   assert(j->usage);
@@ -851,7 +1014,7 @@ const char *AH_Job_GetAccountId(const AH_JOB *j) {
 
 
 
-int AH_Job_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx, uint32_t guiid){
+int AH_Job_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
 
   assert(j);
   assert(j->usage);
@@ -859,23 +1022,23 @@ int AH_Job_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx, uint32_t guiid){
   AH_Job_SampleResults(j);
 
   if (j->processFn)
-    return j->processFn(j, ctx, guiid);
+    return j->processFn(j, ctx);
   else {
     DBG_INFO(AQHBCI_LOGDOMAIN, "No processFn set");
-    return AH_Job_DefaultProcessHandler(j, guiid);
+    return AH_Job_DefaultProcessHandler(j);
   }
 }
 
 
 
-int AH_Job_Commit(AH_JOB *j, int doLock, uint32_t guiid){
+int AH_Job_Commit(AH_JOB *j, int doLock){
   assert(j);
   assert(j->usage);
   if (j->commitFn)
-    return j->commitFn(j, doLock, guiid);
+    return j->commitFn(j, doLock);
   else {
     DBG_DEBUG(AQHBCI_LOGDOMAIN, "No commitFn set");
-    return AH_Job_DefaultCommitHandler(j, doLock, guiid);
+    return AH_Job_DefaultCommitHandler(j, doLock);
   }
 }
 
@@ -883,8 +1046,7 @@ int AH_Job_Commit(AH_JOB *j, int doLock, uint32_t guiid){
 
 int AH_Job_Exchange(AH_JOB *j, AB_JOB *bj,
 		    AH_JOB_EXCHANGE_MODE m,
-		    AB_IMEXPORTER_CONTEXT *ctx,
-		    uint32_t guiid){
+		    AB_IMEXPORTER_CONTEXT *ctx){
   GWEN_DB_NODE *db;
 
   assert(j);
@@ -942,7 +1104,7 @@ int AH_Job_Exchange(AH_JOB *j, AB_JOB *bj,
   } /* switch */
 
   if (j->exchangeFn)
-    return j->exchangeFn(j, bj, m, ctx, guiid);
+    return j->exchangeFn(j, bj, m, ctx);
   else {
     DBG_INFO(AQHBCI_LOGDOMAIN, "No exchangeFn set");
     return GWEN_ERROR_NOT_SUPPORTED;
@@ -951,11 +1113,11 @@ int AH_Job_Exchange(AH_JOB *j, AB_JOB *bj,
 
 
 
-int AH_Job_Prepare(AH_JOB *j, uint32_t guiid){
+int AH_Job_Prepare(AH_JOB *j){
   assert(j);
   assert(j->usage);
   if (j->prepareFn)
-    return j->prepareFn(j, guiid);
+    return j->prepareFn(j);
   else {
     DBG_DEBUG(AQHBCI_LOGDOMAIN, "No prepareFn set");
     return GWEN_ERROR_NOT_SUPPORTED;
@@ -1203,7 +1365,7 @@ void AH_Job_Dump(const AH_JOB *j, FILE *f, unsigned int insert) {
 
 
 
-int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
+int AH_Job__CommitSystemData(AH_JOB *j, int doLock) {
   GWEN_DB_NODE *dbCurr;
   AB_USER *u;
   AB_BANKING *ab;
@@ -1499,7 +1661,9 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
             GWEN_DB_AddGroupChildren(bn, dbRd);
             /* remove "head" and "segment" group */
             GWEN_DB_DeleteGroup(bn, "head");
-            GWEN_DB_DeleteGroup(bn, "segment");
+	    GWEN_DB_DeleteGroup(bn, "segment");
+	    DBG_INFO(AQHBCI_LOGDOMAIN, "Added BPD Job %s:%d",
+                     GWEN_DB_GroupName(dbRd), segver);
             modCust=1;
           } /* if isbpdjob */
           else {
@@ -1522,8 +1686,10 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
 						  "version",
 						  0, 0));
       }
-      else if (strcasecmp(GWEN_DB_GroupName(dbRd), "AccountData")==0){
-        const char *accountId;
+      else if (strcasecmp(GWEN_DB_GroupName(dbRd), "AccountData")==0 ||
+	       strcasecmp(GWEN_DB_GroupName(dbRd), "AccountData2")==0){
+	const char *accountId;
+        const char *accountSuffix;
         const char *userName;
         const char *accountName;
         const char *bankCode;
@@ -1545,6 +1711,7 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
 	accountId=GWEN_DB_GetCharValue(dbRd, "accountId", 0, 0);
 	if (accountId==NULL)
 	  accountId=I18N("AH_JOB|-- no account id --");
+	accountSuffix=GWEN_DB_GetCharValue(dbRd, "accountSubId", 0, 0);
         accountName=GWEN_DB_GetCharValue(dbRd, "account/name", 0, 0);
         userName=GWEN_DB_GetCharValue(dbRd, "name1", 0, 0);
 	iban=GWEN_DB_GetCharValue(dbRd, "iban", 0, 0);
@@ -1566,7 +1733,12 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
             GWEN_Buffer_AppendString(mbuf, accountName);
           else
             GWEN_Buffer_AppendString(mbuf, accountId);
-          GWEN_Gui_ProgressLog(0,
+	  if (accountSuffix) {
+	    GWEN_Buffer_AppendString(mbuf, "(");
+	    GWEN_Buffer_AppendString(mbuf, accountSuffix);
+	    GWEN_Buffer_AppendString(mbuf, ")");
+	  }
+	  GWEN_Gui_ProgressLog(0,
 			       GWEN_LoggerLevel_Notice,
 			       GWEN_Buffer_GetStart(mbuf));
 	  GWEN_Buffer_free(mbuf);
@@ -1575,14 +1747,15 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
         acc=AB_Banking_FindAccount(ab, AH_PROVIDER_NAME,
                                    "de", /* TODO: get country */
                                    bankCode,
-                                   accountId);
+                                   accountId,
+                                   accountSuffix);
 	if (acc) {
           DBG_NOTICE(AQHBCI_LOGDOMAIN,
                      "Account \"%s\" already exists",
                      accountId);
 	  accCreated=0;
 	  if (doLock) {
-	    rv=AB_Banking_BeginExclUseAccount(ab, acc, guiid);
+	    rv=AB_Banking_BeginExclUseAccount(ab, acc);
 	    if (rv<0) {
 	      DBG_ERROR(AQHBCI_LOGDOMAIN, "here (%d)", rv);
 	      mayModifyAcc=0;
@@ -1592,7 +1765,7 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
 	  }
           else
 	    mayModifyAcc=1;
-	}
+        }
         else {
           DBG_NOTICE(AQHBCI_LOGDOMAIN, "Creating account \"%s\"", accountId);
 	  accCreated=1;
@@ -1601,7 +1774,12 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
           assert(acc);
           AB_Account_SetCountry(acc, "de");
           AB_Account_SetBankCode(acc, bankCode);
-          AB_Account_SetAccountNumber(acc, accountId);
+	  AB_Account_SetAccountNumber(acc, accountId);
+          if (strcasecmp(GWEN_DB_GroupName(dbRd), "AccountData2")==0)
+            /* KTV in version 2 available */
+            AH_Account_AddFlags(acc, AH_BANK_FLAGS_KTV2);
+          else
+            AH_Account_SubFlags(acc, AH_BANK_FLAGS_KTV2);
           DBG_NOTICE(AQHBCI_LOGDOMAIN,
                      "Setting user \"%s\" for account \"%s\"",
                      AB_User_GetUserId(u),
@@ -1618,6 +1796,8 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
 	    AB_Account_SetOwnerName(acc, userName);
 	  if (iban)
 	    AB_Account_SetIBAN(acc, iban);
+          if (accountSuffix && *accountSuffix)
+            AB_Account_SetSubAccountId(acc, accountSuffix);
 
 	  /* set bank name */
 	  bpd=AH_User_GetBpd(j->user);
@@ -1651,10 +1831,10 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
 	else {
 	  if (mayModifyAcc) {
 	    if (doLock) {
-	      rv=AB_Banking_EndExclUseAccount(ab, acc, 0, guiid);
+	      rv=AB_Banking_EndExclUseAccount(ab, acc, 0);
 	      if (rv<0) {
 		DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
-		AB_Banking_EndExclUseAccount(ab, acc, 1, guiid); /* abort */
+		AB_Banking_EndExclUseAccount(ab, acc, 1); /* abort */
 	      }
 	    }
 	  }
@@ -1695,7 +1875,7 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
 				 "text", text);
 	    if (AH_HBCI_SaveMessage(h, j->user, dbTmp)) {
 	      DBG_ERROR(AQHBCI_LOGDOMAIN, "Could not save this message:");
-	      GWEN_DB_Dump(dbTmp, stderr, 2);
+	      GWEN_DB_Dump(dbTmp, 2);
 	    }
 	    GWEN_DB_Group_free(dbTmp);
 	  }
@@ -1714,7 +1894,7 @@ int AH_Job__CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
 
 
 
-int AH_Job_CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
+int AH_Job_CommitSystemData(AH_JOB *j, int doLock) {
   AB_USER *u;
   AB_BANKING *ab;
   int rv, rv2;
@@ -1727,7 +1907,7 @@ int AH_Job_CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
 
   /* lock user */
   if (doLock) {
-    rv=AB_Banking_BeginExclUseUser(ab, u, guiid);
+    rv=AB_Banking_BeginExclUseUser(ab, u);
     if (rv<0) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
       return rv;
@@ -1735,14 +1915,14 @@ int AH_Job_CommitSystemData(AH_JOB *j, int doLock, uint32_t guiid) {
   }
 
   /* commit data */
-  rv2=AH_Job__CommitSystemData(j, doLock, guiid);
+  rv2=AH_Job__CommitSystemData(j, doLock);
 
   if (doLock) {
     /* unlock user */
-    rv=AB_Banking_EndExclUseUser(ab, u, 0, guiid);
+    rv=AB_Banking_EndExclUseUser(ab, u, 0);
     if (rv<0) {
       DBG_INFO(AQHBCI_LOGDOMAIN, "here (%d)", rv);
-      AB_Banking_EndExclUseUser(ab, u, 1, guiid); /* abandon */
+      AB_Banking_EndExclUseUser(ab, u, 1); /* abandon */
       return rv;
     }
   }
@@ -1794,7 +1974,7 @@ int AH_Job_HasItanResult(AH_JOB *j) {
 
 
 
-int AH_Job_DefaultProcessHandler(AH_JOB *j, uint32_t guiid){
+int AH_Job_DefaultProcessHandler(AH_JOB *j){
   assert(j);
   assert(j->usage);
   if (j->flags & AH_JOB_FLAGS_PROCESSED) {
@@ -1806,7 +1986,7 @@ int AH_Job_DefaultProcessHandler(AH_JOB *j, uint32_t guiid){
 
 
 
-int AH_Job_DefaultCommitHandler(AH_JOB *j, int doLock, uint32_t guiid){
+int AH_Job_DefaultCommitHandler(AH_JOB *j, int doLock){
   int rv;
 
   assert(j);
@@ -1815,7 +1995,7 @@ int AH_Job_DefaultCommitHandler(AH_JOB *j, int doLock, uint32_t guiid){
     DBG_WARN(AQHBCI_LOGDOMAIN, "Already committed job \"%s\"", j->name);
     return 0;
   }
-  rv=AH_Job_CommitSystemData(j, doLock, guiid);
+  rv=AH_Job_CommitSystemData(j, doLock);
   j->flags|=AH_JOB_FLAGS_COMMITTED;
   return rv;
 }
