@@ -137,7 +137,7 @@ int AH_Msg_SignRdh10(AH_MSG *hmsg,
   assert(e);
   GWEN_MsgEngine_SetMode(e, "rdh");
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   uFlags=AH_User_GetFlags(su);
 
@@ -442,7 +442,7 @@ int AH_Msg_EncryptRdh10(AH_MSG *hmsg) {
   assert(e);
   GWEN_MsgEngine_SetMode(e, "rdh");
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
   uFlags=AH_User_GetFlags(u);
@@ -701,7 +701,7 @@ int AH_Msg_DecryptRdh10(AH_MSG *hmsg, GWEN_DB_NODE *gr){
   assert(e);
   GWEN_MsgEngine_SetMode(e, "rdh");
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
   uFlags=AH_User_GetFlags(u);
@@ -907,7 +907,7 @@ int AH_Msg_VerifyRdh10(AH_MSG *hmsg, GWEN_DB_NODE *gr) {
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
   assert(u);
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   /* get crypt token of signer */
   rv=AB_Banking_GetCryptToken(AH_HBCI_GetBankingApi(h),
