@@ -143,7 +143,7 @@ int AH_Msg_SignRdh3(AH_MSG *hmsg,
   assert(e);
   GWEN_MsgEngine_SetMode(e, "rdh");
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   uFlags=AH_User_GetFlags(su);
 
@@ -426,7 +426,7 @@ int AH_Msg_EncryptRdh3(AH_MSG *hmsg) {
   assert(e);
   GWEN_MsgEngine_SetMode(e, "rdh");
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
   uFlags=AH_User_GetFlags(u);
@@ -684,7 +684,7 @@ int AH_Msg_DecryptRdh3(AH_MSG *hmsg, GWEN_DB_NODE *gr){
   assert(e);
   GWEN_MsgEngine_SetMode(e, "rdh");
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
   uFlags=AH_User_GetFlags(u);
@@ -889,7 +889,7 @@ int AH_Msg_VerifyRdh3(AH_MSG *hmsg, GWEN_DB_NODE *gr) {
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
   assert(u);
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   /* get crypt token of signer */
   rv=AB_Banking_GetCryptToken(AH_HBCI_GetBankingApi(h),
