@@ -135,7 +135,7 @@ int AH_Msg_SignRdh5(AH_MSG *hmsg,
   assert(e);
   GWEN_MsgEngine_SetMode(e, "rdh");
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   uFlags=AH_User_GetFlags(su);
 
@@ -428,7 +428,7 @@ int AH_Msg_EncryptRdh5(AH_MSG *hmsg) {
   assert(e);
   GWEN_MsgEngine_SetMode(e, "rdh");
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
   uFlags=AH_User_GetFlags(u);
@@ -694,7 +694,7 @@ int AH_Msg_DecryptRdh5(AH_MSG *hmsg, GWEN_DB_NODE *gr){
   assert(e);
   GWEN_MsgEngine_SetMode(e, "rdh");
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
   uFlags=AH_User_GetFlags(u);
@@ -899,7 +899,7 @@ int AH_Msg_VerifyRdh5(AH_MSG *hmsg, GWEN_DB_NODE *gr) {
   u=AH_Dialog_GetDialogOwner(hmsg->dialog);
   assert(u);
 
-  gid=AH_Dialog_GetGuiId(hmsg->dialog);
+  gid=0;
 
   /* get crypt token of signer */
   rv=AB_Banking_GetCryptToken(AH_HBCI_GetBankingApi(h),
