@@ -110,7 +110,8 @@ uint32_t AH_User_Flags_fromDb(GWEN_DB_NODE *db, const char *name) {
       fl|=AH_USER_FLAGS_KEEPALIVE;
     else if (strcasecmp(s, "ignoreUpd")==0)
       fl|=AH_USER_FLAGS_IGNORE_UPD;
-    else if (strcasecmp(s, "forceSsl3")==0)
+    else if (strcasecmp(s, "forceSsl3")==0 ||
+	     strcasecmp(s, "forceSslv3")==0)
       fl|=AH_USER_FLAGS_FORCE_SSL3;
     else if (strcasecmp(s, "noBase64")==0)
       fl|=AH_USER_FLAGS_NO_BASE64;
@@ -217,6 +218,7 @@ void GWENHYWFAR_CB AH_User_freeData(void *bp, void *p) {
   free(ue->tokenName);
   free(ue->prompt);
   GWEN_Url_free(ue->serverUrl);
+  GWEN_DB_Group_free(ue->dbUpd);
   AH_Bpd_free(ue->bpd);
   GWEN_MsgEngine_free(ue->msgEngine);
   AH_TanMethod_List_free(ue->tanMethodDescriptions);
@@ -262,7 +264,7 @@ void AH_User_ReadDb(AB_USER *u, GWEN_DB_NODE *db) {
   }
   else
     ue->serverUrl=NULL;
-  
+
   /* load BPD */
   AH_Bpd_free(ue->bpd);
   gr=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST, "bpd");
@@ -351,6 +353,11 @@ void AH_User_ReadDb(AB_USER *u, GWEN_DB_NODE *db) {
   /* read some settings */
   ue->maxTransfersPerJob=GWEN_DB_GetIntValue(db, "maxTransfersPerJob", 0, AH_USER_MAX_TRANSFERS_PER_JOB);
   ue->maxDebitNotesPerJob=GWEN_DB_GetIntValue(db, "maxDebitNotesPerJob", 0, AH_USER_MAX_DEBITNOTES_PER_JOB);
+
+  free(ue->tanMediumId);
+  s=GWEN_DB_GetCharValue(db, "tanMediumId", 0, NULL);
+  if (s) ue->tanMediumId=strdup(s);
+  else ue->tanMediumId=NULL;
 }
 
 
@@ -468,7 +475,9 @@ void AH_User_toDb(AB_USER *u, GWEN_DB_NODE *db) {
   GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
 		      "maxDebitNotesPerJob",
 		      ue->maxDebitNotesPerJob);
-
+  if (ue->tanMediumId)
+    GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+			 "tanMediumId", ue->tanMediumId);
 }
 
 
@@ -1112,8 +1121,7 @@ int AH_User_MkTanName(const AB_USER *u,
 int AH_User_InputPin(AB_USER *u,
 		     char *pwbuffer,
 		     int minLen, int maxLen,
-                     int flags,
-                     uint32_t guiid){
+                     int flags){
   GWEN_BUFFER *nbuf;
   int rv;
   const char *numeric_warning = "";
@@ -1190,7 +1198,7 @@ int AH_User_InputPin(AB_USER *u,
 			  pwbuffer,
 			  minLen,
 			  maxLen,
-                          guiid);
+			  0);
   GWEN_Buffer_free(nbuf);
 
   return rv;
@@ -1201,8 +1209,7 @@ int AH_User_InputPin(AB_USER *u,
 int AH_User_InputPasswd(AB_USER *u,
 			char *pwbuffer,
 			int minLen, int maxLen,
-                        int flags,
-                        uint32_t guiid){
+                        int flags){
   GWEN_BUFFER *nbuf;
   int rv;
   const char *numeric_warning = "";
@@ -1279,7 +1286,7 @@ int AH_User_InputPasswd(AB_USER *u,
 			  pwbuffer,
 			  minLen,
 			  maxLen,
-                          guiid);
+			  0);
   GWEN_Buffer_free(nbuf);
 
   return rv;
@@ -1290,8 +1297,7 @@ int AH_User_InputPasswd(AB_USER *u,
 int AH_User_InputTan(AB_USER *u,
 		     char *pwbuffer,
 		     int minLen,
-                     int maxLen,
-                     uint32_t guiid){
+                     int maxLen){
   int rv;
   char buffer[512];
   const char *un;
@@ -1336,7 +1342,7 @@ int AH_User_InputTan(AB_USER *u,
 			  pwbuffer,
 			  minLen,
 			  maxLen,
-                          guiid);
+			  0);
   GWEN_Buffer_free(nbuf);
   AB_BankInfo_free(bi);
   return rv;
@@ -1348,8 +1354,7 @@ int AH_User_InputTanWithChallenge(AB_USER *u,
 				  const char *challenge,
 				  char *pwbuffer,
 				  int minLen,
-                                  int maxLen,
-                                  uint32_t guiid){
+                                  int maxLen){
   int rv;
   char buffer[512];
   const char *un;
@@ -1402,7 +1407,7 @@ int AH_User_InputTanWithChallenge(AB_USER *u,
 			  pwbuffer,
 			  minLen,
 			  maxLen,
-                          guiid);
+			  0);
   GWEN_Buffer_free(nbuf);
   AB_BankInfo_free(bi);
   return rv;
@@ -1590,6 +1595,32 @@ void AH_User_SetSelectedTanMethod(AB_USER *u, int i) {
 
 
 
+const char *AH_User_GetTanMediumId(const AB_USER *u) {
+  AH_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AH_USER, u);
+  assert(ue);
+
+  return ue->tanMediumId;
+}
+
+
+
+void AH_User_SetTanMediumId(AB_USER *u, const char *s) {
+  AH_USER *ue;
+
+  assert(u);
+  ue=GWEN_INHERIT_GETDATA(AB_USER, AH_USER, u);
+  assert(ue);
+
+  free(ue->tanMediumId);
+  if (s) ue->tanMediumId=strdup(s);
+  else ue->tanMediumId=NULL;
+}
+
+
+
 void AH_User_LoadTanMethods(AB_USER *u) {
   AH_USER *ue;
 
@@ -1597,59 +1628,74 @@ void AH_User_LoadTanMethods(AB_USER *u) {
   ue=GWEN_INHERIT_GETDATA(AB_USER, AH_USER, u);
   assert(ue);
 
-  AH_TanMethod_List_Clear(ue->tanMethodDescriptions);
-
+  /* read directly from BPD */
   if (ue->cryptMode==AH_CryptMode_Pintan) {
-    AH_JOB *jTan;
+    GWEN_DB_NODE *db;
+    int rv;
 
-    jTan=AH_Job_Tan_new(u, 1);
-    if (!jTan) {
-      DBG_WARN(AQHBCI_LOGDOMAIN, "Job HKTAN not available");
+    AH_TanMethod_List_Clear(ue->tanMethodDescriptions);
+    db=GWEN_DB_Group_new("bpd");
+    rv=AH_Job_SampleBpdVersions("JobTan", u, db);
+    if (rv<0) {
+      DBG_INFO(AQHBCI_LOGDOMAIN, "No BPD for TAN job");
     }
     else {
-      GWEN_DB_NODE *db;
-      GWEN_DB_NODE *dbT;
-  
-      db=AH_Job_GetParams(jTan);
-      assert(db);
-  
-      dbT=GWEN_DB_FindFirstGroup(db, "tanMethod");
-      if (!dbT) {
-	DBG_ERROR(AQHBCI_LOGDOMAIN, "No tanmethod found");
-      }
-      while(dbT) {
-	AH_TAN_METHOD *tm;
-  
-	tm=AH_TanMethod_fromDb(dbT);
-	if (tm) {
-	  DBG_INFO(AQHBCI_LOGDOMAIN,
-		   "Adding TAN method [%s]",
-		   AH_TanMethod_GetMethodId(tm));
-	  AH_TanMethod_List_Add(tm, ue->tanMethodDescriptions);
+      GWEN_DB_NODE *dbV;
+
+      dbV=GWEN_DB_GetFirstGroup(db);
+      while(dbV) {
+	int version;
+
+	version=atoi(GWEN_DB_GroupName(dbV));
+	if (version>0) {
+	  GWEN_DB_NODE *dbT;
+
+	  dbT=GWEN_DB_FindFirstGroup(dbV, "tanMethod");
+	  if (!dbT) {
+	    DBG_INFO(AQHBCI_LOGDOMAIN, "No tan method found");
+	  }
+	  while(dbT) {
+	    AH_TAN_METHOD *tm;
+
+	    tm=AH_TanMethod_fromDb(dbT);
+	    if (tm) {
+	      DBG_INFO(AQHBCI_LOGDOMAIN,
+			"Adding TAN method %d [%s] for GV version %d",
+                        AH_TanMethod_GetFunction(tm),
+			AH_TanMethod_GetMethodId(tm),
+			version);
+	      AH_TanMethod_SetGvVersion(tm, version);
+	      AH_TanMethod_List_Add(tm, ue->tanMethodDescriptions);
+	    }
+	    else {
+	      DBG_WARN(AQHBCI_LOGDOMAIN, "Invalid TAN method");
+	      GWEN_DB_Dump(dbT, 2);
+	    }
+
+	    dbT=GWEN_DB_FindNextGroup(dbT, "tanMethod");
+	  }
 	}
-	else {
-	  DBG_WARN(AQHBCI_LOGDOMAIN, "Invalid TAN method");
-	  GWEN_DB_Dump(dbT, stderr, 2);
-	}
-  
-	dbT=GWEN_DB_FindNextGroup(dbT, "tanMethod");
+
+	dbV=GWEN_DB_GetNextGroup(dbV);
       }
-  
-      AH_Job_free(jTan);
     }
+    GWEN_DB_Group_free(db);
   }
 }
 
 
 
 
-const AH_TAN_METHOD_LIST *AH_User_GetTanMethodDescriptions(const AB_USER *u) {
+const AH_TAN_METHOD_LIST *AH_User_GetTanMethodDescriptions(AB_USER *u) {
   AH_USER *ue;
 
   assert(u);
   ue=GWEN_INHERIT_GETDATA(AB_USER, AH_USER, u);
   assert(ue);
 
+  /* always reload TAN methods from BPD */
+  AH_User_LoadTanMethods(u);
+
   return ue->tanMethodDescriptions;
 }
 
