@@ -57,6 +57,7 @@ int main(int argc, char **argv) {
   const char *cmd;
   const char *pinFile;
   int nonInteractive=0;
+  int acceptValidCerts=0;
   int rv;
   AB_BANKING *ab;
   GWEN_GUI *gui;
@@ -96,6 +97,17 @@ int main(int argc, char **argv) {
     "This automatically returns a confirmative answer to any non-critical\n"
     "message."
   },
+  {
+    0,                            /* flags */
+    GWEN_ArgsType_Int,            /* type */
+    "acceptValidCerts",           /* name */
+    0,                            /* minnum */
+    1,                            /* maxnum */
+    "A",                          /* short option */
+    "acceptvalidcerts",           /* long option */
+    "Automatically accept all valid TLS certificate",
+    "Automatically accept all valid TLS certificate"
+  },
   {
     GWEN_ARGS_FLAGS_HAS_ARGUMENT, /* flags */
     GWEN_ArgsType_Char,           /* type */
@@ -219,6 +231,10 @@ int main(int argc, char **argv) {
                              I18N("  setMaxTransfers:\n"
                                   "    Set the maximum number of transfers/debit notes per job \n\n"));
 
+    GWEN_Buffer_AppendString(ubuf,
+                             I18N("  setTanMediumId:\n"
+                                  "    Set the medium id for some PIN/TAN methods (like mTAN) \n\n"));
+
     fprintf(stderr, "%s\n", GWEN_Buffer_GetStart(ubuf));
     GWEN_Buffer_free(ubuf);
     return 0;
@@ -236,13 +252,21 @@ int main(int argc, char **argv) {
   }
 
   gui=GWEN_Gui_CGui_new();
-  s=GWEN_DB_GetCharValue(db, "charset", 0, "ISO-8859-15");
-  GWEN_Gui_CGui_SetCharSet(gui, s);
+  s=GWEN_DB_GetCharValue(db, "charset", 0, NULL);
+  if (s && *s)
+    GWEN_Gui_SetCharSet(gui, s);
   nonInteractive=GWEN_DB_GetIntValue(db, "nonInteractive", 0, 0);
+  acceptValidCerts=GWEN_DB_GetIntValue(db, "acceptValidCerts", 0, 0);
   if (nonInteractive)
     GWEN_Gui_AddFlags(gui, GWEN_GUI_FLAGS_NONINTERACTIVE);
   else
     GWEN_Gui_SubFlags(gui, GWEN_GUI_FLAGS_NONINTERACTIVE);
+
+  if (acceptValidCerts)
+    GWEN_Gui_AddFlags(gui, GWEN_GUI_FLAGS_ACCEPTVALIDCERTS);
+  else
+    GWEN_Gui_SubFlags(gui, GWEN_GUI_FLAGS_ACCEPTVALIDCERTS);
+
   pinFile=GWEN_DB_GetCharValue(db, "pinFile", 0, NULL);
   if (pinFile) {
     GWEN_DB_NODE *dbPins;
@@ -250,8 +274,7 @@ int main(int argc, char **argv) {
     dbPins=GWEN_DB_Group_new("pins");
     if (GWEN_DB_ReadFile(dbPins, pinFile,
 			 GWEN_DB_FLAGS_DEFAULT |
-			 GWEN_PATH_FLAGS_CREATE_GROUP,
-			 0, 20000)) {
+			 GWEN_PATH_FLAGS_CREATE_GROUP)) {
       fprintf(stderr, "Error reading pinfile \"%s\"\n", pinFile);
       return 2;
     }
@@ -335,6 +358,9 @@ int main(int argc, char **argv) {
   else if (strcasecmp(cmd, "setmaxtransfers")==0) {
     rv=setMaxTransfers(ab, db, argc, argv);
   }
+  else if (strcasecmp(cmd, "setTanMediumId")==0) {
+    rv=setTanMediumId(ab, db, argc, argv);
+  }
   else if (strcasecmp(cmd, "versions")==0) {
     showVersions();
     rv=0;
