@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Thu Jul 03 2003
- copyright   : (C) 2003 by Martin Preuss
+ copyright   : (C) 2003-2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -32,10 +29,8 @@
 
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/text.h>
-#include <gwenhywfar/bufferedio.h>
-#include <gwenhywfar/io_file.h>
-#include <gwenhywfar/iolayer.h>
-#include <gwenhywfar/iomanager.h>
+
+#include <gwenhywfar/syncio_file.h>
 
 // #include <aqhbci/version.h>
 #include <aqhbci/msgengine.h>
@@ -513,7 +508,7 @@ int show(const s_args &args) {
 
 
   if (args.logLevel>=GWEN_LoggerLevel_Debug)
-    GWEN_XMLNode_Dump(GWEN_MsgEngine_GetDefinitions(e), stderr, 1);
+    GWEN_XMLNode_Dump(GWEN_MsgEngine_GetDefinitions(e), 1);
 
   listNode=GWEN_MsgEngine_ListMessage(e,
                                       args.typ.c_str(),
@@ -529,7 +524,7 @@ int show(const s_args &args) {
 
   DBG_INFO(0, "Listnode:");
   if (args.logLevel>=GWEN_LoggerLevel_Info)
-    GWEN_XMLNode_Dump(listNode, stderr, 1);
+    GWEN_XMLNode_Dump(listNode, 1);
 
   version=atoi(GWEN_XMLNode_GetProperty(listNode, "version", "-1"));
 
@@ -601,7 +596,7 @@ int listAll(const s_args &args) {
 
 
   if (args.logLevel>=GWEN_LoggerLevel_Info)
-    GWEN_XMLNode_Dump(GWEN_MsgEngine_GetDefinitions(e), stderr, 1);
+    GWEN_XMLNode_Dump(GWEN_MsgEngine_GetDefinitions(e), 1);
 
 
   n=GWEN_MsgEngine_GetDefinitions(e);
@@ -717,7 +712,7 @@ int checkAll(const s_args &args) {
 
 
   if (args.logLevel>=GWEN_LoggerLevel_Info)
-    GWEN_XMLNode_Dump(GWEN_MsgEngine_GetDefinitions(e), stderr, 1);
+    GWEN_XMLNode_Dump(GWEN_MsgEngine_GetDefinitions(e), 1);
 
 
   n=GWEN_MsgEngine_GetDefinitions(e);
@@ -770,7 +765,7 @@ int checkAll(const s_args &args) {
               }
 
               if (isError) {
-                GWEN_XMLNode_Dump(cn, stderr, 2);
+                GWEN_XMLNode_Dump(cn, 2);
                 errors++;
               }
             }
@@ -798,104 +793,71 @@ int checkAll(const s_args &args) {
 void _logMessage(const string &fname,
                  const string &msg,
                  GWEN_DB_NODE *hd) {
-  int fd;
   int rv;
-  GWEN_IO_LAYER *io;
+  GWEN_SYNCIO *sio;
 
-  fd=open(fname.c_str(),
-          O_RDWR | O_CREAT | O_APPEND,
-          S_IRUSR | S_IWUSR);
-  if (fd==-1) {
-    DBG_ERROR(0, "fopen(%s): %s", fname.c_str(), strerror(errno));
+  sio=GWEN_SyncIo_File_new(fname.c_str(), GWEN_SyncIo_File_CreationMode_CreateAlways);
+  GWEN_SyncIo_AddFlags(sio,
+		       GWEN_SYNCIO_FILE_FLAGS_READ |
+		       GWEN_SYNCIO_FILE_FLAGS_WRITE |
+		       GWEN_SYNCIO_FILE_FLAGS_UREAD |
+		       GWEN_SYNCIO_FILE_FLAGS_UWRITE |
+		       GWEN_SYNCIO_FILE_FLAGS_APPEND);
+  rv=GWEN_SyncIo_Connect(sio);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+    GWEN_SyncIo_free(sio);
     return;
   }
 
-  /* create io layer for this file */
-  io=GWEN_Io_LayerFile_new(-1, fd);
-  assert(io);
-
-  rv=GWEN_Io_Manager_RegisterLayer(io);
-  if (rv) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Internal error: Could not register io layer (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
-    return;
-  }
-
-  rv=GWEN_DB_WriteToIo(hd, io,
+  rv=GWEN_DB_WriteToIo(hd, sio,
 		       GWEN_DB_FLAGS_WRITE_SUBGROUPS |
 		       GWEN_DB_FLAGS_DETAILED_GROUPS |
 		       GWEN_DB_FLAGS_USE_COLON|
-		       GWEN_DB_FLAGS_OMIT_TYPES,
-		       0,
-		       2000);
+		       GWEN_DB_FLAGS_OMIT_TYPES);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+    GWEN_SyncIo_Disconnect(sio);
+    GWEN_SyncIo_free(sio);
     return;
   }
 
   /* append empty line to separate header from data */
-  rv=GWEN_Io_Layer_WriteChar(io, '\n',
-			     GWEN_IO_REQUEST_FLAGS_WRITEALL,
-			     0,
-			     2000);
+  rv=GWEN_SyncIo_WriteForced(sio, (const uint8_t*) "\n", 1);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+    GWEN_SyncIo_Disconnect(sio);
+    GWEN_SyncIo_free(sio);
     return;
   }
 
   /* write data */
-  rv=GWEN_Io_Layer_WriteBytes(io,
-			      (const uint8_t*)msg.data(),
-			      msg.length(),
-			      GWEN_IO_REQUEST_FLAGS_WRITEALL,
-			      0,
-                              2000);
+  rv=GWEN_SyncIo_WriteForced(sio, (const uint8_t*) msg.data(), msg.length());
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+    GWEN_SyncIo_Disconnect(sio);
+    GWEN_SyncIo_free(sio);
     return;
   }
 
   /* append CR for better readability */
-  rv=GWEN_Io_Layer_WriteChar(io, '\n',
-			     GWEN_IO_REQUEST_FLAGS_WRITEALL,
-			     0,
-			     2000);
+  rv=GWEN_SyncIo_WriteForced(sio, (const uint8_t*) "\n", 1);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+    GWEN_SyncIo_Disconnect(sio);
+    GWEN_SyncIo_free(sio);
     return;
   }
 
   /* close layer */
-  rv=GWEN_Io_Layer_DisconnectRecursively(io, NULL, 0, 0, 30000);
+  rv=GWEN_SyncIo_Disconnect(sio);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+    GWEN_SyncIo_free(sio);
     return;
   }
 
-  GWEN_Io_Layer_free(io);
+  GWEN_SyncIo_free(sio);
 }
 
 
@@ -1169,8 +1131,7 @@ int analyzeLog(const s_args &args) {
 
   if (!args.parseFile.empty()) {
     if (GWEN_DB_WriteFile(allgr, args.parseFile.c_str(),
-			  GWEN_DB_FLAGS_DEFAULT,
-			  0, 2000)) {
+			  GWEN_DB_FLAGS_DEFAULT)) {
       fprintf(stderr, "ERROR saving message.\n");
       GWEN_DB_Group_free(allgr);
       GWEN_MsgEngine_free(e);
