@@ -1,9 +1,6 @@
 /***************************************************************************
-  $RCSfile$
-  -------------------
-  cvs         : $Id$
   begin       : Sat Oct 25 2003
-  copyright   : (C) 2003 by Martin Preuss
+  copyright   : (C) 2003-2010 by Martin Preuss
   email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -35,10 +32,7 @@
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/directory.h>
 #include <gwenhywfar/path.h>
-#include <gwenhywfar/bufferedio.h>
-#include <gwenhywfar/io_file.h>
-#include <gwenhywfar/iolayer.h>
-#include <gwenhywfar/iomanager.h>
+#include <gwenhywfar/syncio_file.h>
 
 #include <unistd.h>
 #include <sys/stat.h>
@@ -69,106 +63,71 @@ LogAnalyzer::LogFile::LogMessage::~LogMessage(){
 
 
 int LogAnalyzer::LogFile::LogMessage::toFile(const string &fname) {
-  int fd;
   int rv;
-  GWEN_IO_LAYER *io;
+  GWEN_SYNCIO *sio;
 
-  fd=open(fname.c_str(),
-          O_RDWR | O_CREAT | O_APPEND,
-          S_IRUSR | S_IWUSR);
-  if (fd==-1) {
-    DBG_ERROR(0, "fopen(%s): %s", fname.c_str(), strerror(errno));
-    return GWEN_ERROR_IO;
-  }
-
-  /* create io layer for this file */
-  io=GWEN_Io_LayerFile_new(-1, fd);
-  assert(io);
-
-  rv=GWEN_Io_Manager_RegisterLayer(io);
-  if (rv) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Internal error: Could not register io layer (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+  sio=GWEN_SyncIo_File_new(fname.c_str(), GWEN_SyncIo_File_CreationMode_CreateAlways);
+  GWEN_SyncIo_AddFlags(sio,
+		       GWEN_SYNCIO_FILE_FLAGS_READ |
+		       GWEN_SYNCIO_FILE_FLAGS_WRITE |
+		       GWEN_SYNCIO_FILE_FLAGS_UREAD |
+		       GWEN_SYNCIO_FILE_FLAGS_UWRITE |
+		       GWEN_SYNCIO_FILE_FLAGS_APPEND);
+  rv=GWEN_SyncIo_Connect(sio);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+    GWEN_SyncIo_free(sio);
     return rv;
   }
 
-  /* write header */
-  rv=GWEN_DB_WriteToIo(_header, io,
+  rv=GWEN_DB_WriteToIo(_header, sio,
 		       GWEN_DB_FLAGS_WRITE_SUBGROUPS |
 		       GWEN_DB_FLAGS_DETAILED_GROUPS |
 		       GWEN_DB_FLAGS_USE_COLON|
-		       GWEN_DB_FLAGS_OMIT_TYPES,
-		       0,
-		       2000);
+		       GWEN_DB_FLAGS_OMIT_TYPES);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+    GWEN_SyncIo_Disconnect(sio);
+    GWEN_SyncIo_free(sio);
     return rv;
   }
 
   /* append empty line to separate header from data */
-  rv=GWEN_Io_Layer_WriteChar(io, '\n',
-			     GWEN_IO_REQUEST_FLAGS_WRITEALL,
-			     0,
-			     2000);
+  rv=GWEN_SyncIo_WriteForced(sio, (const uint8_t*) "\n", 1);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+    GWEN_SyncIo_Disconnect(sio);
+    GWEN_SyncIo_free(sio);
     return rv;
   }
 
   /* write data */
-  rv=GWEN_Io_Layer_WriteBytes(io,
-			      (const uint8_t*)_message.data(),
-			      _message.length(),
-			      GWEN_IO_REQUEST_FLAGS_WRITEALL,
-			      0,
-			      2000);
+  rv=GWEN_SyncIo_WriteForced(sio, (const uint8_t*) _message.data(), _message.length());
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+    GWEN_SyncIo_Disconnect(sio);
+    GWEN_SyncIo_free(sio);
     return rv;
   }
 
   /* append CR for better readability */
-  rv=GWEN_Io_Layer_WriteChar(io, '\n',
-			     GWEN_IO_REQUEST_FLAGS_WRITEALL,
-			     0,
-			     2000);
+  rv=GWEN_SyncIo_WriteForced(sio, (const uint8_t*) "\n", 1);
   if (rv<0) {
     DBG_INFO(0, "here (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+    GWEN_SyncIo_Disconnect(sio);
+    GWEN_SyncIo_free(sio);
     return rv;
   }
 
   /* close layer */
-  rv=GWEN_Io_Layer_DisconnectRecursively(io, NULL, 0, 0, 30000);
+  rv=GWEN_SyncIo_Disconnect(sio);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+    GWEN_SyncIo_free(sio);
     return rv;
   }
 
-  GWEN_Io_Layer_free(io);
-
+  GWEN_SyncIo_free(sio);
   return 0;
 }
 
@@ -179,50 +138,28 @@ int LogAnalyzer::LogFile::LogMessage::toFile(const string &fname) {
 
 LogAnalyzer::LogFile::LogFile(const string &fname)
 :_fileName(fname){
-  GWEN_IO_LAYER *io;
+  GWEN_SYNCIO *sio;
   GWEN_FAST_BUFFER *fb;
-  int fd;
   int rv;
   uint8_t buffer[1024];
 
-  fd=open(fname.c_str(), O_RDONLY);
-  if (fd==-1) {
-    DBG_ERROR(0,
-	      "Error opening file \"%s\": %s",
-              fname.c_str(),
-              strerror(errno));
-    throw Error("LogAnalyzer::Logfile::LogFile",
-                ERROR_LEVEL_NORMAL,
-                HBCI_ERROR_CODE_UNKNOWN,
-                ERROR_ADVISE_DONTKNOW,
-                "Error opening file",
-                fname);
-  }
-
-  /* create io layer for this file */
-  io=GWEN_Io_LayerFile_new(fd, -1);
-  assert(io);
-
-  /* create fast buffer around io layer */
-  fb=GWEN_FastBuffer_new(1024, io, 0, 20000);
-
-  rv=GWEN_Io_Manager_RegisterLayer(io);
-  if (rv) {
-    DBG_ERROR(0,
-	      "Internal error: Could not register io layer (%d)", rv);
-    GWEN_FastBuffer_free(fb);
-    GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					GWEN_IO_REQUEST_FLAGS_FORCE,
-					0, 2000);
-    GWEN_Io_Layer_free(io);
+  sio=GWEN_SyncIo_File_new(fname.c_str(), GWEN_SyncIo_File_CreationMode_OpenExisting);
+  GWEN_SyncIo_AddFlags(sio, GWEN_SYNCIO_FILE_FLAGS_READ);
+  rv=GWEN_SyncIo_Connect(sio);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+    GWEN_SyncIo_free(sio);
     throw Error("LogAnalyzer::Logfile::LogFile",
 		ERROR_LEVEL_NORMAL,
 		HBCI_ERROR_CODE_UNKNOWN,
 		ERROR_ADVISE_DONTKNOW,
-		"Error registering io layer",
+		"Error opening file",
 		fname);
   }
 
+  /* create fast buffer around io layer */
+  fb=GWEN_FastBuffer_new(1024, sio);
+
   for (;;) {
     Pointer<LogMessage> msg;
     GWEN_DB_NODE *hd;
@@ -241,10 +178,8 @@ LogAnalyzer::LogFile::LogFile(const string &fname)
 	DBG_ERROR(0, "here (%d)", rv);
 	GWEN_DB_Group_free(hd);
 	GWEN_FastBuffer_free(fb);
-	GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					    GWEN_IO_REQUEST_FLAGS_FORCE,
-					    0, 2000);
-	GWEN_Io_Layer_free(io);
+	GWEN_SyncIo_Disconnect(sio);
+        GWEN_SyncIo_free(sio);
 	throw Error("LogAnalyzer::Logfile::LogFile",
 		    ERROR_LEVEL_NORMAL,
 		    HBCI_ERROR_CODE_UNKNOWN,
@@ -268,10 +203,8 @@ LogAnalyzer::LogFile::LogFile(const string &fname)
 	DBG_ERROR(0, "here (%d)", rv);
 	GWEN_DB_Group_free(hd);
 	GWEN_FastBuffer_free(fb);
-	GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					    GWEN_IO_REQUEST_FLAGS_FORCE,
-					    0, 2000);
-	GWEN_Io_Layer_free(io);
+	GWEN_SyncIo_Disconnect(sio);
+	GWEN_SyncIo_free(sio);
 	throw Error("LogAnalyzer::Logfile::LogFile",
 		    ERROR_LEVEL_NORMAL,
 		    HBCI_ERROR_CODE_UNKNOWN,
@@ -294,10 +227,8 @@ LogAnalyzer::LogFile::LogFile(const string &fname)
 	DBG_ERROR(0, "here (%d)", rv);
 	GWEN_DB_Group_free(hd);
 	GWEN_FastBuffer_free(fb);
-	GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-					    GWEN_IO_REQUEST_FLAGS_FORCE,
-					    0, 2000);
-	GWEN_Io_Layer_free(io);
+	GWEN_SyncIo_Disconnect(sio);
+	GWEN_SyncIo_free(sio);
 	throw Error("LogAnalyzer::Logfile::LogFile",
 		    ERROR_LEVEL_NORMAL,
 		    HBCI_ERROR_CODE_UNKNOWN,
@@ -314,10 +245,8 @@ LogAnalyzer::LogFile::LogFile(const string &fname)
   }
 
   GWEN_FastBuffer_free(fb);
-  GWEN_Io_Layer_DisconnectRecursively(io, NULL,
-				      0,
-				      0, 2000);
-  GWEN_Io_Layer_free(io);
+  GWEN_SyncIo_Disconnect(sio);
+  GWEN_SyncIo_free(sio);
 }
 
 
