@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -20,6 +17,8 @@
 #include "account.h"
 #include "queues_l.h"
 #include "user.h"
+#include "dlg_edituser_l.h"
+#include "dlg_newuser_l.h"
 
 #include <aqbanking/account_be.h>
 #include <aqbanking/job_be.h>
@@ -32,7 +31,6 @@
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/inherit.h>
 #include <gwenhywfar/misc.h>
-#include <gwenhywfar/bio_buffer.h>
 #include <gwenhywfar/dbio.h>
 #include <gwenhywfar/text.h>
 #include <gwenhywfar/process.h>
@@ -48,10 +46,8 @@
 
 
 #define I18N(msg) GWEN_I18N_Translate(PACKAGE, msg)
-#define I18N_NOOP(msg) msg
 #define I18S(msg) msg
 
-#define I18N_NOOP(msg) msg
 
 
 
@@ -59,6 +55,37 @@ GWEN_INHERIT(AB_PROVIDER, AO_PROVIDER)
 
 
 
+
+static AO_APPINFO _appInfos[]={
+{ I18S("Intuit Quicken Windows 2010"),    "QWIN",       "1800"},
+{ I18S("Intuit Quicken Windows 2008"),    "QWIN",       "1700"},
+{ I18S("Intuit Quicken Windows 2007"),    "QWIN",       "1600"},
+{ I18S("Intuit Quicken Windows 2006"),    "QWIN",       "1500"},
+{ I18S("Intuit Quicken Windows 2005"),    "QWIN",       "1400"},
+{ I18S("Intuit Quicken Mac 2008"),        "QMOFX",      "1700"},
+{ I18S("Intuit Quicken Mac 2007"),        "QMOFX",      "1600"},
+{ I18S("Intuit Quicken Mac 2006"),        "QMOFX",      "1500"},
+{ I18S("Intuit Quicken Mac 2005"),        "QMOFX",      "1400"},
+
+{ I18S("Intuit QuickBooks Windows 2008"), "QBW",        "1800"},
+{ I18S("Intuit QuickBooks Windows 2007"), "QBW",        "1700"},
+{ I18S("Intuit QuickBooks Windows 2006"), "QBW",        "1600"},
+{ I18S("Intuit QuickBooks Windows 2005"), "QBW",        "1500"},
+
+{ I18S("Microsoft Money Plus"),           "Money Plus", "1700"},
+{ I18S("Microsoft Money 2007"),           "Money",      "1600"},
+{ I18S("Microsoft Money 2006"),           "Money",      "1500"},
+{ I18S("Microsoft Money 2005"),           "Money",      "1400"},
+{ I18S("Microsoft Money 2004"),           "Money",      "1200"},
+{ I18S("Microsoft Money 2003"),           "Money",      "1100"},
+
+{ NULL, NULL, NULL}
+};
+
+
+
+
+
 AB_PROVIDER *AO_Provider_new(AB_BANKING *ab){
   AB_PROVIDER *pro;
   AO_PROVIDER *dp;
@@ -79,6 +106,12 @@ AB_PROVIDER *AO_Provider_new(AB_BANKING *ab){
   AB_Provider_SetExtendUserFn(pro, AO_Provider_ExtendUser);
   AB_Provider_SetExtendAccountFn(pro, AO_Provider_ExtendAccount);
 
+  AB_Provider_SetGetEditUserDialogFn(pro, AO_Provider_GetEditUserDialog);
+  AB_Provider_AddFlags(pro, AB_PROVIDER_FLAGS_HAS_EDITUSER_DIALOG);
+
+  AB_Provider_SetGetNewUserDialogFn(pro, AO_Provider_GetNewUserDialog);
+  AB_Provider_AddFlags(pro, AB_PROVIDER_FLAGS_HAS_NEWUSER_DIALOG);
+
   return pro;
 }
 
@@ -171,7 +204,7 @@ int AO_Provider_Fini(AB_PROVIDER *pro, GWEN_DB_NODE *dbData){
 
 
 
-int AO_Provider_UpdateJob(AB_PROVIDER *pro, AB_JOB *j, uint32_t guiid){
+int AO_Provider_UpdateJob(AB_PROVIDER *pro, AB_JOB *j){
   AO_PROVIDER *dp;
 
   assert(pro);
@@ -198,7 +231,7 @@ int AO_Provider_UpdateJob(AB_PROVIDER *pro, AB_JOB *j, uint32_t guiid){
 
 
 
-int AO_Provider_AddJob(AB_PROVIDER *pro, AB_JOB *j, uint32_t guiid){
+int AO_Provider_AddJob(AB_PROVIDER *pro, AB_JOB *j){
   AO_PROVIDER *dp;
   AB_ACCOUNT *a;
   AB_USER *u;
@@ -419,8 +452,7 @@ AB_JOB *AO_Provider_FindJobById(AB_JOB_LIST2 *jl, uint32_t jid) {
 
 
 
-int AO_Provider_Execute(AB_PROVIDER *pro, AB_IMEXPORTER_CONTEXT *ctx,
-			uint32_t guiid){
+int AO_Provider_Execute(AB_PROVIDER *pro, AB_IMEXPORTER_CONTEXT *ctx){
   AO_PROVIDER *dp;
   int oks=0;
   int errors=0;
@@ -431,7 +463,7 @@ int AO_Provider_Execute(AB_PROVIDER *pro, AB_IMEXPORTER_CONTEXT *ctx,
   dp=GWEN_INHERIT_GETDATA(AB_PROVIDER, AO_PROVIDER, pro);
   assert(dp);
 
-  rv=AO_Provider_ExecQueue(pro, ctx, guiid);
+  rv=AO_Provider_ExecQueue(pro, ctx);
   if (!rv)
     oks++;
   else {
@@ -483,7 +515,7 @@ int AO_Provider_Execute(AB_PROVIDER *pro, AB_IMEXPORTER_CONTEXT *ctx,
     AB_Job_List2Iterator_free(jit);
   }
 
-  rv=AB_Banking_ExecutionProgress(AB_Provider_GetBanking(pro), 0);
+  rv=AB_Banking_ExecutionProgress(AB_Provider_GetBanking(pro));
   if (rv==GWEN_ERROR_USER_ABORTED) {
     DBG_INFO(AQOFXCONNECT_LOGDOMAIN,
              "User aborted");
@@ -505,8 +537,7 @@ int AO_Provider_Execute(AB_PROVIDER *pro, AB_IMEXPORTER_CONTEXT *ctx,
 
 int AO_Provider__ProcessImporterContext(AB_PROVIDER *pro,
 					AB_USER *u,
-					AB_IMEXPORTER_CONTEXT *ictx,
-					uint32_t guiid){
+					AB_IMEXPORTER_CONTEXT *ictx){
   AB_IMEXPORTER_ACCOUNTINFO *ai;
 
   assert(pro);
@@ -534,9 +565,9 @@ int AO_Provider__ProcessImporterContext(AB_PROVIDER *pro,
 
       a=AB_Banking_FindAccount(AB_Provider_GetBanking(pro),
                                AQOFXCONNECT_BACKENDNAME,
-                               country, bankCode, accountNumber);
+                               country, bankCode, accountNumber, NULL);
       if (!a) {
-        char msg[]=I18N_NOOP("Adding account %s to bank %s");
+        char msg[]=I18S("Adding account %s to bank %s");
         char msgbuf[512];
 
         DBG_INFO(AQOFXCONNECT_LOGDOMAIN, "Adding account %s to bank %s",
@@ -558,7 +589,7 @@ int AO_Provider__ProcessImporterContext(AB_PROVIDER *pro,
 
         snprintf(msgbuf, sizeof(msgbuf), I18N(msg),
                  accountNumber, bankCode);
-	GWEN_Gui_ProgressLog(guiid,
+	GWEN_Gui_ProgressLog(0,
 			     GWEN_LoggerLevel_Notice,
 			     msgbuf);
         AB_Banking_AddAccount(AB_Provider_GetBanking(pro),a );
@@ -590,9 +621,7 @@ int AO_Provider__ProcessImporterContext(AB_PROVIDER *pro,
 
 
 
-int AO_Provider_RequestAccounts(AB_PROVIDER *pro,
-				AB_USER *u,
-				uint32_t guiid) {
+int AO_Provider_RequestAccounts(AB_PROVIDER *pro, AB_USER *u, int keepOpen) {
   AO_PROVIDER *dp;
   GWEN_BUFFER *reqbuf;
   GWEN_BUFFER *rbuf=NULL;
@@ -609,6 +638,7 @@ int AO_Provider_RequestAccounts(AB_PROVIDER *pro,
 			     GWEN_GUI_PROGRESS_SHOW_PROGRESS |
 			     GWEN_GUI_PROGRESS_SHOW_LOG |
                              GWEN_GUI_PROGRESS_ALWAYS_SHOW_LOG |
+                             (keepOpen?GWEN_GUI_PROGRESS_KEEP_OPEN:0) |
 			     GWEN_GUI_PROGRESS_SHOW_ABORT,
 			     I18N("Requesting account list"),
 			     I18N("We are now requesting a list of "
@@ -620,14 +650,14 @@ int AO_Provider_RequestAccounts(AB_PROVIDER *pro,
 				  "which can be managed via <i>OFX</i>.\n"
 				  "</html>"),
 			     1,
-			     guiid);
+                             0);
   ictx=AB_ImExporterContext_new();
 
   reqbuf=GWEN_Buffer_new(0, 2048, 0, 1);
   GWEN_Buffer_ReserveBytes(reqbuf, 1024);
 
   /* add actual request */
-  rv=AO_Provider__AddAccountInfoReq(pro, u, guiid, reqbuf);
+  rv=AO_Provider__AddAccountInfoReq(pro, u, reqbuf);
   if (rv<0) {
     DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
 	      "Error adding request element (%d)", rv);
@@ -638,7 +668,7 @@ int AO_Provider_RequestAccounts(AB_PROVIDER *pro,
   }
 
   /* wrap message (adds headers etc) */
-  rv=AO_Provider__WrapMessage(pro, u, reqbuf, guiid);
+  rv=AO_Provider__WrapMessage(pro, u, reqbuf);
   if (rv<0) {
     DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
 	      "Error adding request element (%d)", rv);
@@ -648,13 +678,12 @@ int AO_Provider_RequestAccounts(AB_PROVIDER *pro,
     return rv;
   }
 
-  /* exchange mesages */
+  /* exchange mesages (could also return HTTP code!) */
   rv=AO_Provider_SendAndReceive(pro, u,
 				(const uint8_t*)GWEN_Buffer_GetStart(reqbuf),
 				GWEN_Buffer_GetUsedBytes(reqbuf),
-				&rbuf,
-				guiid);
-  if (rv<0) {
+				&rbuf);
+  if (rv) {
     DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
 	      "Error exchanging getAccounts-request (%d)", rv);
     GWEN_Buffer_free(reqbuf);
@@ -686,7 +715,7 @@ int AO_Provider_RequestAccounts(AB_PROVIDER *pro,
     GWEN_Buffer_Rewind(rbuf);
     dbProfile=GWEN_DB_Group_new("profile");
     /* actually import */
-    rv=AB_ImExporter_ImportBuffer(importer, ictx, rbuf, dbProfile, pid);
+    rv=AB_ImExporter_ImportBuffer(importer, ictx, rbuf, dbProfile);
     GWEN_DB_Group_free(dbProfile);
     GWEN_Buffer_free(rbuf);
     if (rv<0) {
@@ -701,7 +730,7 @@ int AO_Provider_RequestAccounts(AB_PROVIDER *pro,
     }
 
     /* create accounts */
-    rv=AO_Provider__ProcessImporterContext(pro, u, ictx, pid);
+    rv=AO_Provider__ProcessImporterContext(pro, u, ictx);
     if (rv<0) {
       DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
 		"Error importing accounts (%d)", rv);
@@ -722,8 +751,7 @@ int AO_Provider_RequestAccounts(AB_PROVIDER *pro,
 
 
 int AO_Provider_RequestStatements(AB_PROVIDER *pro, AB_JOB *j,
-				  AB_IMEXPORTER_CONTEXT *ictx,
-				  uint32_t guiid) {
+				  AB_IMEXPORTER_CONTEXT *ictx) {
   AO_PROVIDER *dp;
   GWEN_BUFFER *reqbuf;
   GWEN_BUFFER *rbuf=0;
@@ -755,7 +783,7 @@ int AO_Provider_RequestStatements(AB_PROVIDER *pro, AB_JOB *j,
   GWEN_Buffer_ReserveBytes(reqbuf, 1024);
 
   /* add actual request */
-  rv=AO_Provider__AddStatementRequest(pro, j, guiid, reqbuf);
+  rv=AO_Provider__AddStatementRequest(pro, j, reqbuf);
   if (rv<0) {
     DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
 	      "Error adding request element (%d)", rv);
@@ -764,7 +792,7 @@ int AO_Provider_RequestStatements(AB_PROVIDER *pro, AB_JOB *j,
   }
 
   /* wrap message (adds headers etc) */
-  rv=AO_Provider__WrapMessage(pro, u, reqbuf, guiid);
+  rv=AO_Provider__WrapMessage(pro, u, reqbuf);
   if (rv<0) {
     DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
 	      "Error adding request element (%d)", rv);
@@ -772,16 +800,15 @@ int AO_Provider_RequestStatements(AB_PROVIDER *pro, AB_JOB *j,
     return rv;
   }
 
-  /* exchange messages */
+  /* exchange messages (might also return HTTP code!) */
   rv=AO_Provider_SendAndReceive(pro, u,
 				(const uint8_t*)GWEN_Buffer_GetStart(reqbuf),
 				GWEN_Buffer_GetUsedBytes(reqbuf),
-				&rbuf,
-				guiid);
-  if (rv<0) {
+				&rbuf);
+  if (rv) {
     DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
 	      "Error exchanging getStatements-request (%d)", rv);
-    GWEN_Gui_ProgressLog(guiid,
+    GWEN_Gui_ProgressLog(0,
 			 GWEN_LoggerLevel_Error,
 			 I18N("Error parsing server response"));
     GWEN_Buffer_free(rbuf);
@@ -794,7 +821,7 @@ int AO_Provider_RequestStatements(AB_PROVIDER *pro, AB_JOB *j,
 
     /* parse response */
     GWEN_Buffer_free(reqbuf);
-    GWEN_Gui_ProgressLog(guiid,
+    GWEN_Gui_ProgressLog(0,
 			 GWEN_LoggerLevel_Info,
 			 I18N("Parsing response"));
 
@@ -810,13 +837,13 @@ int AO_Provider_RequestStatements(AB_PROVIDER *pro, AB_JOB *j,
     GWEN_Buffer_Rewind(rbuf);
     dbProfile=GWEN_DB_Group_new("profile");
     /* actually import */
-    rv=AB_ImExporter_ImportBuffer(importer, ictx, rbuf, dbProfile, guiid);
+    rv=AB_ImExporter_ImportBuffer(importer, ictx, rbuf, dbProfile);
     GWEN_DB_Group_free(dbProfile);
     GWEN_Buffer_free(rbuf);
     if (rv<0) {
       DBG_ERROR(AQOFXCONNECT_LOGDOMAIN,
 		"Error importing server response (%d)", rv);
-      GWEN_Gui_ProgressLog(guiid,
+      GWEN_Gui_ProgressLog(0,
 			   GWEN_LoggerLevel_Error,
 			   I18N("Error parsing response"));
       return rv;
@@ -833,8 +860,7 @@ int AO_Provider_RequestStatements(AB_PROVIDER *pro, AB_JOB *j,
 
 int AO_Provider_ExecUserQueue(AB_PROVIDER *pro,
                               AB_IMEXPORTER_CONTEXT *ctx,
-			      AO_USERQUEUE *uq,
-			      uint32_t guiid){
+			      AO_USERQUEUE *uq){
   AB_JOB_LIST2_ITERATOR *jit;
   AO_PROVIDER *dp;
   int errors=0;
@@ -861,7 +887,7 @@ int AO_Provider_ExecUserQueue(AB_PROVIDER *pro,
         int rv;
 
 	/* start new context */
-	rv=AO_Provider_RequestStatements(pro, uj, ctx, guiid);
+	rv=AO_Provider_RequestStatements(pro, uj, ctx);
 	if (rv==GWEN_ERROR_USER_ABORTED) {
 	  DBG_INFO(AQOFXCONNECT_LOGDOMAIN, "User aborted");
 	  AB_Job_List2Iterator_free(jit);
@@ -876,8 +902,7 @@ int AO_Provider_ExecUserQueue(AB_PROVIDER *pro,
 	  oks++;
 	else
 	  errors++;
-	rv=GWEN_Gui_ProgressAdvance(guiid,
-				    AO_Provider_CountDoneJobs(dp->bankingJobs));
+	rv=GWEN_Gui_ProgressAdvance(0, AO_Provider_CountDoneJobs(dp->bankingJobs));
 	if (rv==GWEN_ERROR_USER_ABORTED) {
 	  DBG_INFO(AQOFXCONNECT_LOGDOMAIN, "User aborted");
 	  AB_Job_List2Iterator_free(jit);
@@ -899,8 +924,7 @@ int AO_Provider_ExecUserQueue(AB_PROVIDER *pro,
 
 
 int AO_Provider_ExecQueue(AB_PROVIDER *pro,
-			  AB_IMEXPORTER_CONTEXT *ctx,
-			  uint32_t guiid) {
+			  AB_IMEXPORTER_CONTEXT *ctx) {
   AO_USERQUEUE *uq;
   AO_PROVIDER *dp;
   int errors=0;
@@ -926,10 +950,10 @@ int AO_Provider_ExecQueue(AB_PROVIDER *pro,
 	     I18N("Locking user %s"),
 	     AB_User_GetUserId(u));
     tbuf[sizeof(tbuf)-1]=0;
-    GWEN_Gui_ProgressLog(guiid,
+    GWEN_Gui_ProgressLog(0,
 			 GWEN_LoggerLevel_Info,
 			 tbuf);
-    rv=AB_Banking_BeginExclUseUser(ab, u, guiid);
+    rv=AB_Banking_BeginExclUseUser(ab, u);
     if (rv<0) {
       DBG_INFO(AQOFXCONNECT_LOGDOMAIN,
 	       "Could not lock customer [%s] (%d)",
@@ -938,23 +962,23 @@ int AO_Provider_ExecQueue(AB_PROVIDER *pro,
 	       I18N("Could not lock user %s (%d)"),
 	       AB_User_GetUserId(u), rv);
       tbuf[sizeof(tbuf)-1]=0;
-      GWEN_Gui_ProgressLog(guiid,
+      GWEN_Gui_ProgressLog(0,
 			   GWEN_LoggerLevel_Error,
 			   tbuf);
-      AB_Banking_EndExclUseUser(ab, u, 1, guiid);  /* abandon */
+      AB_Banking_EndExclUseUser(ab, u, 1);  /* abandon */
       errors++;
       if (rv==GWEN_ERROR_USER_ABORTED)
 	return rv;
     }
     else {
-      rv=AO_Provider_ExecUserQueue(pro, ctx, uq, guiid);
+      rv=AO_Provider_ExecUserQueue(pro, ctx, uq);
       if (rv)
 	errors++;
       else
 	oks++;
       if (rv==GWEN_ERROR_USER_ABORTED) {
 	DBG_INFO(AQOFXCONNECT_LOGDOMAIN, "User aborted");
-	AB_Banking_EndExclUseUser(ab, u, 1, guiid);  /* abandon */
+	AB_Banking_EndExclUseUser(ab, u, 1);  /* abandon */
 	return rv;
       }
 
@@ -962,16 +986,16 @@ int AO_Provider_ExecQueue(AB_PROVIDER *pro,
 	       I18N("Unlocking user %s"),
 	       AB_User_GetUserId(u));
       tbuf[sizeof(tbuf)-1]=0;
-      GWEN_Gui_ProgressLog(guiid,
+      GWEN_Gui_ProgressLog(0,
 			   GWEN_LoggerLevel_Info,
 			   tbuf);
-      rv=AB_Banking_EndExclUseUser(ab, u, 0, guiid);
+      rv=AB_Banking_EndExclUseUser(ab, u, 0);
       if (rv<0) {
 	snprintf(tbuf, sizeof(tbuf)-1,
 		 I18N("Could not unlock user %s (%d)"),
 		 AB_User_GetUserId(u), rv);
 	tbuf[sizeof(tbuf)-1]=0;
-	GWEN_Gui_ProgressLog(guiid,
+	GWEN_Gui_ProgressLog(0,
 			     GWEN_LoggerLevel_Error,
 			     tbuf);
 	errors++;
@@ -1009,6 +1033,108 @@ int AO_Provider_ExtendAccount(AB_PROVIDER *pro, AB_ACCOUNT *a,
 }
 
 
+
+GWEN_DIALOG *AO_Provider_GetEditUserDialog(AB_PROVIDER *pro, AB_USER *u) {
+  AO_PROVIDER *xp;
+  GWEN_DIALOG *dlg;
+
+  assert(pro);
+  xp=GWEN_INHERIT_GETDATA(AB_PROVIDER, AO_PROVIDER, pro);
+  assert(xp);
+
+  dlg=AO_EditUserDialog_new(AB_Provider_GetBanking(pro), u, 1);
+  if (dlg==NULL) {
+    DBG_INFO(AQOFXCONNECT_LOGDOMAIN, "here (no dialog)");
+    return NULL;
+  }
+
+  return dlg;
+}
+
+
+
+GWEN_DIALOG *AO_Provider_GetNewUserDialog(AB_PROVIDER *pro, int i) {
+  AO_PROVIDER *xp;
+  GWEN_DIALOG *dlg;
+
+  assert(pro);
+  xp=GWEN_INHERIT_GETDATA(AB_PROVIDER, AO_PROVIDER, pro);
+  assert(xp);
+
+  dlg=AO_NewUserDialog_new(AB_Provider_GetBanking(pro));
+  if (dlg==NULL) {
+    DBG_INFO(AQOFXCONNECT_LOGDOMAIN, "here (no dialog)");
+    return NULL;
+  }
+
+  return dlg;
+}
+
+
+
+const AO_APPINFO *AO_Provider_GetAppInfos(AB_PROVIDER *pro) {
+  return _appInfos;
+}
+
+
+
+int AO_Provider_GetCert(AB_PROVIDER *pro, AB_USER *u) {
+  AO_PROVIDER *xp;
+  int rv;
+  const char *url;
+
+  assert(pro);
+  xp=GWEN_INHERIT_GETDATA(AB_PROVIDER, AO_PROVIDER, pro);
+  assert(xp);
+
+  url=AO_User_GetServerAddr(u);
+  if (url && *url) {
+    uint32_t uFlags;
+    uint32_t hFlags=0;
+    uint32_t pid;
+
+    uFlags=AO_User_GetFlags(u);
+    if (uFlags & AO_USER_FLAGS_FORCE_SSL3)
+      hFlags|=GWEN_HTTP_SESSION_FLAGS_FORCE_SSL3;
+
+    pid=GWEN_Gui_ProgressStart(GWEN_GUI_PROGRESS_ALLOW_EMBED |
+                               GWEN_GUI_PROGRESS_SHOW_PROGRESS |
+                               GWEN_GUI_PROGRESS_SHOW_ABORT,
+                               I18N("Getting Certificate"),
+                               I18N("We are now asking the server for its "
+                                    "SSL certificate"),
+                               GWEN_GUI_PROGRESS_NONE,
+                               0);
+
+    rv=AB_Banking_GetCert(AB_Provider_GetBanking(pro),
+                          url,
+                          "https", 443, &hFlags, pid);
+    if (rv<0) {
+      GWEN_Gui_ProgressEnd(pid);
+      return rv;
+    }
+
+    if (hFlags & GWEN_HTTP_SESSION_FLAGS_FORCE_SSL3) {
+      DBG_INFO(AQOFXCONNECT_LOGDOMAIN, "Setting ForceSSLv3 flag");
+      uFlags|=AO_USER_FLAGS_FORCE_SSL3;
+    }
+    else {
+      DBG_INFO(AQOFXCONNECT_LOGDOMAIN, "Clearing ForceSSLv3 flag");
+      uFlags&=~AO_USER_FLAGS_FORCE_SSL3;
+    }
+    AO_User_SetFlags(u, uFlags);
+    GWEN_Gui_ProgressEnd(pid);
+    return 0;
+  }
+  else {
+    DBG_ERROR(AQOFXCONNECT_LOGDOMAIN, "No url");
+    return GWEN_ERROR_INVALID;
+  }
+}
+
+
+
+
 #include "network.c"
 #include "request.c"
 
