@@ -1,6 +1,4 @@
 /***************************************************************************
- $RCSfile$
- -------------------
  begin       : Wed Jan 09 2008
  copyright   : (C) 2008 by Martin Preuss
  email       : martin@libchipcard.de
@@ -14,7 +12,6 @@
 
 
 int AO_Provider__AddBankStatementReq(AB_PROVIDER *pro, AB_JOB *j,
-				     uint32_t guiid,
 				     GWEN_BUFFER *buf) {
   const char *s;
   AB_ACCOUNT *a;
@@ -106,7 +103,6 @@ int AO_Provider__AddBankStatementReq(AB_PROVIDER *pro, AB_JOB *j,
 
 
 int AO_Provider__AddCreditCardStatementReq(AB_PROVIDER *pro, AB_JOB *j,
-					   uint32_t guiid,
 					   GWEN_BUFFER *buf) {
   const char *s;
   AB_ACCOUNT *a;
@@ -165,7 +161,6 @@ int AO_Provider__AddCreditCardStatementReq(AB_PROVIDER *pro, AB_JOB *j,
 
 
 int AO_Provider__AddInvStatementReq(AB_PROVIDER *pro, AB_JOB *j,
-				    uint32_t guiid,
 				    GWEN_BUFFER *buf) {
   const char *s;
   AB_ACCOUNT *a;
@@ -247,7 +242,6 @@ int AO_Provider__AddInvStatementReq(AB_PROVIDER *pro, AB_JOB *j,
 
 
 int AO_Provider__AddStatementRequest(AB_PROVIDER *pro, AB_JOB *j,
-				     uint32_t guiid,
 				     GWEN_BUFFER *buf) {
   AB_ACCOUNT *a;
   int rv;
@@ -257,11 +251,11 @@ int AO_Provider__AddStatementRequest(AB_PROVIDER *pro, AB_JOB *j,
 
   switch(AB_Account_GetAccountType(a)) {
   case AB_AccountType_CreditCard:
-    rv=AO_Provider__AddCreditCardStatementReq(pro, j, guiid, buf);
+    rv=AO_Provider__AddCreditCardStatementReq(pro, j, buf);
     break;
 
   case AB_AccountType_Investment:
-    rv=AO_Provider__AddInvStatementReq(pro, j, guiid, buf);
+    rv=AO_Provider__AddInvStatementReq(pro, j, buf);
     break;
 
   case AB_AccountType_Checking:
@@ -270,7 +264,7 @@ int AO_Provider__AddStatementRequest(AB_PROVIDER *pro, AB_JOB *j,
   case AB_AccountType_Cash:
   case AB_AccountType_Unknown:
   default:
-    rv=AO_Provider__AddBankStatementReq(pro, j, guiid, buf);
+    rv=AO_Provider__AddBankStatementReq(pro, j, buf);
     break;
   }
 
