@@ -1,6 +1,6 @@
 /***************************************************************************
  begin       : Fri Apr 02 2004
- copyright   : (C) 2004,2010 by Martin Preuss
+ copyright   : (C) 2004-2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -21,6 +21,8 @@
 #include <gwenhywfar/gui.h>
 #include <gwenhywfar/fastbuffer.h>
 #include <gwenhywfar/dbio_be.h>
+#include <gwenhywfar/syncio_file.h>
+#include <gwenhywfar/syncio_buffered.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -199,10 +201,20 @@ int AHB_SWIFT_GetNextSubTag(const char **sptr, AHB_SWIFT_SUBTAG **tptr) {
 
   s=*sptr;
   if (*s=='?') {
-    /* we check for >3 because empty fields are also treated as "no subtag" */
-    if (strlen(s)>3 && isdigit(s[1]) && isdigit(s[2])) {
-      id=((s[1]-'0')*10)+(s[2]-'0');
-      s+=3;
+    const char *t;
+
+    t=s;
+    t++;
+    if (*t==0x0a)
+      t++;
+    if (*t && isdigit(*t)) {
+      id=(*(t++)-'0')*10;
+      if (*t==0x0a)
+	t++;
+      if (*t && isdigit(*t)) {
+	id+=*(t++)-'0';
+	s=t;
+      }
     }
   }
   content=s;
@@ -211,11 +223,25 @@ int AHB_SWIFT_GetNextSubTag(const char **sptr, AHB_SWIFT_SUBTAG **tptr) {
   for (;;) {
     while(*s && *s!='?')
       s++;
-    if (*s=='?' && strlen(s)>3 && isdigit(s[1]) && isdigit(s[2])) {
-      nextId=((s[1]-'0')*10)+(s[2]-'0');
-      /* TODO: check nextId */
-      /* s is the beginning of a new subtag, so the end has been found */
-      break;
+
+    if (*s=='?') {
+      const char *t;
+  
+      t=s;
+      t++;
+      if (*t==0x0a)
+	t++;
+      if (*t && isdigit(*t)) {
+	nextId=(*(t++)-'0')*10;
+	if (*t==0x0a)
+	  t++;
+	if (*t && isdigit(*t)) {
+	  nextId+=*(t++)-'0';
+	  /* TODO: check nextId */
+	  /* s is the beginning of a new subtag, so the end has been found */
+	  break;
+	}
+      }
     }
     else if (*s)
       /* not the beginning of a new tag, continue */
@@ -459,7 +485,7 @@ int AHB_SWIFT__ReadDocument(GWEN_FAST_BUFFER *fb,
       DBG_ERROR(AQBANKING_LOGDOMAIN,
                 "Error in SWIFT data: no tag name");
       GWEN_Text_DumpString(GWEN_Buffer_GetStart(lbuf),
-                           GWEN_Buffer_GetUsedBytes(lbuf), stderr, 2);
+                           GWEN_Buffer_GetUsedBytes(lbuf), 2);
       GWEN_Buffer_free(lbuf);
       return -1;
     }
@@ -470,7 +496,7 @@ int AHB_SWIFT__ReadDocument(GWEN_FAST_BUFFER *fb,
       DBG_ERROR(AQBANKING_LOGDOMAIN,
                 "Error in SWIFT data: incomplete tag name");
       GWEN_Text_DumpString(GWEN_Buffer_GetStart(lbuf),
-			   GWEN_Buffer_GetUsedBytes(lbuf), stderr, 2);
+			   GWEN_Buffer_GetUsedBytes(lbuf), 2);
       GWEN_Buffer_free(lbuf);
       return -1;
     }
@@ -547,7 +573,7 @@ int AHB_SWIFT_ReadDocument(GWEN_FAST_BUFFER *fb,
       }
       if (swhead[2]!=':') {
         DBG_ERROR(AQBANKING_LOGDOMAIN, "Not a SWIFT block");
-        GWEN_Text_DumpString(swhead, 4, stderr, 2);
+        GWEN_Text_DumpString(swhead, 4, 2);
 	return GWEN_ERROR_BAD_DATA;
       }
       DBG_DEBUG(0, "Reading block %d", swhead[1]-'0');
@@ -558,7 +584,7 @@ int AHB_SWIFT_ReadDocument(GWEN_FAST_BUFFER *fb,
       for (;;) {
 	GWEN_FASTBUFFER_READBYTE(fb, c);
         if (c<0) {
-	  if (c==GWEN_BUFFEREDIO_CHAR_EOF) {
+	  if (c==GWEN_ERROR_EOF) {
 	    DBG_ERROR(AQBANKING_LOGDOMAIN,
 		      "EOF met (%d)", c);
 	    return GWEN_ERROR_EOF;
@@ -636,7 +662,7 @@ int AHB_SWIFT_ReadDocument(GWEN_FAST_BUFFER *fb,
         for (;;) {
 	  GWEN_FASTBUFFER_READBYTE(fb, c);
 	  if (c<0) {
-            if (c==GWEN_BUFFEREDIO_CHAR_EOF) {
+            if (c==GWEN_ERROR_EOF) {
               DBG_ERROR(AQBANKING_LOGDOMAIN,
                         "EOF met (%d)", c);
 	      return GWEN_ERROR_EOF;
@@ -667,12 +693,10 @@ int AHB_SWIFT_ReadDocument(GWEN_FAST_BUFFER *fb,
 
 
 int AHB_SWIFT_Import(GWEN_DBIO *dbio,
-		     GWEN_IO_LAYER *io,
+		     GWEN_SYNCIO *sio,
                      GWEN_DB_NODE *data,
 		     GWEN_DB_NODE *cfg,
-		     uint32_t flags,
-		     uint32_t guiid,
-		     int msecs) {
+		     uint32_t flags) {
   int rv;
   const char *p;
   int skipFileLines;
@@ -693,7 +717,41 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
   skipFileLines=GWEN_DB_GetIntValue(cfg, "skipFileLines", 0, 0);
   skipDocLines=GWEN_DB_GetIntValue(cfg, "skipDocLines", 0, 0);
 
-  fb=GWEN_FastBuffer_new(256, io, guiid, msecs);
+  fb=GWEN_FastBuffer_new(256, sio);
+
+  /* skip lines at the beginning if requested */
+  if (skipFileLines>0) {
+    int i;
+    GWEN_BUFFER *lbuf;
+
+    lbuf=GWEN_Buffer_new(0, 256, 0, 1);
+    for (i=0; i<skipFileLines; i++) {
+      int err;
+
+      err=GWEN_FastBuffer_ReadLineToBuffer(fb, lbuf);
+      if (err<0) {
+	if (err==GWEN_ERROR_EOF && i==0)
+	  break;
+	DBG_INFO(AQBANKING_LOGDOMAIN,
+		 "Error in report, aborting (%d)", err);
+	GWEN_Buffer_free(lbuf);
+	GWEN_FastBuffer_free(fb);
+	return err;
+      }
+      GWEN_Buffer_Reset(lbuf);
+    }
+    GWEN_Buffer_free(lbuf);
+
+    if (i<skipFileLines) {
+      /* not enough lines to skip, assume end of document */
+
+      GWEN_FastBuffer_free(fb);
+      DBG_INFO(AQBANKING_LOGDOMAIN, "To few lines in file");
+      GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Error,
+			   I18N("Empty SWIFT file, aborting"));
+      return GWEN_ERROR_EOF;
+    }
+  }
 
   for (;;) {
     AHB_SWIFT_TAG_LIST *tl;
@@ -701,7 +759,7 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
     tl=AHB_SWIFT_Tag_List_new();
 
     /* check for user abort */
-    rv=GWEN_Gui_ProgressAdvance(guiid, GWEN_GUI_PROGRESS_NONE);
+    rv=GWEN_Gui_ProgressAdvance(0, GWEN_GUI_PROGRESS_NONE);
     if (rv==GWEN_ERROR_USER_ABORTED) {
       DBG_INFO(AQBANKING_LOGDOMAIN, "User aborted");
       GWEN_FastBuffer_free(fb);
@@ -709,7 +767,7 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
       return rv;
     }
 
-    GWEN_Gui_ProgressLog(guiid, GWEN_LoggerLevel_Debug,
+    GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Debug,
 			 I18N("Reading SWIFT document"));
 
     /* skip lines at the beginning if requested */
@@ -741,12 +799,12 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
 	break;
     }
 
-    GWEN_Gui_ProgressLog(guiid, GWEN_LoggerLevel_Debug,
+    GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Debug,
 			 I18N("Parsing SWIFT data"));
     rv=AHB_SWIFT_ReadDocument(fb, tl, 0);
     if (rv<0) {
       DBG_INFO(AQBANKING_LOGDOMAIN, "Error in report, aborting");
-      GWEN_Gui_ProgressLog(guiid, GWEN_LoggerLevel_Error,
+      GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Error,
 			   I18N("Error parsing SWIFT data"));
       GWEN_FastBuffer_free(fb);
       AHB_SWIFT_Tag_List_free(tl);
@@ -757,7 +815,7 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
       DBG_INFO(AQBANKING_LOGDOMAIN, "End of document reached");
       if (docsImported==0) {
 	DBG_INFO(AQBANKING_LOGDOMAIN, "Empty document, aborting");
-	GWEN_Gui_ProgressLog(guiid, GWEN_LoggerLevel_Error,
+	GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Error,
 			     I18N("Empty SWIFT document, aborting"));
 	GWEN_FastBuffer_free(fb);
 	AHB_SWIFT_Tag_List_free(tl);
@@ -767,18 +825,18 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
     }
 
     /* now all tags have been read, transform them */
-    GWEN_Gui_ProgressLog(guiid, GWEN_LoggerLevel_Debug,
+    GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Debug,
 			 I18N("Importing SWIFT data"));
-    rv=AHB_SWIFT940_Import(tl, data, cfg, flags, guiid, msecs);
+    rv=AHB_SWIFT940_Import(tl, data, cfg, flags);
     if (rv) {
       DBG_INFO(AQBANKING_LOGDOMAIN, "Error importing SWIFT MT940");
-      GWEN_Gui_ProgressLog(guiid, GWEN_LoggerLevel_Error,
+      GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Error,
 			   I18N("Error importing SWIFT data"));
       GWEN_FastBuffer_free(fb);
       AHB_SWIFT_Tag_List_free(tl);
       return rv;
     }
-    GWEN_Gui_ProgressLog(guiid, GWEN_LoggerLevel_Debug,
+    GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Debug,
 			 I18N("Swift document successfully imported"));
     docsImported++;
   } /* for */
@@ -792,12 +850,10 @@ int AHB_SWIFT_Import(GWEN_DBIO *dbio,
 
 
 int AHB_SWIFT_Export(GWEN_DBIO *dbio,
-		     GWEN_IO_LAYER *io,
+		     GWEN_SYNCIO *sio,
 		     GWEN_DB_NODE *data,
                      GWEN_DB_NODE *cfg,
-		     uint32_t flags,
-		     uint32_t guiid,
-		     int msecs) {
+		     uint32_t flags) {
   DBG_ERROR(AQBANKING_LOGDOMAIN, "AHB_SWIFT_Export: Not yet implemented");
   return -1;
 }
@@ -805,29 +861,30 @@ int AHB_SWIFT_Export(GWEN_DBIO *dbio,
 
 
 GWEN_DBIO_CHECKFILE_RESULT AHB_SWIFT_CheckFile(GWEN_DBIO *dbio,
-					       const char *fname,
-					       uint32_t guiid,
-					       int msecs) {
-  int fd;
-  GWEN_BUFFEREDIO *bio;
+					       const char *fname) {
   int i;
   GWEN_DBIO_CHECKFILE_RESULT res;
   GWEN_BUFFER *lbuf;
+  GWEN_SYNCIO *sio;
+  GWEN_SYNCIO *baseIo;
+  int rv;
 
   assert(dbio);
   assert(fname);
 
-  fd=open(fname, O_RDONLY);
-  if (fd==-1) {
+  sio=GWEN_SyncIo_File_new(fname, GWEN_SyncIo_File_CreationMode_OpenExisting);
+  GWEN_SyncIo_AddFlags(sio, GWEN_SYNCIO_FILE_FLAGS_READ);
+  baseIo=sio;
+
+  sio=GWEN_SyncIo_Buffered_new(baseIo);
+  rv=GWEN_SyncIo_Connect(sio);
+  if (rv<0) {
     /* error */
     DBG_ERROR(AQBANKING_LOGDOMAIN,
-              "open(%s): %s", fname, strerror(errno));
+	      "open(%s): %s", fname, strerror(errno));
     return GWEN_DBIO_CheckFileResultNotOk;
   }
 
-  bio=GWEN_BufferedIO_File_new(fd);
-  GWEN_BufferedIO_SetReadBuffer(bio, 0, 256);
-
   /* search for ":20:" tag */
   lbuf=GWEN_Buffer_new(0, 256, 0, 1);
   res=GWEN_DBIO_CheckFileResultNotOk;
@@ -835,15 +892,14 @@ GWEN_DBIO_CHECKFILE_RESULT AHB_SWIFT_CheckFile(GWEN_DBIO *dbio,
     int err;
     const char *p;
 
-    if (GWEN_BufferedIO_CheckEOF(bio))
-      break;
-
-    err=GWEN_BufferedIO_ReadLine2Buffer(bio, lbuf);
-    if (err) {
+    err=GWEN_SyncIo_Buffered_ReadLineToBuffer(sio, lbuf);
+    if (err<0) {
       DBG_INFO(AQBANKING_LOGDOMAIN, "Error in report, aborting");
       res=GWEN_DBIO_CheckFileResultNotOk;
       break;
     }
+    else if (err==0)
+      break;
     p=GWEN_Buffer_GetStart(lbuf);
     if (strstr(p, ":20:")) {
       /* don't be too sure about the file being importable... */
@@ -854,8 +910,8 @@ GWEN_DBIO_CHECKFILE_RESULT AHB_SWIFT_CheckFile(GWEN_DBIO *dbio,
   } /* for */
   GWEN_Buffer_free(lbuf);
 
-  GWEN_BufferedIO_Close(bio);
-  GWEN_BufferedIO_free(bio);
+  GWEN_SyncIo_Disconnect(sio);
+  GWEN_SyncIo_free(sio);
 
   return res;
 }
