@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Fri Apr 02 2004
- copyright   : (C) 2004 by Martin Preuss
+ copyright   : (C) 2004-2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -32,6 +29,9 @@
 #include <assert.h>
 
 
+#define CENTURY_CUTOFF_YEAR 70
+
+
 int AHB_SWIFT__SetCharValue(GWEN_DB_NODE *db,
                             uint32_t flags,
                             const char *name,
@@ -188,7 +188,7 @@ int AHB_SWIFT940_Parse_86(const AHB_SWIFT_TAG *tg,
 	  case 61:
 	  case 62:
 	  case 63: /* Verwendungszweck */
-	    if (strlen(s)>4 && s[4]=='+') {
+	    if (strlen(s)>5 && s[4]=='+') {
 	      if (identifier[0] && tbuf && GWEN_Buffer_GetUsedBytes(tbuf)) {
 		/* close previous identifier */
 		if (strcasecmp(identifier, "EREF+")==0) {
@@ -220,7 +220,7 @@ int AHB_SWIFT940_Parse_86(const AHB_SWIFT_TAG *tg,
 		tbuf=GWEN_Buffer_new(0, 54, 0, 1);
 	      else
 		GWEN_Buffer_Reset(tbuf);
-	      GWEN_Buffer_AppendString(tbuf, s+4);
+	      GWEN_Buffer_AppendString(tbuf, s+5);
 	    }
 	    else {
 	      /* no identifier here */
@@ -569,7 +569,10 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
     return -1;
   }
   d1a=((p[0]-'0')*10) + (p[1]-'0');
-  d1a+=2000;
+  if (d1a>=CENTURY_CUTOFF_YEAR)
+    d1a+=1900;
+  else
+    d1a+=2000;
   d2a=((p[2]-'0')*10) + (p[3]-'0');
   d3a=((p[4]-'0')*10) + (p[5]-'0');
 
@@ -799,6 +802,10 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
           AHB_SWIFT__SetCharValue(data, flags, "origvalue/currency", buffer);
           p+=3;
           bleft-=3;
+          if (*p=='/') { /* Deutsche Bank seems to be sending */
+	    p++;         /* a "/" between currency and amount */
+	    bleft--;
+          }
           /* get value */
           p2=p;
           while(*p2 && *p2!='/') p2++;
@@ -826,6 +833,10 @@ int AHB_SWIFT940_Parse_61(const AHB_SWIFT_TAG *tg,
           AHB_SWIFT__SetCharValue(data, flags, "charges/currency", buffer);
           p+=3;
           bleft-=3;
+          if (*p=='/') { /* Deutsche Bank seems to be sending */
+	    p++;         /* a "/" between currency and amount */
+	    bleft--;
+          }
           /* get value */
           p2=p;
           while(*p2 && *p2!='/') p2++;
@@ -899,7 +910,10 @@ int AHB_SWIFT940_Parse_6_0_2(const AHB_SWIFT_TAG *tg,
     return -1;
   }
   d1=((p[0]-'0')*10) + (p[1]-'0');
-  d1+=2000;
+  if (d1>=CENTURY_CUTOFF_YEAR)
+    d1+=1900;
+  else
+    d1+=2000;
   d2=((p[2]-'0')*10) + (p[3]-'0');
   d3=((p[4]-'0')*10) + (p[5]-'0');
 
@@ -1079,9 +1093,7 @@ int AHB_SWIFT940_Parse_NS(const AHB_SWIFT_TAG *tg,
 int AHB_SWIFT940_Import(AHB_SWIFT_TAG_LIST *tl,
 			GWEN_DB_NODE *data,
 			GWEN_DB_NODE *cfg,
-			uint32_t flags,
-			uint32_t guiid,
-			int msecs) {
+			uint32_t flags) {
   AHB_SWIFT_TAG *tg;
   GWEN_DB_NODE *dbDay=NULL;
   GWEN_DB_NODE *dbTemplate=NULL;
@@ -1108,7 +1120,7 @@ int AHB_SWIFT940_Import(AHB_SWIFT_TAG_LIST *tl,
 				    I18N("Importing SWIFT tags..."),
 				    NULL,
 				    AHB_SWIFT_Tag_List_GetCount(tl),
-				    guiid);
+				    0);
 
   tg=AHB_SWIFT_Tag_List_First(tl);
   while(tg) {
