@@ -1,7 +1,4 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Mon Mar 01 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -14,19 +11,19 @@
 #ifndef AQBANKING_VERSION_H
 #define AQBANKING_VERSION_H
 
-#define AQBANKING_VERSION_MAJOR 4
-#define AQBANKING_VERSION_MINOR 2
-#define AQBANKING_VERSION_PATCHLEVEL 4
+#define AQBANKING_VERSION_MAJOR 5
+#define AQBANKING_VERSION_MINOR 0
+#define AQBANKING_VERSION_PATCHLEVEL 2
 #define AQBANKING_VERSION_BUILD 0
 #define AQBANKING_VERSION_TAG "stable"
-#define AQBANKING_VERSION_FULL_STRING "4.2.4.0stable"
-#define AQBANKING_VERSION_STRING "4.2.4"
+#define AQBANKING_VERSION_FULL_STRING "5.0.2.0stable"
+#define AQBANKING_VERSION_STRING "5.0.2"
 
 
-#define AQBANKING_SO_CURRENT 31
-#define AQBANKING_SO_REVISION 4
-#define AQBANKING_SO_AGE 2
-#define AQBANKING_SO_EFFECTIVE 29
+#define AQBANKING_SO_CURRENT 33
+#define AQBANKING_SO_REVISION 2
+#define AQBANKING_SO_AGE 0
+#define AQBANKING_SO_EFFECTIVE 33
 
 #endif /* AQBANKING_VERSION_H */
 
